//                           This file uses Kraks distance data (afst_erh_81_05 og afst_gym_81_05) together with individual addresses (from A10_findadresse) 
//	                         to construct the distance between each individual and the nearest upper secondary educational institutions

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

cd $data

set more off, perm 

// First we find which specific programs each institutions offer 
forval uddayear=2001/2014{      
local t_1 = `uddayear'-1
use "$adj_raw\udda`t_1'", clear
keep pnr igfsp
gen igfsp_1=floor(igfsp/10000)
gen igupsec_1=inrange(igfsp_1,2000,3599)  // enrolled in upper secondary education in year t-1
keep pnr igupsec_1
save temp, replace
use "$adj_raw\udda`uddayear'", clear
keep pnr iginstnr igfsp
gen simpleigfsp = floor(igfsp/1000000)
gen simpleigfsp2 = floor(igfsp/10000)
drop igfsp
keep if inrange(simpleigfsp,20,30)  // enrolled in (first year of) upper secondary school 
merge 1:1 pnr using temp, nogen keep(master match)
drop if igupsec_1==1    // not enrolled in upper secondary school previous year (especially, we drop non-first year students at academic schools)

//In year 2009 the vocational school category 3049 is split into 3049 and 3050, and from year 2010 it is primarily 3050. 
//Thus, we consider 3049 and 3050 to be a single category in all years.
replace simpleigfsp2 = 2016 if inrange(simpleigfsp2,2017,2018)
replace simpleigfsp2 = 2551 if inrange(simpleigfsp2,2554,2559)
replace simpleigfsp2 = 3049 if simpleigfsp2 == 3050
tab1 simpleigfsp simpleigfsp2, mis
tab  simpleigfsp simpleigfsp2
 
//Here, we construct variables indicating whether a given institution offers programs within main types (groups) of programs (`hgruppe')
foreach hgruppe of numlist 20 25 30 {
gen number`hgruppe'_temp = 1 if simpleigfsp == `hgruppe'
bysort iginstnr: egen number`hgruppe' = max(number`hgruppe'_temp)
bysort iginstnr: egen n`hgruppe'      = total(number`hgruppe'_temp)
replace number`hgruppe'=0 if n`hgruppe'<10   // We require at least 10 new students for the instition to be enrolled into this main group of programs (hgruppe)
drop number`hgruppe'_temp
} 
foreach ugruppe of numlist 2015 2016 2539 2551 3039 3040 3042 3044 3046 3048 3049 {
gen number`ugruppe'_temp = 1 if simpleigfsp2 == `ugruppe'
bysort iginstnr: egen number`ugruppe' = max(number`ugruppe'_temp)
bysort iginstnr: egen n`ugruppe'      = total(number`ugruppe'_temp)
replace number`ugruppe'=0 if n`ugruppe'<10          // Similar requirement for more detailed types/groups of programs               
drop number`ugruppe'_temp
}
preserve

bys iginstnr: keep if _n==1     // dataset with only one record per institution
keep iginstnr n2* n3* number*
tab1 n20 n25 n30
tab n20 if n20>0   // n20 is the number of students enrolled in traditional general upper secondary programs
tab n25 if n25>0   // n25 is the number of students enrolled in commercial or technical general upper secondary programs
tab n30 if n30>0   // n30 is the number of students enrolled in vocational programs

restore

//Here we construct weights which are used to calculate weighted average distance measures
//We construct these weights for the main groups defined as general schools (2025) and vocational schools (30)
gen udda30dummy = inlist(simpleigfsp,30)
gen udda2025dummy = inlist(simpleigfsp,20,25)

foreach hgruppe in 30 2025 {
bysort simpleigfsp2:       gen weight_temp`hgruppe' = _N      if udda`hgruppe'dummy == 1   // No. of persons within each of the 11 detailed categories of simpleigfsp2 who are in the main group hgruppe; e.g. the No. with 2015 within hgrupe 2025
bysort udda`hgruppe'dummy: gen weighttotal_temp`hgruppe' = _N if udda`hgruppe'dummy == 1   // Within each hgruppe: The total number of persons, i.e. the denominator when calculating weights
egen weighttotal`hgruppe' = max(weighttotal_temp`hgruppe')                                 // Ditto - This total is in all observations
la var weighttotal`hgruppe' "Weight denominator for main group `hgruppe'"
}
drop udda30dummy udda2025dummy 

// The variable weight_hgruppe_ugruppe is the No. of obs. with detailed edu code ugruppe divided by the total No. of obs. within the main group hgruppe 
global numlist20   "2015 2016"
global numlist25   "2539 2551"
global numlist2025 "2015 2016 2539 2551"
global numlist30   "3039 3040 3042 3044 3046 3048 3049"
global numlist2530 "2539 2551 3039 3040 3042 3044 3046 3048 3049"

foreach hgruppe in 2025 30 {
foreach ugruppe of global numlist`hgruppe' {
di "`hgruppe' `ugruppe'"
gen weight`hgruppe'_`ugruppe'_temp = weight_temp`hgruppe' if simpleigfsp2 == `ugruppe'  
egen weight`hgruppe'_`ugruppe' = max(weight`hgruppe'_`ugruppe'_temp)
replace weight`hgruppe'_`ugruppe' = weight`hgruppe'_`ugruppe' / weighttotal`hgruppe'
drop weight`hgruppe'_`ugruppe'_temp
la var weight`hgruppe'_`ugruppe' "Weight of `ugruppe' within `hgruppe'"
} 
}

drop simpleigfsp simpleigfsp2 *_temp* pnr igupsec_1
bysort iginstnr: keep if _n == 1             // keep only one obs. for each institution
sum weight*

save "$data\inst_uddannelse_v2", replace

keep weight*
collapse weight*
gen k = 1

save "$data\inst_uddannelse_v2_weights", replace


//Below we combine data for the types of programs offered by the institutions and data for the distance between addresses of individuals and addresses of the 20 closest institutions (vocational and commercial/technical general schools)
if `uddayear'<=2007{                                                                // uddayear is the year after start of education status is measured. Thus, uddayear=2007 => year of of edu start is 2006
use "D:\data\Workdata\703822\Projekter\p1602\data\afstande\afst_erh_81_05", clear   // All addresses 1981-2005(2006), old municipalities. Old municipality codes are used in 2006 and earlier by Statistics Denmark
}
if `uddayear'>2007{                                                                 // uddayear is the year after start of education status is measured. Thus, uddayear=2008 => year of of edu start is 2007
use "D:\data\Workdata\703822\Projekter\p1602\data\afstande\afst_erh_07_12", clear   // All addresses 2007-2012, new municipalities. New municipality codes are used in 2007 and later by Statistics Denmark
}
forval t = 5/20 {
replace afst_`t' = 50000 if kom == 400 //correction for the island bornholm. 50000 is just an arbitrairy value, slightly higher than the average (34000). We do not use data for Bornholm in the final analysis
}
forval t = 1/20 {
rename afst_`t' afsterv_`t'
replace afsterv_`t' = afsterv_`t' / 1000
rename inst_`t' iginstnr 
merge m:1 iginstnr using "$data\inst_uddannelse_v2", nogen keep(master match)
rename iginstnr inst_`t' 
foreach gruppe in 25 30 3039 3040 3042 3044 3046 3048 3049 2539 2551 {
rename number`gruppe' number`gruppe'_`t'
rename n`gruppe' n`gruppe'_`t'
}
}
rename adr_aar adr_aar_erv
save "$data\inst_uddannelse_v2_erv", replace
if `uddayear'<=2007{
use "D:\data\Workdata\703822\Projekter\p1602\data\afstande\afst_gym_81_05", clear
}
if `uddayear'>2007{
use "D:\data\Workdata\703822\Projekter\p1602\data\afstande\afst_gym_07_12", clear
}
forval t = 1/10 {                                 // For traditional general schools: 10 closest indtitutions
rename afst_`t' afstgym_`t'
replace afstgym_`t' = afstgym_`t' / 1000
rename inst_`t' iginstnr 
merge m:1 iginstnr using "$data\inst_uddannelse_v2", nogen keep(master match)
rename iginstnr inst_`t' 
foreach gruppe in 20 2015 2016 {
rename number`gruppe' number`gruppe'_`t'
rename n`gruppe' n`gruppe'_`t'
}
}
rename adr_aar adr_aar_gymn
merge 1:1 opgikom kom using "$data\inst_uddannelse_v2_erv", nogen keep(master match)

//Below we calculate the distance to the nearest institution within main catogories

//For the traditional general schools (hgruppe 20) we find the nearest institution with students in the relevant year
foreach hgruppe in 20 {
gen afst`hgruppe'_first = .
forval t = 1/10 {
replace afst`hgruppe'_first = afstgym_`t' if number`hgruppe'_`t' == 1 & afst`hgruppe'_first == .
}
gen afstmissing`hgruppe' = 1 if afst`hgruppe'_first == .
replace afst`hgruppe'_first = afstgym_10 if afst`hgruppe'_first == .
count if afst`hgruppe'_first == .
la var afst`hgruppe'_first "Distance to nearest `hgruppe'"

//For traditional general schools, we find distances to nearest ugruppe (3-year stx, and 2-year hf) 
foreach ugruppe in 2015 2016 {
gen afst`hgruppe'_`ugruppe' = .
forval t = 1/10 {
replace afst`hgruppe'_`ugruppe' = afstgym_`t' if number`ugruppe'_`t' == 1 & afst`hgruppe'_`ugruppe' == .
}
gen afstmissing`hgruppe'_`ugruppe' = 1 if afst`hgruppe'_`ugruppe' == .
replace afst`hgruppe'_`ugruppe' = afstgym_10 if afst`hgruppe'_`ugruppe' == .
count if afst`hgruppe'_`ugruppe' == .
la var afst`hgruppe'_`ugruppe' "Distance to nearest `ugruppe'"
}
}

//For commercial and technical general schools and vocational schools we have 2 main groups (hgrupper):
foreach hgruppe in 25 30 {
gen afst`hgruppe'_first = .
forval t = 1/20 {
replace afst`hgruppe'_first = afsterv_`t' if number`hgruppe'_`t' == 1 & afst`hgruppe'_first == .
}
gen afstmissing`hgruppe' = 1 if afst`hgruppe'_first == .
replace afst`hgruppe'_first = afsterv_20 if afst`hgruppe'_first == .
count if afst`hgruppe'_first == .
la var afst`hgruppe'_first "Distance to nearest `hgruppe'"

//For the 9 specific types schools within commercial/technical general schools and vocational schools, we find the nearest institution with the specific type of program 
//(2 groups of general schools and 7 intro groups of vocational schools)
global numlist25 "2539 2551"
global numlist30 "3039 3040 3042 3044 3046 3048 3049"

foreach ugruppe of global numlist`hgruppe' {
gen afst`hgruppe'_`ugruppe' = .
forval t = 1/20 {
replace afst`hgruppe'_`ugruppe' = afsterv_`t' if number`ugruppe'_`t' == 1 & afst`hgruppe'_`ugruppe' == .
}
gen afstmissing`hgruppe'_`ugruppe' = 1 if afst`hgruppe'_`ugruppe' == .
replace afst`hgruppe'_`ugruppe' = afsterv_20 if afst`hgruppe'_`ugruppe' == .
count if afst`hgruppe'_`ugruppe' == .
la var afst`hgruppe'_`ugruppe' "Distance to nearest `ugruppe'" 
}
}

keep opgikom kom afst* adr_aar* weight*
drop weighttotal*

//Distances across main groups:
egen afst2025_first = rowmin(afst20_first afst25_first)
egen afst2530_first = rowmin(afst25_first afst30_first)
la var afst2025_first "Distance to nearest academic institution"
la var afst2530_first "Distance to nearest vocational or voc-oriented academic institution"

//Distances for specific groups:
foreach ugruppe in 2015 2016 {
gen afst2025_`ugruppe' = afst20_`ugruppe'
la var afst2025_`ugruppe' "Distance to nearest `ugruppe'"
}
foreach ugruppe in 2539 2551 {
gen afst2025_`ugruppe' = afst25_`ugruppe'
gen afst2530_`ugruppe' = afst25_`ugruppe'
la var afst2025_`ugruppe' "Distance to nearest `ugruppe'"
la var afst2530_`ugruppe' "Distance to nearest `ugruppe'"
}
foreach ugruppe in 3039 3040 3042 3044 3046 3048 3049 {
gen afst2530_`ugruppe' = afst30_`ugruppe'
la var afst2530_`ugruppe' "Distance to nearest `ugruppe'"
}


//Weighted average distances to main categories of schools:
gen k = 1
drop weight*
merge m:1 k using "$data\inst_uddannelse_v2_weights", nogen 

global numlist20   "2015 2016"
global numlist25   "2539 2551"
global numlist2025 "2015 2016 2539 2551"
global numlist30   "3039 3040 3042 3044 3046 3048 3049"
global numlist2530 "2539 2551 3039 3040 3042 3044 3046 3048 3049"

foreach hgruppe in 30 2025 {
foreach ugruppe of global numlist`hgruppe' {
gen afst`hgruppe'_w`ugruppe' = afst`hgruppe'_`ugruppe'*weight`hgruppe'_`ugruppe'
}
egen afst`hgruppe'_average_w = rowtotal(afst`hgruppe'_w*)
drop afst`hgruppe'_w*
la var afst`hgruppe'_average_w "Distance to `hgruppe', average weighted"
}

order opgikom kom afst30_first afst2025_first adr_aar* 


gen uddayear=`uddayear'
keep kom opgikom uddayear afst30_first afst2025_first *_average* adr_aar* afst20_2015 afst20_2016 afst25_2539 afst25_2551 afst30_3039 afst30_3040 afst30_3042 afst30_3044 afst30_3046 afst30_3048 afst30_3049

save "$data\uddannelse_afstand`uddayear'", replace
}

use "$data\uddannelse_afstand2001", clear
forval uddayear=2002/2014{
append using "$data\uddannelse_afstand`uddayear'"
}
save "$data\education_distance", replace

//deleting files
erase "$data\inst_uddannelse_v2.dta"
erase "$data\inst_uddannelse_v2_weights.dta"
erase "$data\inst_uddannelse_v2_erv.dta"
erase "$data\temp.dta"
