
/********************************************************************************
This program merges all previously created datasets, make new variables, 
add labels, etc.
*********************************************************************************/
set more off 

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

cd "$data"
clear

//Merges datasets
use data, clear
merge 1:1 pnrb using discony   
tab byear _merge
drop _merge
merge 1:1 pnrb using cony   
tab byear _merge
drop _merge
merge 1:1 pnrb using grades
tab byear _merge
drop _merge
merge 1:1 pnrb using indh
tab byear _merge
drop _merge
merge 1:1 pnrb using udd
tab byear _merge
drop _merge
merge 1:1 pnrb using crime
tab byear _merge
drop _merge
merge 1:1 pnrb using child_parent_address
tab byear _merge
drop _merge
merge 1:1 pnrb using firstuddaadresse, keep(master match)
tab byear _merge
drop _merge

//Merges distance to main sample using the address of individuals the first of January in the year completing compulsory school
rename adresse1opgikom opgikom
rename adresse1kom kom
gen uddayear=gradyear+1  // distance to education 1/1 in the year leaving lower secondary school. uddayear is used in the distance dataset. It is education status for population by 1/1, but effectively the previous year.
merge m:1 uddayear opgikom kom using education_distance, nogen keep(master match) keepusing(afst*)
foreach number in 30 2025 {
rename afst`number'_first     afst1_`number'_first
rename afst`number'_average_w afst1_`number'_average_w
la var afst1_`number'_first "Shortest distance to type `number' education in grad year"
la var afst1_`number'_average_w "Weighted average distance to type `number' education in grad year"
}
foreach number in 20_2015 20_2016 25_2539 25_2551 30_3039 30_3040 30_3042 30_3044 30_3046 30_3048 30_3049  {
rename afst`number'     afst1_`number'
}
rename opgikom adresse1opgikom 
rename kom adresse1kom 

// Distance is set to missing for the island Bornholm: only 1 academic and 4 vocational institutions on the island. Our calculation of average distances is misleading. 
// Also, addresses from before the merging of smaller municipalities at Bornholm into one in 2003 are not available in the basic distance files.
foreach ending in _first _average_w {
foreach number in 30 2025 {
replace afst1_`number'`ending' = . if adresse1kom==400
}
}

gen almgymn = firstudda == 20        
gen gymn = inlist(firstudda,20,25)    
gen ervgymn = inlist(firstudda,25)
drop vu vuf vum 

* Changing missing crime to no crimes
foreach x in crimem unconditionalm detentionm violencem violencem2 mentalm ///
             crimef unconditionalf detentionf violencef violencef2 mentalf{
replace `x'=0 if `x'==.
}

forval t=1986/1989{
gen b`t' = byear==`t'
la var b`t' "Birth year `t'"
}

label var ufagf "Compulsory edu. Father"
label var fagf "Vocational edu. Father"
gen vuf = kvuf+mvuf
label var vuf "Further education Father"
label var lvuf "Higher education Father"
gen lvvuf =vuf+lvuf
label var lvvuf "Further/Higher education Father"
label var kvuf "Short further edu. Father"
label var mvuf "Medium further edu. Father"

label var ufagm "Compulsory edu. Mother"
label var fagm "Vocational Mother"
gen vum = kvum+mvum
label var vum "Further education Mother"
label var lvum "Higher education Mother"
gen lvvum =vum+lvum
label var lvvum "Further/Higher education Mother"
label var kvum "Short further edu. Mother"
label var mvum "Medium further edu. Mother"

label var ufag "Compulsory education"
label var fag "Vocational education"
gen vu= kvu+mvu
label var vu "Further education"
label var lvu "Higher education"
gen lvvu=vu+lvu
label var lvvu "Further/Higher education"

la var twins "Multiple births"

gen finedu = 1 if ufag==0
replace finedu = 0 if ufag==1
la var finedu "Completed upper secondary education program"
label var ufag "No upper secondary education"

gen missincomem = (incomem==.)
label var missincomem "Missing income, mor"
gen missincomef = (incomef==.)
label var missincomef "Missing income, far"

//variable modifications
replace fagf = 0 if fagf == .
replace lvvuf = 0 if lvvuf == .
replace fagm = 0 if fagm == .
replace lvvum = 0 if lvvum == .
replace  missuddanyf = 0 if  missuddanyf== .
replace  missuddanym = 0 if  missuddanym== .
replace are_in_udfk = 0 if are_in_udfk == .
gen old_grad = grad_age >= 17 & grad_age != .
la var old_grad "At least age 17 when completing compulsory education"

gen no_obl_proj = obl_proj== .
replace obl_proj = 0 if obl_proj == .
gen no_exam_mat = math_ex == .
replace math_ex = 0 if math_ex == .
gen no_exam_dan = danish_OW_ex == .
replace danish_OW_ex = 0 if danish_OW_ex == .
gen no_exam_danmat = exam_danmat== .
replace exam_danmat = 0 if exam_danmat == .
gen no_exam_mean7 = exam_mean7== .
replace exam_mean7 = 0 if exam_mean7 == .
gen no_teacheval_mean7 = teacheval_mean7== .
replace teacheval_mean7 = 0 if teacheval_mean7 == .

gen no_obl_proj13 = obl_proj13== .
replace obl_proj13 = 6 if obl_proj13 == .
gen no_exam_mat13 = math_ex13 == .
replace math_ex13 = 6 if math_ex13 == .
gen no_exam_dan13 = danish_OW_ex13 == .
replace danish_OW_ex13 = 6 if danish_OW_ex13 == .
gen no_exam_dan_W_13 = danish_W_ex13 == .
replace danish_W_ex13 = 6 if danish_W_ex13 == .
gen no_exam_danmat13 = exam_danmat13== .
replace exam_danmat13 = 6 if exam_danmat13 == .
gen no_exam_mean7_13 = exam_mean7_13== .
replace exam_mean7_13 = 6 if exam_mean7_13 == .
gen no_teacheval_mean7_13 = teacheval_mean7_13== .
replace teacheval_mean7_13 = 6 if teacheval_mean7_13 == .
gen no_english_ex13 = english_ex13==.
replace english_ex13=6 if english_ex13==.
gen no_science_ex13 = science_ex13==.
replace science_ex13=6 if science_ex13==.

gen miss_twins = twins == .
replace twins = 0 if twins == .

foreach t in 1 5 10 14 {
la var parrentborsam`t' "Parents live together (`t' aar)"
la var borhjemme`t' "Live with parent(s) (`t' aar)"
la var nokomb`t' "Child in register (`t' aar)"
la var nokomm`t' "Mother in register (`t' aar)"
la var nokomf`t' "Father in register (`t' aar)"
}

la var no_obl_proj "No marks in mandatory project"
la var no_exam_mat "No marks in math"
la var no_exam_dan "No marks in Danish"
la var no_exam_danmat "No marks in Danish/math"
la var no_exam_mean7 "No marks in the 6 mandatory exams"
la var no_teacheval_mean7 "No marks for the year's work in the 8 subjects"

la var no_obl_proj13 "No marks in mandatory project"
la var no_exam_mat13 "No marks in math"
la var no_exam_dan13 "No marks in Danish"
la var no_exam_danmat13 "No marks in Danish/math"
la var no_exam_mean7_13 "No marks in the 6 mandatory exams"
la var no_teacheval_mean7_13 "No marks for the year's work in the 8 subjects"

la var miss_twins "No info on twins"


foreach var in old_grad grad_age min_grades4 min_grades7 nonmiss_math nonmiss_danish nonmiss_teacheval7 nonmiss_grade_ex7 min_grades4_13 min_grades7_13 nonmiss_math13 nonmiss_danish13 nonmiss_teacheval7_13 nonmiss_grade_ex7_13 {
replace `var' = 0 if `var' == . & are_in_udfk == 0
}

foreach var in rasledigm rasledigf raskontm raskontf rasfortidm rasfortidf rasuarbstyrkm rasuarbstyrkf norasm norasf {
replace `var' = 0 if `var' == .
}

label var hsmo "Any older half siblings, mother"
label var hsfo "Any older half siblings, father"

rename pnrb pnr

replace siblings = 0 if siblings >= 20   // implies: siblings=0 if siblings=.
replace onlychild=1 if siblings==0
gen sib1=siblings==1
gen sib2=siblings==2
la var sib1 "1 full sibling"
la var sib2 "2 full siblings"   // reference is that the child has 3 or more full siblings, i.e. that there are at least four full siblings in the family

replace ledgrm=0 if ledgrm== .
replace ledgrf=0 if ledgrf== .

gen incmism = incomem==.     // income is missing for mother (gross, disposable, earnings)
gen incmisf = incomef==.
la var incmism "Income missing mother"
la var incmisf "Income missing father"

replace incomem = 200000 if incomem == .    // perindkialt, gross income
replace incomef = 200000 if incomef == .
replace incomem = incomem/1000000
replace incomef = incomef/1000000

replace busincf=200000 if busincf==.
replace busincm=200000 if busincm==.
replace busincf=busincf/1000000
replace busincm=busincm/1000000

gen lincomem=incomem
replace lincomem=0.001 if incomem<0.001  // income less than DKK 1000 is replaced by 1000.
replace lincomem=log(lincomem)
la var lincomem "Log income mother" 
gen lincomef=incomef
replace lincomef=0.001 if incomef<0.001  // income less than DKK 1000 is replaced by 1000.
replace lincomef=log(lincomef)
la var lincomef "Log income father" 

foreach g in m f{
foreach x in wagerec selfemp unemp pen oth{
replace `x'`g'=0 if `x'`g'==.
}
}

gen notwithparents14=1-borhjemme14 
gen separation14=1-parrentborsam14 
la var notwithparents14 "Not with parent(s) at age 14"
la var separation14 "Parents separated at age 14"

forval a=15/29{
gen inpop`a'=hf_kode`a'!=.
la var inpop`a' "In population at age `a'"
}

la var firstuddafinish "First completed upper secondary edu. (by age 25)"
la var firstudda "First started upper secondary edu."

//detailed education codes for enrolment in firstuddayear
gen igfirst=.
forval t=2001/2014{
merge 1:1 pnr using "$adj_raw\udda`t'", nogen keep(master match) keepusing(igfsp`t')
replace igfirst=igfsp`t' if firstuddayear==`t' & igfirst==. & igfsp`t'!=.
drop igfsp`t'
}
sum pnr firstuddayear igfirst firstudda
gen igfirst4 = floor(igfirst/10000)
replace igfirst4=2016 if igfirst4==2017   
replace igfirst4=3049 if igfirst4==3050
bys firstudda: tab igfirst4
//label drop igfsp4
//label define igfsp4 2015 "General, 3-year (stx)" 2016 "General, 2-year (hf)" 2539 "Mercantile (hhx)" 2551 "Technical (htx)" 3039 "Commercial field" 3040 "Technology and communication" 3042 "Construction" 3044 "Craftsmanship" 3046 "Food production and catering" 3048 "Mechanical engineering, transport and logistics" 3049 "Service"
label define igfsp4 2015 "General, 3-year (stx)" 2016 "General, 2-year (hf)" 2539 "Mercantile (hhx)" 2551 "Technical (htx)" 3039 "Commercial field" 3040 "Technology, communication" 3042 "Construction" 3044 "Craftsmanship" 3046 "Food production, catering" 3048 "Mechanics, transport, logistics" 3049 "Service"
label values igfirst4 igfsp4
tab igfirst4
tab igfirst4 if 2000<igfirst4&igfirst4<2900
tab igfirst4 if 3000<igfirst4&igfirst4<3099

// Ethnicity. We use info at age 25 since the sample used in the analysis requires the person to be living in Denmark at age 25. 
gen ieland=.
gen ietype=.
forval t=2012/2015{
merge 1:1 pnr using "$rawdata\iepe`t'.dta", nogen keepusing(ie_type opr_land) keep(master match)
replace ieland=opr_land if `t'-byear==26
replace ietype=ie_type  if `t'-byear==26
}
				/* EU countries */
gen westim = inlist(ieland, 5126, 5128, 5422, 5607, 5104, 5130, 5134, ///
				5142, 5150, 5750, 5609, 5611, 5108, 5153, 5140, 5154, 5156, 5158, ///
				5779, 5752, 5164, 5170, 5120, 5776, 5180, 5174, 5182, 5111, 5184, ///
				/* Non-EU western countries */ ///
				5124, 5502, 5314, 5105, 5106, 5107, 5109, 5514, 5110, 5159, ///
				6160, 5390, 5176, 5397, 5399, 5114 ,5132,5143,5186,5199 ///
				/* Czechoslovakia, Greenland and the Faore Islands */ ///
				5902, 5101, 5129) & ietype ==2 
la var westim "Western immigrant"
				/* EU countries */
gen westdec = inlist(ieland, 5126, 5128, 5422, 5607, 5104, 5130, 5134, ///
				5142, 5150, 5750, 5609, 5611, 5108, 5153, 5140, 5154, 5156, 5158, ///
				5779, 5752, 5164, 5170, 5120, 5776, 5180, 5174, 5182, 5111, 5184, ///
				/* Non-EU western countries */ ///
				5124, 5502, 5314, 5105, 5106, 5107, 5109, 5514, 5110, 5159, ///
				6160, 5390, 5176, 5397, 5399, ///
				/* Czechoslovakia, Greenland and the Faore Islands */ ///
				5902, 5101, 5129) & ietype ==3 
la var westdec "Western 2nd generation immigrant"
gen nwestim = (westim ==0 & ieland!=5100 & ietype==2) 
la var nwestim "Non-western immigrant"
gen nwestdec = (westdec==0 & ieland !=5100 & ietype ==3)
la var nwestdec "Non-western 2nd generation immigrant"

// Construct variable for those (with birth year 1986) completing 9th grade in a normal way 1 year earlier than the norm, i.e. in 2001. 
// For these observations, we do not have information on 9th grade test scores, and they should therefore be excluded from the final estimation sample
save temp, replace
keep if byear==1986
merge 1:m pnr using "$rawdata\kotre2018_old.dta", nogen keepusing(udd udel elev3_vfra elev3_vtil hf_kode) keep(master match)
sort pnr elev3_vfra
keep if inlist(udd,1009,1109,1115,1116,1209,2509,2516)
tab udel, mis
keep if udel==29
sort pnr elev3_vfra elev3_vtil
by pnr: keep if _n==_N
gen month=month(elev3_vtil)
gen year=year(elev3_vtil)
gen gr9early1986=month==6&year==2001
count if gr9early1986==1
keep pnr gr9early1986
save temp2, replace
use temp, replace
merge 1:1 pnr using temp2, nogen keep(master match)
replace gr9early1986=0 if gr9early1986==.
la var gr9early1986 "Completed grade 9 in 2001" 
count if gr9early1986==1
sum gr9early1986

gen     not_grade9marks = 1 if are_in_udfk==0
replace not_grade9marks = 0 if are_in_udfk==1
label var not_grade9marks "No grade 9 marks"
gen nogrades86 = b1986*not_grade9marks           // No marks are observed for early completers (at age 14) of the first cohort. Thus, the effect of no marks for this cohort may be very different than for later cohorts
label var nogrades86 "No marks and 1986 cohort"
label var grad_year "Year with grade 9 test scores (last)"
label var grad_age "Age grade 9 test scores"
label var old_grad "Age 17+ grade 9 test scores"
label var no_obl_proj13 "No marks, project report"

foreach x in danish_OW_co13 math_co13 english_co13 science_co13 danish_O_co13 danish_WS_co13 danish_WP_co13  danish_O_ex13 danish_WS_ex13 danish_WP_ex13 {
gen no_`x'=`x'==.
gen `x'_nm=`x'  // only non-missing values
replace `x'=6 if `x'==.
}
la var math_co13 "Math score by teacher" 
la var danish_OW_co13 "Danish score by teacher"
la var english_co13 "English score by teacher"
la var science_co13 "Science score by teacher"
la var math_co13_nm "Math score by teacher" 
la var danish_OW_co13_nm "Danish score by teacher"
la var english_co13_nm "English score by teacher"
la var science_co13_nm "Science score by teacher"
la var no_math_co13 "Math score by teacher missing" 
la var no_danish_OW_co13 "Danish score by teacher missing"
la var no_english_co13 "English score by teacher missing"
la var no_science_co13 "Science score by teacher missing"

la var danish_O_co13_nm "Reading score by teacher"
la var danish_WP_co13_nm "Essay score by teacher"
la var danish_WS_co13_nm "Spelling score by teacher"
la var danish_O_co13 "Reading score by teacher"
la var danish_WP_co13 "Essay score by teacher"
la var danish_WS_co13 "Spelling score by teacher"

la var danish_O_ex13_nm "Test score reading"
la var danish_WP_ex13_nm "Test score essay"
la var danish_WS_ex13_nm "Test score spelling"
la var danish_O_ex13 "Test score reading"
la var danish_WP_ex13 "Test score essay"
la var danish_WS_ex13 "Test score spelling"

la var no_danish_O_co13 "Reading score by teacher missing"
la var no_danish_WP_co13 "Essay score by teacher missing"
la var no_danish_WS_co13 "Spelling score by teacher missing"
la var no_danish_O_ex13 "Test score reading missing"
la var no_danish_WP_ex13 "Test score essay missing"
la var no_danish_WS_ex13 "Test score spelling missing"

// Test scores which only have values if they are non-missing
gen no_math_ex13=no_exam_mat13
gen no_danish_OW_ex13=no_exam_dan13
foreach x in  math_ex13 danish_OW_ex13 english_ex13 science_ex13 obl_proj13 {
gen `x'_nm=`x' if no_`x'==0
}
la var math_ex13_nm "Test score math" 
la var danish_OW_ex13_nm "Test score Danish"
la var english_ex13_nm "Test score English"
la var science_ex13_nm "Test score science"
la var obl_proj13_nm "Test score project report"
la var math_ex13 "Test score math" 
la var danish_OW_ex13 "Test score Danish"
la var english_ex13 "Test score English"
la var science_ex13 "Test score science"
la var obl_proj13 "Test score project report"

egen matmean=rowmean(math_ex13      math_co13)
egen danmean=rowmean(danish_OW_ex13 danish_OW_co13)
tab1 matmean danmean, mis


// Income (in a given year) is defined as missing for individuals who are not living in Denmark in the beginning and end of the year. This is not important for estimation results.
foreach x in inderh indper{
forval  t=25/28{
local t1=`t'+1
replace `x'`t'=. if hfyrs`t'==. | hfyrs`t1'==.
}
} 
foreach x in inddis{
forval  t=25/27{
local t1=`t'+1
replace `x'`t'=. if hfyrs`t'==. | hfyrs`t1'==.
}
} 

label var missuddanym "Mother, no education info."
label var missuddanyf "Father, no education info."
label var norasm "Mother, no info. on labor market status"
label var norasf "Father, no info. on labor market status"
label var firstborn "First-born"
label var siblings "Number of full siblings"
label var borhjemme14 "Live with parent(s), age 14"
label var parrentborsam14 "Parents live together, age 14"
label var nokomb14 "Child not in population, age 14"
label var nokomm14 "Mother not in population, age 14"
label var nokomf14 "Father not in population, age 14"
label var misfather "No father ID"
label var mismother "No mother ID"
label var b1986 "Birth year 1986"
label var b1987 "Birth year 1987"
label var b1988 "Birth year 1988"
label var male "Male"
label var westim "Western immigrant"
label var westdec "Western 2nd generation immigrant"
label var nwestim "Non-Western immigrant"
label var nwestdec "Non-Western 2nd generation immigrant"
label var missincomem "Missing income, mother"
label var missincomef "Missing income, father"
la var no_exam_mat13 "No test score in math"
la var no_exam_dan13 "No test score in Danish"
la var no_english_ex13 "No test score in English"
la var no_science_ex13 "No test score in science"
la var no_obl_proj13 "No test score, project report"
la var not_grade9marks "No 9th grade test scores"
la var nogrades86 "No test scores and birth year 1986"

// Keep only birth year cohorts 1986,...,1989. 
keep if inrange(byear,1986,1989)  // Is already implemented in A1_data.do file

forval a=25/30{
rename udsattenetto`a' NEET`a'
}

gen inpop17_24=inpop17+inpop18+inpop19+inpop20+inpop21+inpop22+inpop23+inpop24 
la var inpop17_24 "No of years in population age 17-24 (max=8)"
tab inpop17_24, mis

gen erhv = firstudda==30 | firstudda==35  // elever der starter direkte på hovedforløb (35) på erhvervsuddannelser medtages i estimationer - og sidestilles med dem der starter på introforløb (30)
gen nostart=firstudda==.
gen start=firstudda!=.
sum gymn erhv nostart
la var gymn "Started academic secondary edu."
la var erhv "Started vocational secondary edu."
la var nostart "Did not enrol in secondary edu."
la var start "Started upper sec. edu."

gen gymncomp=inlist(firstuddafinish,20,25)
gen erhvcomp=inlist(firstuddafinish,35)
gen nocomplete=firstuddafinish==.
gen complete=firstuddafinish!=.
la var gymncomp "Completed academic secondary edu."
la var erhvcomp "Completed vocational secondary edu."
la var nocomplete "No completed secondary edu."
la var complete "Completed upper sec. edu."

gen uddcat=.
replace uddcat=1 if firstuddafinish==20 | firstuddafinish==25  // completed academic upper seconcary by age 25
replace uddcat=2 if firstuddafinish==35                        // completed vocational upper secondary by age 25
replace uddcat=3 if uddcat!=1 & uddcat!=2 & (firstudda==20 | firstudda==25)  // No completed upper secondary education, but had been enrolled in academic upper secondary program
replace uddcat=4 if uddcat!=1 & uddcat!=2 & (firstudda==30 | firstudda==35)  // No completed upper secondary education, but had been enrolled in vocational upper secondary program
replace uddcat=5 if uddcat==.                                                // No completed or started upper secondary education
label define uddcatlab 1 "Gen." 2 "Voc." 3 "Gen.st." 4 "Voc.st." 5 "Not_st."
label values uddcat uddcatlab
gen uddcat2=.
replace uddcat2=1 if  (firstudda==20 | firstudda==25)  // Enrolled in academic upper secondary program
replace uddcat2=2 if  (firstudda==30 | firstudda==35)  // Enrolled in vocational upper secondary program
replace uddcat2=3 if uddcat2==.                        // Did not enrol in any upper secondary education
label define uddcat2lab 1 "Gen." 2 "Voc." 3 "Not_st."
label values uddcat2 uddcat2lab
gen uddcat3=.
replace uddcat3=1 if firstuddafinish==20 | firstuddafinish==25  // completed academic upper seconcary by age 25
replace uddcat3=2 if firstuddafinish==35                        // completed vocational upper secondary by age 25
replace uddcat3=3 if uddcat3==.
label define uddcat3lab 1 "Gen." 2 "Voc." 3 "Nocom." 
label values uddcat3 uddcat3lab
gen uddcat2e=.
replace uddcat2e=1 if  (firstudda==20 | firstudda==25) & male==1  // Enrolled in academic upper secondary program
replace uddcat2e=2 if  (firstudda==30 | firstudda==35) & male==1  // Enrolled in vocational upper secondary program
replace uddcat2e=3 if uddcat2e==.                      & male==1  // Did not enrol in any upper secondary education
replace uddcat2e=4 if  (firstudda==20 | firstudda==25) & male==0  // Enrolled in academic upper secondary program
replace uddcat2e=5 if  (firstudda==30 | firstudda==35) & male==0  // Enrolled in vocational upper secondary program
replace uddcat2e=6 if uddcat2e==.                      & male==0  // Did not enrol in any upper secondary education
label define uddcat2elab 1 "MGen" 2 "MVoc" 3 "MNost" 4 "FGen" 5 "FVoc" 6 "FNost"
label values uddcat2e uddcat2elab
gen uddcat3e=.
replace uddcat3e=1 if  (firstuddafinish==20 | firstuddafinish==25) & male==1  // Completed academic upper secondary program
replace uddcat3e=2 if  (firstuddafinish==35)                       & male==1  // Completed vocational upper secondary program
replace uddcat3e=3 if uddcat3e==.                                  & male==1  // Did not complete in any upper secondary education
replace uddcat3e=4 if  (firstuddafinish==20 | firstuddafinish==25) & male==0  // Completed academic upper secondary program
replace uddcat3e=5 if  (firstuddafinish==35)                       & male==0  // Completed vocational upper secondary program
replace uddcat3e=6 if uddcat3e==.                                  & male==0  // Did not complete any upper secondary education
label define uddcat3elab 1 "MGen" 2 "MVoc" 3 "MNocom" 4 "FGen" 5 "FVoc" 6 "FNocom"
label values uddcat3e uddcat3elab

foreach x in erh per dis{
forval a=25/30{
replace ind`x'`a'=ind`x'`a'/1000   // income in 1000 DKK
}
}
replace inderh31=inderh31/1000   // earnings and gross income are updated an extra year compared to disposable income
replace indper31=indper31/1000

// trim income
foreach x in erh per dis{
forval a=25/30{
gen tind`x'`a'=ind`x'`a'
replace tind`x'`a'=. if ind`x'`a'<0 | ind`x'`a'>1000   // drop obs when income is negtive or above 1m DKK
}
}
gen tinderh31=inderh31
replace tinderh31=. if inderh31<0 | inderh31>1000   // earnings and gross income are updated an extra year compared to disposable income
gen tindper31=indper31
replace tindper31=. if indper31<0 | indper31>1000   // earnings and gross income are updated an extra year compared to disposable income
replace indper31=indper31/1000
sum inderh28 tinderh28 indper28 tindper28 inddis27 tinddis27 

// Municipalities - conversion of old codes to new codes
sum adresse1kom
save temp, replace
keep if gradyear<=2006
keep pnr adresse1kom adresse1opgikom
rename adresse1kom kom
rename adresse1opgikom opgikom
sum 
merge m:1 kom opgikom using "$rawdata/nogf2013", nogen keepusing(kom_ny) keep(master match)
sum   // kom_ny is missing for 83 obs. for which we have non-missing kom. Probably their address is missing in the conversion file nogf2013 because they live in a new building in gradyear.
save temp2, replace
use temp, clear
merge 1:1 pnr using temp2, nogen keep(master match) keepusing(kom_ny) 
replace kom_ny=adresse1kom if gradyear>2006 & gradyear!=.
tab kom_ny if adresse1kom!=. /*if kom_ny!=.*/, g(komny) mis  // we generate an 'artificial' komny municipality for which kom_ny is missing and adresse1kom is non-missing (containing 83 obs.)
sum adresse1kom kom_ny komny* // check nobs

// Factor variables
gen     ethnic=0
replace ethnic=1 if westim==1
replace ethnic=2 if westdec==1
replace ethnic=3 if nwestim==1
replace ethnic=4 if nwestdec==1
la define ethniclab 0 "Danish origin" 1 "Western immigrant" 2 "Western descendant" 3 "Non-Western immigrant" 4 "Non-Western descendant"
la values ethnic ethniclab
gen     edum=0
replace edum=1 if fagm==1
replace edum=2 if kvum==1
replace edum=3 if mvum==1
replace edum=4 if lvum==1
la define edumlab 0 "Compulsory edu. mother" 1 "Vocational edu. mother" 2 "Short further edu. mother" 3 "Further edu. mother" 4 "Higher edu. mother"
la values edum edumlab
gen     eduf=0
replace eduf=1 if fagf==1
replace eduf=2 if kvuf==1
replace eduf=3 if mvuf==1
replace eduf=4 if lvuf==1
la define eduflab 0 "Compulsory edu. father" 1 "Vocational edu. father" 2 "Short further edu. father" 3 "Further edu. father" 4 "Higher edu. father"
la values eduf eduflab
gen numsib=siblings
replace numsib=3 if siblings>=3
la define siblab 0 "Only child" 1 "1 sibling" 2 "2 siblings" 3 "3+ siblings"
la values numsib siblab
// firstborn
gen     statusm=0
replace statusm=1 if selfempm==1
replace statusm=2 if unempm==1
replace statusm=3 if penm==1
replace statusm=4 if othm==1
la define statusmlab 0 "Mother worker" 1 "Mother self-employed" 2 "Mother unemployed" 3 "Mother disability pension" 4 "Mother not in work force (other)"
la values statusm statusmlab
gen     statusf=0
replace statusf=1 if selfempf==1
replace statusf=2 if unempf==1
replace statusf=3 if penf==1
replace statusf=4 if othf==1
la define statusflab 0 "Father worker" 1 "Father self-employed" 2 "Father unemployed" 3 "Father disability pension" 4 "Father not in work force (other)"
la values statusf statusflab


save prep1, replace



