*** This programme calculates predicted earnings at age 40 based on educational attainment and other intermediate outcomes by age 28-31 and pre-treatment covariates. 
*** We use the surrogate index techniques suggested by Athey et al. (2019). Thus, we use data for older cohorts to estimate a model of earnings at age 40, 
*** and we use the estimates to predict earnings at age 40 for the individuals in our main sample.

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
local dstformat "\\srvfsenas1\data\Formater\SAS formater i Danmarks Statistik\STATA_datasaet\Disced\"
set more off 
cd "$data"
set matsize 2000
clear
	
****************************************************
** Format for education variables (Danish version of ISCED)
	use "`dstformat'n_audd2019_hoved_l1l3_k.dta", clear    // Detailed education categories
		rename start hfaudd
		rename AUDD2019_HOVED_L1L3_K hf_disced	
		gen hf_disced2=substr(hf_disced,1,2)
		destring hf_disced hf_disced2, replace force
	save audd_2019, replace
	
	use "`dstformat'n_audd2019_hoved_l1l3_t.dta", clear    // Text variable for labels
		rename start hfaudd
		rename AUDD2019_HOVED_L1L3_T hf_text	
	save audd_2019_text, replace
	
	use "`dstformat'n_udd_hoved_l1l3_k.dta", clear
		rename start udd
		rename UDD_HOVED_L1L3_K udd_disced	
		gen udd_disced2=substr(udd_disced,1,2)
		destring udd_disced udd_disced2, replace force
	save udd_2019, replace
***********************************************
clear  // Necessary because of save command below

** Old cohorts
** education status, earnings and labor market status at age 25-31, and earnings at age 40. 
forval a=25/31{
save append`a', replace emptyok
}
forval a=25/31{
forval t=1997/2009{    // 1996 is first year where RAS includes the socstil_kode variable, and RAS<t-1> is merged on BEF<t> and UDDA<t> below
di `t'
use "$rawdata\bef`t'.dta", clear 
keep if alder==`a'
gen byear=`t'-`a'-1  // Age is recorded at the beginning of year t 
gen male=koen==1
keep pnr byear male
local t1 = `t'+1
local a1 = `a'+1
merge 1:1 pnr using  "$rawdata_udda\udda`t1'.dta", keep(match) keepusing(hfaudd) nogen // education status age a (end of year or age a+1 beginning of year)
merge m:1 hfaudd using audd_2019
keep if _merge==3
drop _merge
merge m:1 hfaudd using audd_2019_text, keep(master match) nogen
rename hf_text hf_text`a1'
rename hf_disced2 hfmain`a1'
label var    hfmain`a1'  "Highest completed education, main groups"
label define hf_label 	10 "Lower secondary" 15 "Prepare for upper secondary" 20 "General upper secondary" 29 "Vocational (1st year)" ///
						30 "Vocational (main program)"  39 "Further training (vocational)" 40 "Short further" 50 "Long further" 60 "University BA" 70 "MA" 80 "PhD" ///
					  	90 "Not known" 
label values hfmain`a1' hf_label	
replace hfmain=70 if hfmain==80 
replace hfmain`a1'=10 if inlist(hfmain`a1',15,29,90) 
replace hfmain`a1'=30 if hfmain`a1'==35
tab hfmain`a1', missing
rename hfaudd hfaudd`a1'
keep if hf_disced!=.      // hf_disced corresponds to hfaudd except that values are the fsp/disced format 
rename hf_disced hfd`a1'
tostring hfd`a1', replace
replace hfd`a1'="70"+substr(hfd`a1',3,.) if substr(hfd`a1',1,2)=="60"  // Changes bachelor to master level since bachelor level codes have been introduced gradually over time
replace hfd`a1'="70"+substr(hfd`a1',3,.) if substr(hfd`a1',1,2)=="80"  // Changes ph.d. to master level due to few observations at ph.d. level
destring hfd`a1', replace
merge 1:1 pnr using  "$rawdata\ind`t'.dta", keep(match) keepusing(erhvervsindk_13) nogen // earnings age a
rename erhvervsindk_13 earn`a'
gen year`a'=`t'	
save temp, replace

local t_1 = `t'-1   // RAS<t> contains status end of t for pop beginning of t+1. Thus, we merge RAS<t-1> on BEF<t> and UDDA<t>
use "$rawdata\ras`t_1'", clear
if `t_1'>=2008{
keep if pri == 1
keep pnr soc_status_kode
}
if `t_1'<=2007{
keep if novprio==1
keep pnr socstil_kode
}
drop if pnr == .
merge 1:1 pnr using temp, keep(match) nogen 
gen ras = .
if `t_1' >= 2008{
replace ras = soc_status_kode if soc_status_kode !=.
}
if `t_1' <= 2007{
replace ras = socstil if socstil !=.
}
gen     neeb`a' = [inrange(ras,200,201) | inrange(ras,315,336)] & `t_1' <= 2007    // Not in employment or education, gross (brutto), at age `a' (primo)
replace neeb`a' = 1 if [inrange(ras,200,415) | ras == 513]      & `t_1' >= 2008
gen     edu`a' = ras==310                               & `t_1' <= 2007            // In education
replace edu`a' = 1 if [ras==511 | inrange(ras,514,517)] & `t_1' >= 2008
gen     eeb`a'=1-neeb`a'                                                            // Employed or in education
gen     emp`a' = eeb`a'-edu`a'                                                       // Employed
gen status`a'=.
replace status`a'=1 if emp`a'==1
replace status`a'=2 if edu`a'==1
replace status`a'=3 if emp`a'==0 & edu`a'==0
label variable status`a'  "Labour market status age `a'"
label define stat_label  1 "Employed" 2 "Student" 3 "Inactive" 
label values status`a' stat_label	
drop neeb`a' edu`a' eeb`a' emp`a' ras       
cap drop soc_status_kode 
cap drop socstil_kode

// Municipality age 15
local s = `t'-`a'-1 + 16  // `t'-`a'-1=byear and byear+16 is year where the person turns 16, i.e. the typical year of completing compulsory school
merge 1:1 pnr using "$rawdata\fain`s'.dta", keep(master match) keepusing(kom kom_ny) nogen
replace kom=400 if inlist(kom,401,403,405,407,409,411) // Bornholm
replace kom=492 if inlist(kom,493,443)                 // Ærø from 2006; before Ærøskøbing and Marstal

append using append`a'
save append`a', replace
}  // t
}  // a

//Parental characteristics at age 13-14 (byear+14)
forval a=28/31{
clear
save temp`a', replace emptyok
}
forval a=28/31{
forval t=1997/2009{    // NB: 2 cohorts less than above (1999) because parental education is measured at child age 13 (byear+14) and udda register begins in 1981
di `t'
use "$rawdata\bef`t'.dta", clear 
keep if alder==`a'
gen byear=`t'-`a'-1  // Age is recorded at the beginning of year t (primo)
destring pnrm pnrf, replace force
keep pnr byear pnrm pnrf

local p = `t'-`a'-1 + 16  // `t'-`a'-1=byear and byear+14 is year where the person turns 14 (age 13 beginning of year)
                          //  t=1999, a=31 => p=1981 (first year of udda register). However, we can use data for cohorts age 28 in t=1997 and 1998:
						  //  We use +16 since education status of parents does in practice not change much at this age, and we can then obtain parental education for all 10 cohorts
if `t'==1997 & `a'==31{
local s = `t'-`a'-1 + 15  //  local s is used for income register
}
else{
local s = `t'-`a'-1 + 14
}
gen year14=`s'            // year where parental income is measured 
						  
// Mother characterisics
rename pnr pnrb
rename pnrm pnr
merge m:1 pnr using  "$rawdata_udda\udda`p'.dta", keep(master match) keepusing(hf_kode) nogen // education
gen hf_mism = hf_kode==.
gen hf=hf_kode/10
gen ufagm= ((0.0<=hf&hf<2.0)|(3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0)| hf==.)
gen fagm = (3.5<=hf&hf<4)
gen kvum =(4.0<=hf&hf<5.0) | (2.0<=hf&hf<3.0) //kvu eller gym
gen mvum =(5.0<=hf&hf<6.5)
gen lvum = (6.5 <=hf & hf <8.0)
gen hfm=.
replace hfm=1 if ufagm==1
replace hfm=2 if fagm==1
replace hfm=3 if kvum==1
replace hfm=4 if mvum==1
replace hfm=5 if lvum==1
drop hf hf_kode ufagm fagm kvum mvum lvum
merge m:1 pnr using  "$rawdata\ind`s'.dta", keep(master match) keepusing(erhvervsindk_gl perindkialt) nogen // income
rename erhvervsindk_gl earningsm
rename perindkialt incomem
gen incmism = incomem==.   // mother not in income register ind

// Father characterisics
rename pnr pnrm
rename pnrf pnr
merge m:1 pnr using  "$rawdata_udda\udda`p'.dta", keep(master match) keepusing(hf_kode) nogen // education
gen hf_misf = hf_kode==.
gen hf=hf_kode/10
gen ufagm= ((0.0<=hf&hf<2.0)|(3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0)| hf==.)
gen fagm = (3.5<=hf&hf<4)
gen kvum =(4.0<=hf&hf<5.0) | (2.0<=hf&hf<3.0) //kvu eller gym
gen mvum =(5.0<=hf&hf<6.5)
gen lvum = (6.5 <=hf & hf <8.0)
gen hff=.
replace hff=1 if ufagm==1
replace hff=2 if fagm==1
replace hff=3 if kvum==1
replace hff=4 if mvum==1
replace hff=5 if lvum==1
drop hf hf_kode ufagm fagm kvum mvum lvum
merge m:1 pnr using  "$rawdata\ind`s'.dta", keep(master match) keepusing(erhvervsindk_gl perindkialt) nogen  // income
rename erhvervsindk_gl earningsf
rename perindkialt incomef
gen incmisf = incomef==.   // father not in income register ind

rename pnr pnrf
rename pnrb pnr

append using temp`a'
save temp`a', replace
}  // t
}  // a

use append25, clear
forval a=26/31{
merge 1:1 pnr using append`a'
drop _merge
}
forval a=28/31{
merge 1:1 pnr using temp`a', keep(master match) nogen
}
sum
gen earn40=.
gen year40=.
forval t=2009/2018{
merge 1:1 pnr using  "$rawdata\ind`t'", keep(master match) keepusing(erhvervsindk_13) nogen
replace earn40=erhvervsindk_13 if `t'==byear+40+1   // earnings age 40
replace year40=`t'             if `t'==byear+40+1   // The calender year in which earnings are measured
drop erhvervsindk_13
}
*generate variables for Consumer Price Index (Statistics Denmark) in the years of e.g. age 28 and 40
foreach a in 25 26 27 28 29 30 31 40 14{                  // CPI in years of child ages
gen     cpi`a' = 45.6 if year`a' == 1980
replace cpi`a' = 51.0 if year`a' == 1981 
replace cpi`a' = 56.1 if year`a' == 1982  
replace cpi`a' = 60.0 if year`a' == 1983  
replace cpi`a' = 63.8 if year`a' == 1984  
replace cpi`a' = 66.7 if year`a' == 1985  
replace cpi`a' = 69.2 if year`a' == 1986  
replace cpi`a' = 72.0 if year`a' == 1987  
replace cpi`a' = 75.3 if year`a' == 1988  
replace cpi`a' = 78.9 if year`a' == 1989  
replace cpi`a' = 80.9 if year`a' == 1990  
replace cpi`a' = 82.9 if year`a' == 1991  
replace cpi`a' = 84.6 if year`a' == 1992  
replace cpi`a' = 85.7 if year`a' == 1993  
replace cpi`a' = 87.4 if year`a' == 1994  
replace cpi`a' = 89.2 if year`a' == 1995  
replace cpi`a' = 91.1 if year`a' == 1996  
replace cpi`a' = 93.1 if year`a' == 1997  
replace cpi`a' = 94.8 if year`a' == 1998  
replace cpi`a' = 97.2 if year`a' == 1999  
replace cpi`a' = 100.0 if year`a' == 2000  
replace cpi`a' = 102.4 if year`a' == 2001  
replace cpi`a' = 104.8 if year`a' == 2002  
replace cpi`a' = 107.0 if year`a' == 2003  
replace cpi`a' = 108.3 if year`a' == 2004  
replace cpi`a' = 110.2 if year`a' == 2005  
replace cpi`a' = 112.3 if year`a' == 2006  
replace cpi`a' = 114.2 if year`a' == 2007  
replace cpi`a' = 118.1 if year`a' == 2008  
replace cpi`a' = 119.7 if year`a' == 2009  
replace cpi`a' = 122.4 if year`a' == 2010
replace cpi`a' = 125.8 if year`a' == 2011  
replace cpi`a' = 128.8 if year`a' == 2012  
replace cpi`a' = 129.9 if year`a' == 2013
replace cpi`a' = 130.6 if year`a' == 2014
replace cpi`a' = 100*100.0/76.2 if year`a' == 2015  // CPI with value 100 in 2015, and 76.2 in 2000
replace cpi`a' = 100*100.3/76.2 if year`a' == 2016
replace cpi`a' = 100*101.4/76.2 if year`a' == 2017
replace cpi`a' = 100*102.2/76.2 if year`a' == 2018
*converts all prices to 2015 prices
gen cpi`a'_2015 = (cpi`a'/100)/(100/76.2)       // 2015=1 (not 100)
sort year`a'
table year`a', c(mean cpi`a' mean cpi`a'_2015)
}

*converts earnings to 2015 prices, and to 1000 DKK instead of DKK
foreach a in 25 26 27 28 29 30 31 40{
replace earn`a'=earn`a'/(cpi`a'_2015*1000)
sum earn`a', d
replace earn`a'=. if (earn`a'<0 | earn`a'>2500) & `a'==40   // drop obs when earnings at age 40    are negative or above 2.5m DKK
replace earn`a'=. if (earn`a'<0 | earn`a'>1000) & `a'<40    // drop obs when earnings at age 25-31 are negative or above 1m DKK
gen     ecat`a'=.                               // categories of earnings to take account of zero or very low earnings
replace ecat`a'=0 if     earn`a'==0	
replace ecat`a'=1 if   0<earn`a'&earn`a'<=100
replace ecat`a'=2 if 100<earn`a'&earn`a'!=.
}
foreach p in m f{
foreach y in earnings income{
replace `y'`p'=`y'`p'/(cpi14_2015*1000000)  // NB: parental income and earnings are in m DKK
replace `y'`p'=.2   if `y'`p'==.
replace `y'`p'=0    if `y'`p'<0             // income below zero  is set to zero
replace `y'`p'=2.5  if `y'`p'>2.5           // income above 2.5 m is set to 2.5 m
}
}
table hfd29, contents(n earn28 mean earn28 n earn40 mean earn40)  
drop cpi*
save tempold, replace
sum earn* income*

// GPA from general upper secondary school (for those for whom this variable exists)
use "$rawdata\udg2016", clear
destring pnr, force replace
keep if pnr!=.
save tempudg, replace
use tempold, clear
merge 1:m pnr using tempudg, keep(master match) keepusing(audd karakter_udd karakter_udd_vtil skala) nogen
gen yearaudd = year(karakter_udd_vtil)
rename audd hfaudd
merge m:1 hfaudd using audd_2019, keep(master match) keepusing(hf_disced hf_disced2) nogen
merge m:1 hfaudd using audd_2019_text, keep(master match) nogen
rename hfaudd audd
rename hf_disced audd_d
rename hf_disced2 audd_d2
rename hf_text audd_text
tab audd_d2 if karakter_udd!=.    // only grades from general upper secondary school (audd_d2=20) can be used
tab skala if audd_d2==20, mis
sort audd_d2
table audd_d2 if karakter_udd!=., c(mean yearaudd min yearaudd max yearaudd mean skala mean karakter_udd)
tab yearaudd, mis
tab yearaudd if karakter_udd!=., mis
bys audd_d2: tab yearaudd
bys audd_d2: tab yearaudd if karakter_udd!=.
duplicates report pnr if audd_d2==20
duplicates tag    pnr if audd_d2==20, gen(numdup)
tab numdup
keep if audd_d2==20    // only keep observations for test scores in general upper secondary school (gymnasium)
bys pnr (yearaudd): keep if _n==1  // keep first general upper secondary exam in case of more than one
duplicates report pnr   // check
rename karakter_udd k
gen     k7 = k  if skala==7                     // We convert from old (13) to new (7) grading scale using www.optagelse.dk/vejledninger/pdf/Fra-13-skalaen-til-7.pdf
replace k7 = 20 if skala==13 & (k==60 | k==61)  // Except that we do not allow new grades above 12.
replace k7 = 21 if skala==13 &  k==62           
replace k7 = 23 if skala==13 &  k==63 
replace k7 = 25 if skala==13 &  k==64 
replace k7 = 27 if skala==13 &  k==65 
replace k7 = 29 if skala==13 &  k==66 
replace k7 = 31 if skala==13 &  k==67 
replace k7 = 33 if skala==13 &  k==68 
replace k7 = 35 if skala==13 &  k==69 
replace k7 = 37 if skala==13 &  k==70 
replace k7 = 40 if skala==13 &  k==71 
replace k7 = 42 if skala==13 &  k==72 
replace k7 = 44 if skala==13 &  k==73 
replace k7 = 47 if skala==13 &  k==74 
replace k7 = 49 if skala==13 &  k==75 
replace k7 = 52 if skala==13 &  k==76 
replace k7 = 54 if skala==13 &  k==77 
replace k7 = 57 if skala==13 &  k==78 
replace k7 = 59 if skala==13 &  k==79 
replace k7 = 62 if skala==13 &  k==80 
replace k7 = 65 if skala==13 &  k==81 
replace k7 = 68 if skala==13 &  k==82 
replace k7 = 70 if skala==13 &  k==83 
replace k7 = 73 if skala==13 &  k==84 
replace k7 = 76 if skala==13 &  k==85 
replace k7 = 79 if skala==13 &  k==86 
replace k7 = 81 if skala==13 &  k==87 
replace k7 = 84 if skala==13 &  k==88 
replace k7 = 87 if skala==13 &  k==89 
replace k7 = 89 if skala==13 &  k==90 
replace k7 = 92 if skala==13 &  k==91 
replace k7 = 94 if skala==13 &  k==92 
replace k7 = 97 if skala==13 &  k==93 
replace k7 = 99 if skala==13 &  k==94 
replace k7 = 101 if skala==13 &  k==95 
replace k7 = 104 if skala==13 &  k==96 
replace k7 = 106 if skala==13 &  k==97 
replace k7 = 108 if skala==13 &  k==98 
replace k7 = 110 if skala==13 &  k==99 
replace k7 = 112 if skala==13 &  k==100
replace k7 = 113 if skala==13 &  k==101
replace k7 = 115 if skala==13 &  k==102
replace k7 = 116 if skala==13 &  k==103
replace k7 = 117 if skala==13 &  k==104
replace k7 = 118 if skala==13 &  k==105
replace k7 = 120 if skala==13 &  106<=k&k<=130
gr twoway scatter k7 k if skala==13  // check
sum k k7 if skala==13
sum k k7
keep pnr k7 
keep if k7!=.
label var k7 "GPA gymnasium"
save tempold_gpagym, replace
use tempold, clear
merge 1:1 pnr using tempold_gpagym, keep(master match) nogen
gen misk=k7==.
replace k7=68 if k7==.  // 68 is the mean of k7
forval a=29/32{
gen hfq`a'=.
replace hfq`a'=1 if hfmain`a'==20 | inrange(hfmain`a',40,80)   // further edu. or general upper sec.
replace hfq`a'=2 if hfmain`a'==30                              // vocational edu.
replace hfq`a'=3 if hfmain`a'==10                              // no edu. beyond compulsory
tab hfmain`a' hfq`a', mis
bys hfq`a': sum misk k7   				// GPA is missing for some with hfq`a'=1 since it is missing for hhx and htx before 1999.
bys hfq`a': sum      k7 if misk==0      // And because admission to some post-secondary educations is possible without a general upper sec. edu.                       
}										// GPA is non-missing for about 10% with voc.edu. since they have also completed a general upper sec. edu.
save tempold, replace


// Explanatory variables for main sample of analysis
// Keep all control variables from main analysis - can be used when predicting earn28 using main sample only
use "$data/prep1", clear  
cap drop sample
gen sample = gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=.  // 230,369
keep if sample==1  
keep pnr male byear tinderh* eeb* edu* hfaudd* kom_ny erhv erhvcomp start complete afst1_30_average_w afst1_2025_average_w ///
     ufagm fagm kvum mvum lvum ufagf fagf kvuf mvuf lvuf incomem incomef busincm busincf incmism hf_mism incmisf hf_misf ///
     ethnic numsib firstborn separation14 notwithparents14 nokomb14 nokomm14 nokomf14 mismother misfather edum eduf statusm statusf nosociom nosociof  ///
     lincomem lincomef  crimem crimef detentionf violencef2 ///
	 math_ex13 danish_OW_ex13 english_ex13 science_ex13  math_co13 danish_OW_co13 english_co13 science_co13  obl_proj13  ///
	 no_exam_mat13 no_exam_dan13 no_english_ex13 no_science_ex13 no_english_co13 no_science_co13 no_obl_proj13 old_grad not_grade9marks nogrades86    
	 
global all_factor_exmale i.ethnic i.numsib i.firstborn i.separation14 i.notwithparents14 i.nokomb14 i.nokomm14 i.nokomf14 i.mismother i.misfather i.edum i.eduf i.statusm i.statusf i.nosociom i.nosociof  ///
                         c.lincomem c.lincomef  i.crimem i.crimef i.detentionf i.violencef2 ///
						 c.math_ex13 c.danish_OW_ex13 c.english_ex13 c.science_ex13  c.math_co13 c.danish_OW_co13 c.english_co13 c.science_co13  c.obl_proj13  ///
					     i.no_exam_mat13 i.no_exam_dan13 i.no_english_ex13 i.no_science_ex13 i.no_english_co13 i.no_science_co13 i.no_obl_proj13 i.old_grad i.not_grade9marks i.nogrades86    

forval a=26/32{
di "`a'"
rename hfaudd`a' hfaudd
merge m:1 hfaudd using audd_2019, keep(master match) nogen
merge m:1 hfaudd using audd_2019_text, keep(master match) nogen
rename hfaudd hfaudd`a'
rename hf_text hf_text`a'
rename hf_disced2 hfmain`a'
replace hfmain`a'=70 if hfmain`a'==80 
replace hfmain`a'=10 if inlist(hfmain`a',15,29,90) 
replace hfmain`a'=30 if hfmain`a'==35
tostring hf_disced, replace
replace hf_disced="70"+substr(hf_disced,3,.) if substr(hf_disced,1,2)=="60"  // Changes bachelor to master level since bachelor level codes have been introduced gradually over time
replace hf_disced="70"+substr(hf_disced,3,.) if substr(hf_disced,1,2)=="80"  // Changes ph.d. to master level due to few observations at ph.d. level
destring hf_disced, replace
rename hf_disced hfd`a'
}
label define stat_label  1 "Employed" 2 "Student" 3 "Inactive" 
forval a=25/31{
gen     emp`a' = eeb`a'-edu`a'                                                       // Employed
gen status`a'=.
replace status`a'=1 if emp`a'==1
replace status`a'=2 if edu`a'==1
replace status`a'=3 if emp`a'==0 & edu`a'==0
label variable status`a'  "Labour market status age `a'"
label values status`a' stat_label
rename tinderh`a' earn`a'
gen     ecat`a'=.                               // categories of earnings to take account of zero or very low earnings
replace ecat`a'=0 if     earn`a'==0	
replace ecat`a'=1 if   0<earn`a'&earn`a'<=100
replace ecat`a'=2 if 100<earn`a'&earn`a'!=.
}
drop edu2* eeb2* emp2* edu3* eeb3* emp3* 
foreach p in m f{
gen hf`p'=.
replace hf`p'=1 if ufag`p'==1
replace hf`p'=2 if fag`p'==1
replace hf`p'=3 if kvu`p'==1
replace hf`p'=4 if mvu`p'==1
replace hf`p'=5 if lvu`p'==1
drop ufag`p' fag`p' kvu`p' mvu`p' lvu`p'
replace hf_mis`p'=0 if hf_mis`p'==.
rename businc`p' earnings`p'
foreach y in earnings income{
replace `y'`p'=.2   if `y'`p'==.
replace `y'`p'=0    if `y'`p'<0             // income below zero  is set to zero
replace `y'`p'=2.5  if `y'`p'>2.5           // income above 2.5 m is set to 2.5 m
}
}
save tempmain, replace                                    

// GPA from general upper secondary school (for those for whom this variable exists)
use tempmain, clear
merge 1:m pnr using tempudg, keep(master match) keepusing(audd karakter_udd karakter_udd_vtil skala) nogen
gen yearaudd = year(karakter_udd_vtil)
rename audd hfaudd
merge m:1 hfaudd using audd_2019, keep(master match) keepusing(hf_disced hf_disced2) nogen
merge m:1 hfaudd using audd_2019_text, keep(master match) nogen
rename hfaudd audd
rename hf_disced audd_d
rename hf_disced2 audd_d2
rename hf_text audd_text
tab audd_d2 if karakter_udd!=.    // only grades from general upper secondary school (audd_d2=20) can be used
tab skala if audd_d2==20, mis
sort audd_d2
table audd_d2 if karakter_udd!=., c(mean yearaudd min yearaudd max yearaudd mean skala mean karakter_udd)
tab yearaudd, mis
tab yearaudd if karakter_udd!=., mis
bys audd_d2: tab yearaudd
bys audd_d2: tab yearaudd if karakter_udd!=.
duplicates report pnr if audd_d2==20
duplicates tag    pnr if audd_d2==20, gen(numdup)
tab numdup
keep if audd_d2==20    // only keep observations for test scores in general upper secondary school (gymnasium)
bys pnr (yearaudd): keep if _n==1  // keep first general upper secondary exam in case of more than one
duplicates report pnr   // check
rename karakter_udd k
gen     k7 = k  if skala==7                     // We convert from old (13) to new (7) grading scale using www.optagelse.dk/vejledninger/pdf/Fra-13-skalaen-til-7.pdf
replace k7 = 20 if skala==13 & (k==60 | k==61)  // Except that we do not allow new grades above 12.
replace k7 = 21 if skala==13 &  k==62           
replace k7 = 23 if skala==13 &  k==63 
replace k7 = 25 if skala==13 &  k==64 
replace k7 = 27 if skala==13 &  k==65 
replace k7 = 29 if skala==13 &  k==66 
replace k7 = 31 if skala==13 &  k==67 
replace k7 = 33 if skala==13 &  k==68 
replace k7 = 35 if skala==13 &  k==69 
replace k7 = 37 if skala==13 &  k==70 
replace k7 = 40 if skala==13 &  k==71 
replace k7 = 42 if skala==13 &  k==72 
replace k7 = 44 if skala==13 &  k==73 
replace k7 = 47 if skala==13 &  k==74 
replace k7 = 49 if skala==13 &  k==75 
replace k7 = 52 if skala==13 &  k==76 
replace k7 = 54 if skala==13 &  k==77 
replace k7 = 57 if skala==13 &  k==78 
replace k7 = 59 if skala==13 &  k==79 
replace k7 = 62 if skala==13 &  k==80 
replace k7 = 65 if skala==13 &  k==81 
replace k7 = 68 if skala==13 &  k==82 
replace k7 = 70 if skala==13 &  k==83 
replace k7 = 73 if skala==13 &  k==84 
replace k7 = 76 if skala==13 &  k==85 
replace k7 = 79 if skala==13 &  k==86 
replace k7 = 81 if skala==13 &  k==87 
replace k7 = 84 if skala==13 &  k==88 
replace k7 = 87 if skala==13 &  k==89 
replace k7 = 89 if skala==13 &  k==90 
replace k7 = 92 if skala==13 &  k==91 
replace k7 = 94 if skala==13 &  k==92 
replace k7 = 97 if skala==13 &  k==93 
replace k7 = 99 if skala==13 &  k==94 
replace k7 = 101 if skala==13 &  k==95 
replace k7 = 104 if skala==13 &  k==96 
replace k7 = 106 if skala==13 &  k==97 
replace k7 = 108 if skala==13 &  k==98 
replace k7 = 110 if skala==13 &  k==99 
replace k7 = 112 if skala==13 &  k==100
replace k7 = 113 if skala==13 &  k==101
replace k7 = 115 if skala==13 &  k==102
replace k7 = 116 if skala==13 &  k==103
replace k7 = 117 if skala==13 &  k==104
replace k7 = 118 if skala==13 &  k==105
replace k7 = 120 if skala==13 &  106<=k&k<=130
gr twoway scatter k7 k if skala==13  // check
sum k k7 if skala==13
sum k k7
keep pnr k7 
keep if k7!=.
label var k7 "GPA gymnasium"
save tempmain_gpagym, replace
use tempmain, clear
merge 1:1 pnr using tempmain_gpagym, keep(master match) nogen
gen misk=k7==.
replace k7=68 if k7==.  // 68 is the mean of k7
forval a=26/32{
gen hfq`a'=.
replace hfq`a'=1 if hfmain`a'==20 | inrange(hfmain`a',40,80)   // further edu. or general upper sec.
replace hfq`a'=2 if hfmain`a'==30                              // vocational edu.
replace hfq`a'=3 if hfmain`a'==10                              // no edu. beyond compulsory
tab hfmain`a' hfq`a', mis
bys hfq`a': sum misk k7   				// GPA is missing for some with hfq`a'=1 since it is missing for hhx and htx before 1999.
bys hfq`a': sum      k7 if misk==0      // And because admission to some post-secondary educations is possible without a general upper sec. edu.                       
}										// GPA is non-missing for about 10% with voc.edu. since they have also completed a general upper sec. edu.
save tempmain, replace


// check if hfd education code in main dataset exists in old dataset and adjust code if it is missing in old
use tempold, clear
keep if earn40!=. & earn28!=. & status28!=. & hfd29!=.
collapse (count) pnr, by(hfd29)
rename pnr nold
save tempold_collapse, replace

use tempmain, clear
bys hfd29: keep if _n==1
keep hfd29 hf_text29
save temp, replace
use tempmain, clear
keep if earn28!=. & status28!=. & hfd29!=.
collapse (count) pnr, by(hfd29)
rename pnr nmain
merge 1:1 hfd29 using temp, keepusing(hf_text29) keep(master match) nogen
merge 1:1 hfd29 using tempold_collapse
save tempex, replace

// Based on the above collapsed dataset (tempex):
// When the hf education code exists in tempmain (recent years) but not in tempold (earlier years) we change the code to similar edu. code which exists in tempold
use tempmain, clear
forval a=28/32{
replace hfd`a'=301530 if hfd`a'==301535
replace hfd`a'=302515 if hfd`a'==302520
replace hfd`a'=303020 if hfd`a'==303010
replace hfd`a'=303020 if hfd`a'==303015
replace hfd`a'=304015 if hfd`a'==304010
replace hfd`a'=305520 if hfd`a'==305525
replace hfd`a'=306510 if hfd`a'==306520
replace hfd`a'=306510 if hfd`a'==306540  // captured in additional check below (3 lags & byear 1974-77 in tempold)
replace hfd`a'=309010 if hfd`a'==309025
replace hfd`a'=352010 if hfd`a'==353010  // captured in additional check below
replace hfd`a'=403010 if hfd`a'==403090
replace hfd`a'=403010 if hfd`a'==403055  // captured in additional check below (3 lags)
replace hfd`a'=403010 if hfd`a'==403065  // captured in additional check below (3 lags)
replace hfd`a'=405824 if hfd`a'==405825  
replace hfd`a'=408945 if hfd`a'==408925
replace hfd`a'=409510 if hfd`a'==409710
replace hfd`a'=503810 if hfd`a'==503825
replace hfd`a'=503810 if hfd`a'==503830  // captured in additional check below
replace hfd`a'=505895 if hfd`a'==505840
replace hfd`a'=508045 if hfd`a'==508020
replace hfd`a'=508935 if hfd`a'==509710
replace hfd`a'=702030 if hfd`a'==702025
replace hfd`a'=702537 if hfd`a'==702540
replace hfd`a'=702563 if hfd`a'==702562  // captured in additional check below (3 lags & byear 1974-77 in tempold)
replace hfd`a'=703065 if hfd`a'==703040
replace hfd`a'=703517 if hfd`a'==703520
replace hfd`a'=703517 if hfd`a'==703522
replace hfd`a'=703517 if hfd`a'==703525
replace hfd`a'=703510 if hfd`a'==703595  // captured in additional check below (3 lags & byear 1974-77 in tempold)
replace hfd`a'=705915 if hfd`a'==705920
replace hfd`a'=705950 if hfd`a'==705955  // captured in additional check below (3 lags)
replace hfd`a'=705995 if hfd`a'==705960
replace hfd`a'=705995 if hfd`a'==705970
replace hfd`a'=708020 if hfd`a'==708025
replace hfd`a'=709010 if hfd`a'==709015
replace hfd`a'=709010 if hfd`a'==709020
replace hfd`a'=709045 if hfd`a'==709035
replace hfd`a'=709045 if hfd`a'==709040
replace hfd`a'=709095 if hfd`a'==709710
}
save tempmain, replace

// When number of obs. in tempold is small (<=10) we replace with similar code in both tempmain and tempold
use tempmain, clear
forval a=28/32{
replace hfd`a'=301530 if inlist(hfd`a',301565,301560,301555)
replace hfd`a'=305015 if hfd`a'==305010
replace hfd`a'=305535 if hfd`a'==305540
replace hfd`a'=305585 if hfd`a'==305580
replace hfd`a'=408945 if inlist(hfd`a',402015,402025)
replace hfd`a'=405850 if inlist(hfd`a',405835,405895)
replace hfd`a'=502015 if hfd`a'==502030
replace hfd`a'=503010 if inlist(hfd`a',503030,503035,503040,503050,503065)
replace hfd`a'=503810 if hfd`a'==503915
replace hfd`a'=507520 if hfd`a'==507515
replace hfd`a'=702570 if hfd`a'==702571
replace hfd`a'=702595 if hfd`a'==702575
replace hfd`a'=703537 if hfd`a'==703535
replace hfd`a'=703960 if hfd`a'==703955
replace hfd`a'=708020 if hfd`a'==708040
replace hfd`a'=709095 if hfd`a'==709010
replace hfd`a'=709095 if hfd`a'==709045
}
save tempmain, replace
use tempold, clear
forval a=28/32{
replace hfd`a'=301530 if inlist(hfd`a',301565,301560,301555)
replace hfd`a'=305015 if hfd`a'==305010
replace hfd`a'=305535 if hfd`a'==305540
replace hfd`a'=305585 if hfd`a'==305580
replace hfd`a'=408945 if inlist(hfd`a',402015,402025)
replace hfd`a'=405850 if inlist(hfd`a',405835,405895)
replace hfd`a'=502015 if hfd`a'==502030
replace hfd`a'=503010 if inlist(hfd`a',503030,503035,503040,503050,503065)
replace hfd`a'=503810 if hfd`a'==503915
replace hfd`a'=507520 if hfd`a'==507515
replace hfd`a'=702570 if hfd`a'==702571
replace hfd`a'=702595 if hfd`a'==702575
replace hfd`a'=703537 if hfd`a'==703535
replace hfd`a'=703960 if hfd`a'==703955
replace hfd`a'=708020 if hfd`a'==708040
replace hfd`a'=709095 if hfd`a'==709010
replace hfd`a'=709095 if hfd`a'==709045
}
save tempold, replace

cap log close
log using "$logfiles\A4a_indh_expected_income_200825.log", replace

// Check that the above corrections capture all missing-code problems when estimating by age in 2019 (age 29-32)
forval a=29/32{
local a_1 = `a'-1
use tempold, clear
keep if earn40!=. & earn`a_1'!=. & status`a_1'!=. & hfd`a'!=.
collapse (count) pnr, by(hfd`a')
rename pnr nold
save tempold_collapse`a', replace
use tempmain, clear
keep if earn`a_1'!=. & status`a_1'!=. & hfd`a'!=.
collapse (count) pnr, by(hfd`a')
rename pnr nmain
//merge 1:1 hfd29 using temp, keepusing(hf_text29) keep(master match) nogen
merge 1:1 hfd`a' using tempold_collapse`a'
count if _merge==1 // If zero we have no missing-code problems
list if _merge==1
}

// Check that the above corrections capture all missing-code problems when estimating by age in 2019 (age 29-32) using 3-year lags
forval a=29/32{
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
local a_4 = `a'-4
use tempold, clear
keep if earn40!=. & earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
                  & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
                  & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
                  & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.   
collapse (count) pnr, by(hfd`a')
rename pnr nold
save tempold_collapse`a', replace
use tempmain, clear
keep if earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
      & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
      & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
      & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.   
collapse (count) pnr, by(hfd`a')
rename pnr nmain
merge 1:1 hfd`a' using tempold_collapse`a'
count if _merge==1 // If zero we have no missing-code problems
list if _merge==1
}

// Check that the above corrections capture all missing-code problems when estimating by age in 2019 (age 29-32) using 3-year lags and byear cohorts 1974-77 only
forval a=29/32{
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
local a_4 = `a'-4
use tempold, clear
keep if earn40!=. & earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
                  & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
                  & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
                  & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.   & 1974<=byear&byear<=1977
collapse (count) pnr, by(hfd`a')
rename pnr nold
save tempold_collapse`a', replace
use tempmain, clear
keep if earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
      & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
      & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
      & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.  
collapse (count) pnr, by(hfd`a')
rename pnr nmain
merge 1:1 hfd`a' using tempold_collapse`a'
count if _merge==1 // If zero we have no missing-code problems
list if _merge==1
}

// Check for codes with small number of obs in tempold when estimating by age in 2019 (age 29-32) using 3-year lags and byear cohorts 1974-77 only
forval a=29/32{
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
local a_4 = `a'-4
use tempold, clear
keep if earn40!=. & earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
                  & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
                  & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
                  & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.   & 1974<=byear&byear<=1977
collapse (count) pnr, by(hfd`a')
rename pnr nold
save tempold_collapse`a', replace
use tempmain, clear
keep if earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
      & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
      & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
      & earn`a_4'!=. & status`a_4'!=. & hfd`a_3'!=.  
collapse (count) pnr, by(hfd`a')
rename pnr nmain
merge 1:1 hfd`a' using tempold_collapse`a'
count if _merge==3 & nold<=10 // If zero we have no few obs. problems
list if _merge==3 & nold<=10
}

// Check that the above corrections capture all missing-code problems when estimating a model for earnings at age 28 using lagged covariates age 25-27 and byear cohorts 1974-77 only  (earn28p27)
forval a=28/28{
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
local a_4 = `a'-4
use tempold, clear
keep if earn`a'!=. & earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
                   & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
                   & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.   ///
                   & 1974<=byear&byear<=1977
collapse (count) pnr, by(hfd`a')
rename pnr nold
save tempold_collapse`a', replace
use tempmain, clear
keep if earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.   ///
      & earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.   ///
      & earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.  
collapse (count) pnr, by(hfd`a')
rename pnr nmain
merge 1:1 hfd`a' using tempold_collapse`a'
count if _merge==1 // If zero we have no missing-code problems
list if _merge==1
}

// Keep only obs. for cohorts for which we have information on earnings age 25-31 and age 40
use tempold, clear
bys byear: sum earn25 earn26 earn27 earn28 earn29 earn30 earn31 earn40  // Characterize effective sample in terms of byear cohorts
bys byear: sum status25 status26 status27 status28 status29 status30 status31
keep if 1971<=byear&byear<=1977
save tempold, replace

*************
// Estimation

clear        // Earnings age 40 predicted using older cohorts 1974-77, up to 3 years lags in prediction model
save temp_earn40x3lag7477, replace emptyok      
forval a=28/31{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
use tempold, clear
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')) ///
		   ///
		   ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3' ib0.male ///
		   ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')  ///
		   ib0.male#(ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib0.male#(ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3')) ///
		   ib0.male#(ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')) ///
		   if 1974<=byear&byear<=1977
use tempmain, clear
predict earn40x3lag7477   if earn`a'  !=. & status`a'  !=. & hfd`a1' !=. & byear+`a1'==2018 ///
					      &  earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.                    ///
                          &  earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.                    ///
                          &  earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.
rename hfd`a1' hfd
keep if earn40x3lag7477!=.
keep pnr earn40x3lag7477 hfd
append using temp_earn40x3lag7477
save temp_earn40x3lag7477, replace
}

clear        // Earnings age 40 predicted using older cohorts 1974-77, no lags in prediction model
save temp_earn40x7477, replace emptyok      
forval a=28/31{
local a1 = `a'+1
use tempold, clear
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   if 1974<=byear&byear<=1977
use tempmain, clear
predict earn40x7477   if earn`a'!=. & status`a'!=. & hfd`a1'!=. & byear+`a1'==2018 
rename hfd`a1' hfd
keep if earn40x7477!=.
keep pnr earn40x7477 hfd
append using temp_earn40x7477
save temp_earn40x7477, replace
}

clear        // Earnings age 40 predicted using older cohorts 1974-77, only education and gender as covariates
save temp_earn40edu7477, replace emptyok      
forval a=28/31{
local a1 = `a'+1
use tempold, clear
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' ib0.male ///
		   ib0.male#ib50.hfmain`a1'  ///
		   if 1974<=byear&byear<=1977
use tempmain, clear
predict earn40edu7477   if earn`a'!=. & status`a'!=. & hfd`a1'!=. & byear+`a1'==2018 
rename hfd`a1' hfd
keep if earn40edu7477!=.
keep pnr earn40edu7477 hfd
append using temp_earn40edu7477
save temp_earn40edu7477, replace
}

clear        //  Earnings age 40 using 3 extra older cohorts, cohorts 1971-77; but 3-year lags included in prediction model
save temp_earn40x3lag, replace emptyok      //  GPA from gymnasium included - now with more detailed interaction with educational level (hfmain)
forval a=28/31{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
use tempold, clear
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')) ///
		   ///
		   ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3' ib0.male ///
		   ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')  ///
		   ib0.male#(ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib0.male#(ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3')) ///
		   ib0.male#(ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')) 
use tempmain, clear
predict earn40x3lag   if earn`a'  !=. & status`a'  !=. & hfd`a1' !=. & byear+`a1'==2018 ///
                      &  earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.                    ///
                      &  earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.                    ///
                      &  earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.
rename hfd`a1' hfd
keep if earn40x3lag!=.
keep pnr earn40x3lag hfd
append using temp_earn40x3lag
save temp_earn40x3lag, replace
}

clear        //  Earnings age 28 predicted conditional on obs. by age 27 using older cohorts 1974-77, for specification check
save temp_earn28p27_7477, replace emptyok      
forval a=27/27{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
use tempold, clear
reg earn28 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')) ///
		   if 1974<=byear&byear<=1977
use tempmain, clear
predict earn28p27_7477  if earn`a'  !=. & status`a'  !=. & hfd`a1' !=. /*& byear+`a1'==2018*/ ///
                   &  earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.                    ///
                   &  earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.                    
rename hfd`a1' hfd
keep if earn28p27_7477!=.
keep pnr earn28p27_7477 hfd
append using temp_earn28p27_7477
save temp_earn28p27_7477, replace
}

clear        //  Earnings age 28 predicted conditional on obs. by age 27 using data in main sample (cohorts 1986-89), for specification check       
save temp_earn28p27main, replace emptyok      
forval a=27/27{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
use tempmain, clear
reg earn28 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2'))
predict earn28p27main  if e(sample)                    
rename hfd`a1' hfd
keep if earn28p27main!=.
keep pnr earn28p27main hfd
append using temp_earn28p27main
save temp_earn28p27main, replace
}

clear        //  Earnings age 28 predicted conditional on obs. by age 27 using data in main sample (cohorts 1986-89) and all covariates in main analysis, for specification check       
save temp_earn28p27main_allx, replace emptyok      
forval a=27/27{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
use tempmain, clear
reg earn28 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   $all_factor_exmale i.byear i.kom_ny ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#($all_factor_exmale) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2'))
predict earn28p27main_allx  if e(sample)                    
rename hfd`a1' hfd
keep if earn28p27main_allx!=.
keep pnr earn28p27main_allx hfd
append using temp_earn28p27main_allx
save temp_earn28p27main_allx, replace
}


use                 temp_earn40x3lag7477, clear
merge 1:1 pnr using temp_earn40x7477, nogen
merge 1:1 pnr using temp_earn40x3lag, nogen
merge 1:1 pnr using temp_earn40edu7477, nogen
merge 1:1 pnr using temp_earn28p27_7477, nogen
merge 1:1 pnr using temp_earn28p27main, nogen
merge 1:1 pnr using temp_earn28p27main_allx, nogen
save earn40, replace

log close
