*** This programme calculates additional outcome variables at age 28

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
local dstformat "\\srvfsenas1\data\Formater\SAS formater i Danmarks Statistik\STATA_datasaet\Disced\"
set more off 
cd "$data"
set matsize 2000
clear

****************************************************
** Format: pria - months of completed education
	use "`dstformat'n_audd_pria_l1lx_k.dta", clear    // 
		rename start hfaudd
		rename AUDD_PRIA_L1LX_K  pria	
		destring pria, replace force
		replace pria=pria/12  // years of completed education (instead of months)
		la var pria "YOE"
	save pria, replace
***********************************************

// Labor market status age 25-31	
use prep1, clear
keep pnr byear hfaudd* edu2* edu3* eeb2* eeb3* sta2* sta3* 
forval a=25/31{
gen emp`a'  =eeb`a'-edu`a'           // eeb=employed or student.  edu=student
gen unemp`a'=sta`a'==200
gen leave`a'=inrange(sta`a',315,316)
gen notlf`a'=(inrange(sta`a',300,314) | inrange(sta`a',317,415) | sta`a'==513) 
gen self`a'=inrange(sta`a',110,120)
gen wearn`a'=emp`a'-self`a'
gen notlft`a'=notlf`a'+leave`a'
foreach v in unemp`a' leave`a' notlf`a' self`a' wearn`a' notlft`a'{
replace `v'=. if sta`a'==.
}
la var emp`a'   "Employed age `a'"             // including parental leave from employment
la var unemp`a' "Unemployed age `a'"
la var leave`a' "Parental leave age `a'"       // including parental leave from unemployment
la var notlf`a' "Not in labor force age `a'"
la var self`a'  "Self-employed age `a'"
la var wearn`a' "Wage earner age `a'"
la var notlft`a' "Not in labor force age `a'"  // including parental leave from unemployment
gen statd`a'=. // detailed labor market status
replace statd`a'=0 if wearn`a'==1
replace statd`a'=1 if self`a'==1
replace statd`a'=2 if edu`a'==1
replace statd`a'=3 if unemp`a'==1
replace statd`a'=4 if leave`a'==1
replace statd`a'=5 if notlf`a'==1
la define statdv`a' 0 "Wage earner age `a'"  1 "Self-employed age `a'"  2 "Student age `a'"  3 "Unemployed age `a'"  4 "Parental leave age `a'"  5 "Not in labor force age `a'"
la values statd`a' statdv`a'
}
tab1 statd*
tab1 sta28 sta31
sum emp28 edu28 unemp28 leave28 notlf28 sta28 statd28 self28 wearn28 notlft28

// Years of education
gen hfaudd=.
forval a=26/32{
replace hfaudd=hfaudd`a'
merge m:1 hfaudd using pria, keep(master match) nogen
rename pria pria`a'
la var pria`a' "YOE age `a'"  
}
drop hfaudd
sum pria*
tab pria28
	
// GPA upper secondary school
merge 1:1 pnr using tempmain, keepusing(ecat28 k7 misk) keep(master match) nogen  // tempmain is constructed in A_predicted_income
// ecat18 is earnings category: 0 if earn28=0, 1 if 0<earn28<=100, 2 if 100<earn28.
// k7 is GPA from general upper secondary school (coded mean (68) if missing); misk is indicator for missing GPA.
gen gpa=k7
replace gpa=. if misk==1
la var gpa "GPA general upper secondary edu."
save temp, replace
sum

keep pnr byear
save temp3, replace

clear
save append, replace emptyok 
// yearly wage income 
local start=2012
forval t=`start'/2018{                     //     byear=1986: 2012 age=25 (beginning of year);  byear=1989: 2018 age=28 (beginning of year)
use "$rawdata\ind`t'", clear
keep pnr loenmv_13 
drop if pnr==.
merge 1:1 pnr using temp3, keep(match) nogen
gen cpi=.
replace cpi = 128.8 if `t' == 2012  // consumer price index with year 2000=100
replace cpi = 129.9 if `t' == 2013
replace cpi = 130.6 if `t' == 2014
replace cpi = 100*100.0/76.2 if `t' == 2015  //  consumer price index with 2015=100, and 2000=76.2
replace cpi = 100*100.3/76.2 if `t' == 2016
replace cpi = 100*101.4/76.2 if `t' == 2017
replace cpi = 100*102.2/76.2 if `t' == 2018
replace cpi = 100*103.0/76.2 if `t' == 2019
replace cpi = 100*103.4/76.2 if `t' == 2020
*converts all prices to 2015 prices
replace cpi = (cpi/100)/(100/76.2)       // 2015=1 (not 100)
replace loenmv_13 = loenmv_13/cpi
replace loenmv_13 = loenmv_13/1000       // 1,000 DKK, base 2015
gen age=`t'-byear-1        // age primo year t
forval y=1989(-1)1986{
local a=`t'-`y'-1
display `a'
gen wageinc`a' = .
replace wageinc`a' = loenmv_13 if `a'==age
la var wageinc`a'  "Wage income age `a'"
}
sum wageinc*
drop loenmv_13 age byear cpi

if `t'>`start' merge 1:1 pnr using append, update nogen   // option update: non-missing values from using overwrite values in master 
save append, replace
}
sum
use temp, clear
merge 1:1 pnr using append, keep(master match) nogen
save temp, replace
sum

// Hours per month and hourly wage
forval t=2011/2018{  // saving temp version of bfl with only November information on selected variables
di `t'
use pnr ajo_loentimer ajo_loentime_kode ajo_smalt_loenbeloeb ajo_bredt_loenbeloeb ajo_job_start_dato ajo_job_slut_dato arbnr cvrnr oknr /// 
    if  month(ajo_job_start)==11  using "$rawdata\bfl`t'12", clear
save temp_bfl`t', replace	
}

use temp, clear
forval a=25/32{
gen wage_month`a'=.
gen hours_month`a'=.
gen wage_hour`a'=.
la var wage_month`a'  "Wage per month age `a'"
la var hours_month`a' "Hours per month age `a'"
la var wage_hour`a'   "Hourly wage age `a'"
gen hours_monthx`a'=.
gen wage_hourx`a'=.
la var hours_monthx`a' "Hours per month age `a', ex.imputed"
la var wage_hourx`a'   "Hourly wage age `a', ex.imputed"
gen wage_monthb`a'=.  
gen wage_hourb`a'=.
la var wage_monthb`a'  "Wage per month age `a', broad"
la var wage_hourb`a'   "Hourly wage age `a', broad"  // broad wage concept including fringe benefits, etc.
}
gen cpi=.
sum
forval t=2011/2018{  // merge the temp_bfl files on main dataset and generate variables for hours pre month and wage per hour by age
di `t'
merge 1:m pnr using temp_bfl`t', keep(master match) nogen
gen md_start=month(ajo_job_start_dato)
gen md_slut =month(ajo_job_slut_dato)
drop ajo_job_start_dato ajo_job_slut_dato
tab md_start md_slut
rename ajo_loentime_kode hours_code   // 1=reported, 0=imputed
la var hours_code "Code=1 if reported, 0 if imputed"
rename ajo_loentimer hours_month
rename ajo_smalt_loenbeloeb wage_month
rename ajo_bredt_loenbeloeb wage_monthb
replace cpi = 118.1 if `t' == 2008  // consumer price index with year 2000=100
replace cpi = 119.7 if `t' == 2009  
replace cpi = 122.4 if `t' == 2010
replace cpi = 125.8 if `t' == 2011  
replace cpi = 128.8 if `t' == 2012  
replace cpi = 129.9 if `t' == 2013
replace cpi = 130.6 if `t' == 2014
replace cpi = 100*100.0/76.2 if `t' == 2015  //  consumer price index with 2015=100, and 2000=76.2
replace cpi = 100*100.3/76.2 if `t' == 2016
replace cpi = 100*101.4/76.2 if `t' == 2017
replace cpi = 100*102.2/76.2 if `t' == 2018
replace cpi = 100*103.0/76.2 if `t' == 2019
replace cpi = 100*103.4/76.2 if `t' == 2020
*converts all prices to 2015 prices
replace cpi = (cpi/100)/(100/76.2)       // 2015=1 (not 100)
replace wage_month =wage_month/cpi 
replace wage_monthb=wage_monthb/cpi

sort pnr
gen awage_month=.
gen awage_monthb=.
gen ahours_month=.
by pnr: replace awage_month = wage_month                    if _n==1 
by pnr: replace awage_month =awage_month[_n-1]+wage_month   if _n>1
by pnr: replace awage_monthb= wage_monthb                   if _n==1 
by pnr: replace awage_monthb=awage_monthb[_n-1]+wage_monthb if _n>1
by pnr: replace ahours_month= hours_month                   if _n==1 
by pnr: replace ahours_month=ahours_month[_n-1]+hours_month if _n>1
sum wage_month awage_month wage_monthb awage_monthb hours_month ahours_month

gen hours_monthx=hours_month   // hours and wage excluding job observations with imputed hours 
gen wage_monthx=wage_month
replace hours_monthx=0 if hours_code==0
replace wage_monthx=0  if hours_code==0
gen awage_monthx=.
gen ahours_monthx=.
by pnr: replace awage_monthx= wage_monthx                  if _n==1 
by pnr: replace awage_monthx=awage_monthx[_n-1]+wage_monthx if _n>1
by pnr: replace ahours_monthx= hours_monthx                   if _n==1 
by pnr: replace ahours_monthx=ahours_monthx[_n-1]+hours_monthx if _n>1
sum wage_monthx awage_monthx hours_monthx ahours_monthx

by pnr: keep if _n==_N
sum wage_month awage_month wage_monthb awage_monthb hours_month ahours_month wage_monthx awage_monthx hours_monthx ahours_monthx

gen wage_hour =awage_month/ahours_month   // hourly wage calculated as accumulated wage over jobs / accumulated hours over jobs
gen wage_hourx=awage_monthx/ahours_monthx // ditto but excluding observations with imputed hours
gen wage_hourb=awage_monthb/ahours_month  // hourly wage (broad wage definition) calculated as accumulated wage over jobs / accumulated hours over jobs

gen age=`t'-byear
forval a=25/32{
replace wage_month`a'  =wage_month    if  `a'==age
replace hours_month`a' =ahours_month  if  `a'==age
replace wage_hour`a'   =wage_hour     if  `a'==age
replace wage_monthb`a' =wage_monthb   if  `a'==age
replace wage_hourb`a'  =wage_hourb    if  `a'==age
replace hours_monthx`a'=ahours_monthx if  `a'==age
replace wage_hourx`a'  =wage_hourx    if  `a'==age
}
drop hours_month wage_hour wage_hourb ahours_month hours_monthx wage_hourx ahours_monthx md_start md_slut ///
     wage_month awage_month wage_monthb awage_monthb wage_monthx awage_monthx hours_code arbnr cvrnr oknr age
sum pnr
}	
drop cpi
sum wage_month* hours_month* wage_hour*
forval a=28/28{
sum hours_month`a' if hours_month`a'>0 
sum hours_monthx`a' if hours_monthx`a'>0 
sum hours_month`a' hours_monthx`a' wage_hour`a' wage_hourx`a' if hours_monthx`a'>0 
}
sum

duplicates r pnr  // check
tab hours_month28  if wage_hour28>4800 & wage_hour28!=.
tab hours_month28  if wage_hour28>2000 & wage_hour28!=.
tab hours_monthx28 if wage_hourx28>2000 & wage_hourx28!=.
// The majority of those with very high hourly wages work only few hours (also when omitting observations with imputed hours. 
// A possible explanation might be misreported hours.
gen rhours28=round(hours_month28)
tab rhours28 if hours_month28>0   
sum wage_hour28 wage_hourb28 wage_hourx28, d   

save temp, replace

// Top and bottom code hours and hourly wage (at 99% and 1% percentiles) - variables renamed with extension tc below
use temp, clear
keep pnr hours_month* wage_hour*
sum hours_month28 wage_hour28 if hours_month28>0
gen p=.
qui forval a=25/32{
qui sum hours_month`a', d
replace p=r(p99)
replace hours_month`a'=p if hours_month`a'>p & hours_month`a'!=.
replace p=r(p1)
replace hours_month`a'=p if hours_month`a'<p 
qui sum wage_hour`a', d
replace p=r(p99)
replace wage_hour`a'=p if wage_hour`a'>p & wage_hour`a'!=.
replace p=r(p1)
replace wage_hour`a'=p if wage_hour`a'<p
}
sum hours_month28 wage_hour28
sum hours_month28 wage_hourb28 if hours_month28>0
qui forval a=25/32{
qui sum wage_hourb`a', d
replace p=r(p99)
replace wage_hourb`a'=p if wage_hourb`a'>p & wage_hourb`a'!=.
replace p=r(p1)
replace wage_hourb`a'=p if wage_hourb`a'<p
}
sum hours_month28 wage_hourb28
sum hours_monthx28 wage_hourx28 if hours_monthx28>0
qui forval a=25/32{
qui sum hours_monthx`a', d
replace p=r(p99)
replace hours_monthx`a'=p if hours_monthx`a'>p & hours_monthx`a'!=.
replace p=r(p1)
replace hours_monthx`a'=p if hours_monthx`a'<p 
qui sum wage_hourx`a', d
replace p=r(p99)
replace wage_hourx`a'=p if wage_hourx`a'>p & wage_hourx`a'!=.
replace p=r(p1)
replace wage_hourx`a'=p if wage_hourx`a'<p
noi sum hours_monthx`a' wage_hourx`a'
}

// check after top/bottom coding
cap drop rhours28
gen rhours28=round(hours_month28)
tab rhours28    
tab rhours28 if hours_month28>0   
drop rhours28
sum wage_hour28 wage_hourx28 wage_hourb28, d   

rename hours_monthx* hours_mxtc*   // tc=top coded
rename hours_month*  hours_mtc*
rename wage_hourb*   wage_hbtc*
rename wage_hourx*   wage_hxtc*
rename wage_hour*    wage_htc*
sum

// log hours and log wage rate
qui forval a=25/32{
gen lnh_mtc`a'=ln(hours_mtc`a')
gen lnw_htc`a'=ln(wage_htc`a')
la var lnh_mtc`a' "log hours per month age `a'"
la var lnw_htc`a' "log hourly wage age `a'"
}

save temp2, replace

use temp, clear
merge 1:1 pnr using temp2, keep(master match) nogen
forval a=25/32{
replace wage_month`a'  = wage_month`a'/1000
replace wage_monthb`a' = wage_monthb`a'/1000
}
gen check28 = wearn28+self28+edu28+unemp28+notlf28+leave28
gen check28x= wearn28+self28+edu28+unemp28+notlft28
gen check28y= emp28+edu28+unemp28+notlft28
sum check*

keep pnr emp* unemp* leave* notlf* self* sta* wearn* pria* ecat28 k7 misk gpa wage_month* hours_month* wage_hour* wageinc*	///
         hours_mxtc* hours_mtc* wage_hbtc* wage_hxtc* wage_htc* lnh_mtc* lnw_htc*

sum
save addoutcomes, replace	
