/********************************************************************************
           Finish preparation of final sample: Merge expected earnings age 40 and additional outcomes age 28; sample selection
           NB: In the output dataset, earnings, wage and income variables are measured in USD instead of DKK
*********************************************************************************/
*cap log close
set more off 
include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

cd "$data"
use prep1, clear
count

merge 1:1 pnr using earn40, keep(master match) // expected earnings age 40 etc.
tab byear _merge
drop _merge
count
foreach y of varlist earn28p*{
replace `y'=0 if `y'<0
}

merge 1:1 pnr using addoutcomes, keep(master match) nogen // additional outcomes age 28
merge 1:1 pnr using fertility, keep(master match) nogen   // fertility age 28

gen child28_0 = child28==1 & agey28==0
gen child28_1 = child28==1 & inrange(agey28,0,1)
gen child28_2 = child28==1 & inrange(agey28,0,2)
gen child28_3 = child28==1 & inrange(agey28,0,3)
la var child28_0 "Youngest child age 0"
la var child28_1 "Youngest child age 0-1"
la var child28_2 "Youngest child age 0-2"
la var child28_3 "Youngest child age 0-3"
gen child28_1x = child28==1 & agey28==1
gen child28_2x = child28==1 & agey28==2
la var child28_1x "Youngest child age 1"
la var child28_2x "Youngest child age 2"
gen numchild28=numchildren28
replace numchild28=3 if numchild28>3
la var numchild28 "No. of children, Winsorized at 3"

gen grades9matdan = (math_ex13!=. & danish_OW_ex13!=. & math_co13!=. & danish_OW_co13!=. & not_grade9marks==0 & nogrades86==0)

forval t=25/30{
la var tindper`t' "Gross income age `t'"
la var tinderh`t' "Earnings age `t'"
la var tinddis`t' "Disposable income age `t'"
}
la var tindper31 "Gross income age 31"
la var tinderh31 "Earnings age 31"
foreach y of varlist earn40* {
la var `y'   "Earnings age 40"
}

la var fagm "Mother vocational edu."
la var kvum "Mother short further edu."
la var mvum "Mother medium further edu."
la var lvum "Mother higher education"
la var fagf "Father vocational edu."
la var kvuf "Father short further edu."
la var mvuf "Father medium further edu."
la var lvuf "Father higher education"

gen neet28=1-emp28-edu28
la var neet28 "Not in employment or education age 28"

gen compmulti=.
replace compmulti=0 if complete==0
replace compmulti=1 if erhvcomp==1
replace compmulti=2 if gymncomp==1
label define multi 0 "No" 1 "Vocational" 2 "General"
label values compmulti multi

// We measure educational attainment at, e.g., age 28 by October in the year the person was 28 years of age at the beginning of the year. 
// In the registers it is measured by October the previous year. Therefore, we redefine labels for educational attainment
forval a=26/32{
local a1=`a'-1
la var pria`a' "YOE age `a1'"
la var hf_kode`a' "Highest completed edu. level age `a1'"
}  
// For 0.07% of observations with a completed upper secondary education (vocational or general) pria (YOE) is below 12
// due to inconsistencies between registers. Therefore the following correction
forval a=26/32{
replace pria`a'=12 if complete==1 & pria`a'<12
}  
gen postsec29=hf_kode29>35
la var postsec29 "Some post-secondary education age 28"
gen priaus29=pria29
replace priaus29=. if postsec29==1
la var priaus29 "YOE age 28 if no post-secondary edu."
gen priaps29=pria29
replace priaps29=. if postsec29==0
la var priaps29 "YOE age 28 if some post-secondary edu."
gen lvu29=hf_kode29>=60   // University BA, MA, PhD
la var lvu29 "University BA,MA,PhD age 28"

gen matlow = (math_ex13_nm+math_co13_nm)/2 <= 7
gen matmid = 7 < (math_ex13_nm+math_co13_nm)/2 & (math_ex13_nm+math_co13_nm)/2 < 9
gen mathigh=(math_ex13_nm+math_co13_nm)/2 >= 9 & math_ex13_nm!=. & math_co13_nm!=.

// NB: convert earnings, income and wage rate to USD using exchange rate 6.5 (end of 2018)
rename wagerecf wrecf
rename wagerecm wrecm
foreach y of varlist earn40* earn28p* tind* ind* wage*{
replace `y' = `y'/6.5
}
qui forval a=25/32{
replace lnw_htc`a'=ln(wage_htc`a')
}
rename wrecf wagerecf
rename wrecm wagerecm

gen incf=exp(lincomef)*1000  // income in DKK 1000 (instead of DKK 1m) 
replace incf=incf/6.5        // income in USD 1000  
gen lincf=ln(incf)
gen incm=exp(lincomem)*1000  // income in DKK 1000 (instead of DKK 1m) 
replace incm=incm/6.5        // income in USD 1000
gen lincm=ln(incm)
la var lincf "Father log income"
la var lincm "Mother log income"
la var incf "Father income"
la var incm "Mother income"

// Table A1 of the Online Appendíx reports these counts
// Sample selection
count                      // 253,923. byear cohorts 1986-1989 who are in the sample for at least one year prior to age 14 (firstalder<=14) - 91% have firstalder=0.
count if gradyear!=.       // 243,135. gradyear is missing if the person did not attend grade 8, 9 or 10 according to the education register kotre (dropped out before grade 8 or emigrated)
count if gradyear!=. & gradyear<=firstuddayear-1  // 242,197 (we lose 0.4% of obs.). Drop if a person enrol in upper sec. edu. before last year in lower sec. school. E.g. dropout in 8th grade, enrol in voc. edu., reenter 8th grade, complete lower sec. and enrol in another upper sec. edu. pgm.
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.)  // 241,014. If a person has completed an upper secondary education, he should also have been enrolled in such an education program. However, he/she might have completed abroad?
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=.  // 240,840. Is living in Denmark at time of completing compulsory school (1st of Jan in year of completion, or 1st of Jan in year of first inrolling in upper secondary program)
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 // 238,629. Exclude persons born in 1986 who completed 9th grade in June 2001 (one year erlier than prescribed) since we do not have information on test scores in 9th grade before 2002, and this reason for no test score info. is very different from not completing 9th grade.
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. // 228,328 - In UDDA and therefore in BEF at age 25. Completion and start of upper sec. edu. (treatments) are defined at (up to) age 25. Thus it is important with this restriction irrespective of which outcome is used. In RAS register at age 24 and 25.
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. // 221,824  - we lose 3% obs. because there is no distance measure for these addresses
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492   // 221,812  - we lose 12 obs. Addresses at the island Ærø have distance measures in 2006 even though they should not. The reason is unimportant complications due to merging municipalities at Ærø 1 year before the large municipality reform. 
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & eeb28!=. & tinderh28!=.  // 214,871  - outcomes at age 28 observed 
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & eeb28!=. & tinderh28!=. & earn40x7477!=.  // 212,542  - outcomes observed at age 28 and expected earnings at age 40 (constructed based on data for 2018). Living in Denmark at age 28 (and at age: 29 if cohort 1988, 30 if cohort 1987; 31 if cohort1986) 
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & earn40x3lag7477!=.  // 210,339  - outcomes observed (eeb28 and tinderh28 are used to predict earn40x3lag, so they are observed when earn40x3lag is observed). Living in Denmark in 2018 and the 3 previous years (at age 25-28,...,28-31; for cohort 89,...,86)
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & earn40x3lag7477!=. & start==1 // 198,048  - enrolled in upper secondary edu. by age 25
count if gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & earn40x3lag7477!=. & complete==1 // 161,432  - completed upper secondary education by age 25

rename sample sample_udfk   // sample_udfk are those in udfk (9th grade test score sample) among those with byear 1986-89.

gen sample = gradyear!=. & gradyear<=firstuddayear-1 & !(firstuddafinish!=. & firstudda==.) & adresse1kom!=. & gr9early1986!=1 & NEET25!=. & hfyrs25!=. & afst1_2025_first!=. & kom_ny!=492 & earn40x3lag7477!=.   
count if sample==1


******************************************************************
keep if sample==1  
order _all, seq
save prep2, replace

sum
