** This do-file has these steps:
** 1) First step is to restrict the sample, which is people who is 25 before 2015 and who are 15 or more primo 2002 (udfk), and create a dummy for those who have grades in udfk (no data before 2002)
** 2) Identify missing parents
** 3) Find all siblings and step-siblings to this groups of people.
** 4) Find inf on when the person is in the papulation register (fain)
** 5) Find siblings and half siblings.
** 6) Find deaths in family
** 7) Alternative way of finding siblings and halfsiblings
** 8) Saving data with all siblings.
** 9) Creating birthorder and family-variables.
** 10) finding dead siblings
** 11) Households
** 12) Are parents married 0, 5 and 10 years after birth?
** 13) Identifying child's age when parents died (if they did)
** 14) Saving sample without siblings

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

set more off, perm

cd "$data"

clear

save append, replace emptyok
save append1, replace emptyok
save append2, replace emptyok
save append3, replace emptyok
save append4, replace emptyok


** 1) First step is to restrict the sample to individuals who are 25 before 2015, and has 9th grade test scores in the register udfk (no data before 2002)

** Find people with primary school grades
use "$rawdata\udfk2015.dta", clear
keep pnr
duplicates drop
destring pnr, replace force
drop if pnr == .
save "$data\people with grades", replace

** Find people who are 25 before 2015
forval year = 1985/2015 {
use "$adj_raw\fain`year'", clear
keep pnr alder koen pnrm pnrf fodtdato 
rename koen male 
gen byear = `year' - alder - 1
replace male = 0 if male == 2
label var male "male"

gen year = `year'
tempfile temp`year'
save "`temp`year''", replace
}

use "`temp1985'", clear
forval year = 1986/2015 {
append using "`temp`year''"
}

bysort pnr: egen byear2 = max(byear)
replace byear = byear2 // in a few cases the recorded birth year (byear) is misrecorded (because the person is in fain the year before birth)

gen sample = inrange(byear,1986,1989) // Cohort 1989 is 24 years of age beginning of 2014 (age 25 end of 2014): 2014-24-1=1989. 
									  // Cohort 1986 is 15 years of age beginning of 2002: 2002-15-1=1986
                                      
merge m:1 pnr using "$data\people with grades", keep(master match) 

gen sample2 = sample                // sample2 is dummy for birth year cohorts 1986-1989
replace sample = 0 if _merge != 3   // sample is now a dummy =1 for those (among cohorts 1986-1989) who are in udfk, =0 otherwise.
drop _merge

** 2) Identify missing parents
//Identifying the first non-missing father.
bysort pnr (year): gen counterf = _n if pnrf != .
by pnr: egen firstf = min(counterf)
gen double firstdad = pnrf if counterf == firstf
by pnr: egen double pnrf2 = max(firstdad)
gen latef = firstf >= 2
drop pnrf firstdad counterf firstf
rename pnrf2 pnrf

//Identifying the first non-missing mother.
bysort pnr (year): gen counterm = _n if pnrm != .
by pnr: egen firstm = min(counterm)
gen double firstmom = pnrm if counterm == firstm
by pnr: egen double pnrm2 = max(firstmom)
gen latem = firstmom >= 2
drop pnrm firstmom counterm firstm
rename pnrm2 pnrm

** 3) Find all siblings and step-siblings to this groups of people.
bysort pnrm: egen insamplem = sum(sample2) if pnrm != .
bysort pnrf: egen insamplef = sum(sample2) if pnrf != .
keep if [insamplem >= 1 & insamplem != .]  | [insamplef >= 1 & insamplef != .] | sample2 == 1 //keeping people in the right age, and their siblings.

** 4) Find info on when the individual is in the population register
bysort pnr: egen firstyear = min(year)
by pnr: egen lastyear = max(year)
by pnr: egen firstalder= min(alder)
by pnr: egen lastalder = max(alder)

by pnr: egen fodtdato2 = max(fodtdato)
drop fodtdato
rename fodtdato2 fodtdato

duplicates drop
bysort pnr: gen number = _N
sort number pnr
bysort pnr: keep if _n == 1 // 0 drops

drop alder year insamplem insamplef

** 5) Find siblings and half siblings.

bysort pnrm pnrf: gen numbersiblings = _N - 1 if pnrm!= . & pnrf != .
bysort pnrf: gen numberhalfsiblings_f = _N - 1 - numbersiblings if pnrf!= .
bysort pnrm: gen numberhalfsiblings_m = _N - 1 - numbersiblings if pnrm!= .
gen numberhalfsiblings = numberhalfsiblings_f + numberhalfsiblings_m

count if firstalder == .
drop if firstalder == .

la var pnr "Child's PNR"     // pnr is person id number
la var pnrm "Mother's PNR"
la var pnrf "Father's PNR"

gen misf = (pnrf == .)
la var misf "Missing father"
gen mism = (pnrm == .)
la var mism "Missing mother"

sort pnrm pnrf pnr
egen fam_id = group(pnrm pnrf) if pnrf != . & pnrm != .
la var fam_id "Family ID. If two people have the same family ID, they have the same mother and father"

** 6) Find deaths in family
merge 1:1 pnr using "$rawdata\dod2013.dta", keep(master match) keepusing(doddato) nogen

gen dyear = year(doddato)
gen deadage = dyear - byear
gen deadage2 = (doddato - fodtdato)/365.25
replace deadage2 = deadage if deadage2 == .
gen ord = fodtdato == .


** 7) Alternative way of finding siblings and halfsiblings. 
sort pnrm byear fodtdato
by pnrm: gen hsmy = (pnrm==pnrm[_n+1]) & fam_id != fam_id[_n+1] & (fodtdato != fodtdato[_n+1]|fodtdato==.)
la var hsmy "Younger half sibling on mother's side"
by pnrm: gen hsmo = (pnrm==pnrm[_n-1]) & fam_id != fam_id[_n-1] & (fodtdato != fodtdato[_n-1]|fodtdato==.)
la var hsmo "Older half sibling on mother's side"

forval t = 2/20 {
by pnrm: replace hsmy = (pnrm==pnrm[_n+`t']) & fam_id != fam_id[_n+`t'] & (fodtdato != fodtdato[_n+`t']|fodtdato==.) if hsmy == 0
by pnrm: replace hsmo = (pnrm==pnrm[_n-`t']) & fam_id != fam_id[_n-`t'] & (fodtdato != fodtdato[_n-`t']|fodtdato==.) if hsmo == 0
}

sort pnrf byear fodtdato
by pnrf: gen hsfy = (pnrf==pnrf[_n+1]) & fam_id != fam_id[_n+1] & (fodtdato != fodtdato[_n+1]|fodtdato==.)
la var hsfy "Younger half sibling on father's side"
by pnrf: gen hsfo = (pnrf==pnrf[_n-1]) & fam_id != fam_id[_n-1] & (fodtdato != fodtdato[_n-1]|fodtdato==.)
la var hsfo "Older half sibling on father's side"

forval t = 2/20 {
by pnrf: replace hsfy = (pnrf==pnrf[_n+`t']) & fam_id != fam_id[_n+`t'] & (fodtdato != fodtdato[_n+`t']|fodtdato==.) if hsfy == 0
by pnrf: replace hsfo = (pnrf==pnrf[_n-`t']) & fam_id != fam_id[_n-`t'] & (fodtdato != fodtdato[_n-`t']|fodtdato==.) if hsfo == 0
}

** 8) Saving data with all siblings.

save allsiblings_191001, replace
use allsiblings_191001, clear

** 9) Creating birthorder and family-variables.

sort fam_id pnr
by fam_id: gen siblings = _N - 1
replace siblings = . if pnrf == . | pnrm == .
la var siblings "Number of biological siblings"
gen onlychild = siblings == 0
la var onlychild "Only child"

sort fam_id byear fodtdato
by fam_id: gen firstborn = 1 if _n == 1 & siblings > 0
replace firstborn = 0 if firstborn == .

bysort pnrm fodtdato: gen twins = (_N>1) if fodtdato != .

// If two twins are the oldest siblings, both have firstborn status
forval t=1/20 {
bysort fam_id (byear fodtdato): replace firstborn=1 if firstborn[_n-`t']==1 & fodtdato==fodtdato[_n-`t']
bysort fam_id (byear fodtdato): replace firstborn=1 if firstborn[_n+`t']==1 & fodtdato==fodtdato[_n+`t']
}

** 10) finding dead siblings

sort fam_id fodtdato
gen deadsibl = (deadage2 != . & deadage2 < 14)
by fam_id: egen deadsible = total(deadsibl) if fam_id != .
la var deadsible "No. of dead siblings (died before their 14th birthday)"
replace deadage2 = . if deadsibl == 0
by fam_id: egen deads_age = max(deadage2) if deadsible > 0 & deadsible != .
la var deads_age "dead age of oldest dead sibling"

//finding dead older siblings 
sort fam_id fodtdato
gen deadosibl = (deadage2 != . & deadage2 < 14) & [hsmo==1 | hsfo ==1]
by fam_id: egen deadosible = total(deadosibl) if fam_id != .
drop deadosibl
la var deadosible "No. of dead older siblings (died before their 14th birthday)"
replace deadage2 = . if deadosibl == 0
by fam_id: egen deados_age = max(deadage2) if deadosible > 0 & deadosible != .
la var deados_age "dead age of oldest dead sibling"

sort pnrm fodtdato
gen dem = deadage == 0 & pnrf == .
by pnrm: egen deadsiblem = max(dem)
label var deadsiblem "Sibling died before his/her 1 year birthday (not possible to find the biological father)"
drop dem deadage deadage2

** 11) Identify households (who are living together)

rename pnr pnrb
rename pnrf pnr

keep if sample2 == 1

save tempb, replace 

// Father
clear
save append, replace emptyok
forval t = 1981/2001 { 
use tempb, clear
keep if byear == `t'-1
merge m:1 pnr using "$rawdata\fain`t'", nogen keep(master match) keepusing(bopikom kom alder koen)
rename alder agef_b
rename koen koenf
rename bopikom bopikomf
rename kom komf
append using append
save append, replace
}
la var agef_b "Father's age at the year when the child is born"
rename pnr pnrf
rename pnrm pnr 
save tempc, replace 

// Mother
clear
save append1, replace emptyok
forval t = 1981/2001 { 
use tempc, clear
keep if byear == `t'-1
merge m:1 pnr using "$adj_raw\fain`t'", nogen keep(master match) keepusing(bopikom kom alder koen)
rename alder agem_b
rename koen koenm
rename bopikom bopikomm
rename kom komm
append using append1
save append1, replace
}

la var agem_b "Father's age at the year when the child is born"
rename pnr pnrm
rename pnrb pnr 
save tempd, replace 

// Child
clear
save append2, replace emptyok
forval t = 1981/2001 { 
use tempd, clear
keep if byear == `t'-1
merge 1:1 pnr using "$adj_raw\fain`t'", nogen keep(master match) keepusing(bopikom kom)
rename bopikom bopikomb
rename kom komb
append using append2
save append2, replace
}

gen p_livtog = (komm==komf & komm!=. & bopikomm==bopikomf & bopikomm != "")
la var p_livtog "Parents live together 1st of Januar after child birth"
gen all_livtog = (komm==komf & komm!=. & bopikomm==bopikomf & bopikomm != "" & komm==komb & bopikomm == bopikomb)
la var all_livtog "Parents and child live together 1st of Januar after child birth"

drop koenf
rename pnr pnrb
rename pnrm pnr
save tempe, replace 
use tempe, clear 

** 12) Are parents married 0, 5 and 10 years after birth?
clear
save append3, replace emptyok
forval t=1980/2005 {
use tempe, clear
keep if byear==`t' | byear== `t' - 5 | byear == `t'- 10
if `t' >= 1986 {
merge m:1 pnr using "$adj_raw\fain`t'", keep(master match) keepusing(familie_type aegte_id) nogen
}
if `t' <= 1985 {
merge m:1 pnr using "$adj_raw\fain`t'", keep(master match) keepusing(aegte_id) nogen
gen familie_type = .
}

rename aegte_id pnragte`t'

gen marr_base = (pnragte`t'==pnrf & familie_type == 1) if byear == `t'
gen marr5 = (pnragte`t'==pnrf & familie_type == 1) if byear == `t'-5
gen marr10 = (pnragte`t'==pnrf & familie_type == 1) if byear == `t'-10

drop pnragte`t' familie_type

append using append3
save append3, replace
}

rename pnr pnrm
sort pnrb byear
by pnrb: egen mar_base = max(marr_base)
la var mar_base "Married jan 1st after childbirth"
by pnrb: egen mar5 = max(marr5)
la var mar5 "Married jan 1st after child is 5 years old"
by pnrb: egen mar10 = max(marr10)
la var mar10 "Married jan 1st after child is 10 years old"

drop marr_base marr5 marr10
duplicates drop //This is necessary because the above method appends each person at time 0, 5 and 10.
duplicates report pnrb //all 1's.

* 13) Identifying the child's age when the mother and father died (if they did)
rename pnrm pnr
merge m:1 pnr using "$rawdata\dod2013", keep(master match) keepusing(doddato) nogen
gen deam= doddato - fodtdato if doddato != .
gen deadm_age = deam/365.25
la var deadm_age "Child's age when the mother dies"
rename pnr pnrm
rename pnrf pnr
merge m:1 pnr using "$rawdata\dod2013", keep(master match) keepusing(doddato) nogen
gen deaf= doddato - fodtdato if doddato != .
gen deadf_age = deaf/365.25
la var deadf_age "Child's age when the father dies"
rename pnr pnrf

drop deam deaf doddato bopikomm bopikomb bopikomf komm komf komb p_livtog deadsibl koenm ord

la var twins "Has one or more twins"
la var firstborn "First born child (biological parents)"

** 14) Saving sample without siblings

keep if sample2 == 1       // birth year cohorts 1986-1989
count if firstalder<=14
count if firstalder==.
count if firstalder<=14 | firstalder==.                          
keep if firstalder <= 14 | firstalder == .     // in fain/bef register before age 14

save data, replace

duplicates report pnrb

erase append.dta
forval t = 1/4 {
erase append`t'.dta
}
erase tempb.dta
erase tempc.dta
erase tempd.dta
erase tempe.dta
erase "$data\people with grades.dta"

