// Identifies persons who are disconnected, that is, not in employment, education or training (NEET) at age 25 (beginning of year). 
// Based on the RAS register, defined as NEET in two consecutive years (age 25 and age 24, beginning of year)

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"


*cap log close
set more off 
tempfile temp
tempfile append

cd "$data"

clear
save `append', replace emptyok

use data, clear          // byear cohorts 1986-1989
keep pnrb byear
rename pnrb pnr
save `temp', replace
clear

local start=2011

forval t=`start'/2017{
use `temp', clear
local year = `t'
local yearlag1 = `year'-1

tempfile tempo1`t'
save "`tempo1`t''", replace
use "$rawdata\ras`yearlag1'", clear
keep if pri == 1
keep pnr soc_status_kode
rename soc_status_kode soc_status_kode`yearlag1'
drop if pnr == .
merge 1:1 pnr using "`tempo1`t''", keep(match)   // keep only those who are in ras(t-1) and in our basic dataset of 4 cohorts
gen year=`yearlag1'                              // year=t-1
save lag, replace

use `temp', clear
tempfile tempo2`t'
save "`tempo2`t''", replace
use "$rawdata\ras`year'", clear
keep if pri == 1
keep pnr soc_status_kode
rename soc_status_kode soc_status_kode`year'
drop if pnr == .
merge 1:1 pnr using "`tempo2`t''", keep(match)  // keep only those who are in ras(t) and in our basic dataset of 4 cohorts
append using lag                                // For each individual we have 2 records, one for t and one for t-1. However, some individuals only have a record for t, others only for t-1.
replace year= `year' if year==.                 // year=t for records for year t (but not when year=t-1)

bys pnr (year): keep if _N==2                   // keep only persons who are in RAS in both years t and t-1

gen ras = .
if `yearlag1' >= 2008{
replace ras = soc_status_kode`yearlag1' if soc_status_kode`yearlag1' !=.
}
if `yearlag1' <= 2007{
replace ras = socstil`yearlag1' if socstil`yearlag1' !=.
}
if `year' >= 2008{
replace ras = soc_status_kode`year' if soc_status_kode`year' !=.
}
if `year' <= 2007{
replace ras = socstil`year' if socstil`year' !=.
}

count if ras==.  // 0: All persons in ras has a non-missing status code

//udsattenetto is unity 1 if the person in 2 successive years is not in employment or education (or training), but not in the category 'others not in labor force'.
gen udsatte_temp_1 = [inrange(ras,200,201) | inrange(ras,315,336)] & ras != 330 & year <=2007   // 0 because year>2007
replace udsatte_temp_1 = 1 if [inrange(ras,200,415)] & year >= 2008                             // Thus, udsatte_temp_1 is either 0 or 1
bysort pnr: egen udsattenetto = sum(udsatte_temp_1)                                             // This is either 0, 1 or 2 for everyone.
//udsattebrutto is unity 1 if the person in 2 successive years is not in employment or education (or training).
gen udsatte_temp_2 = [inrange(ras,200,201) | inrange(ras,315,336)] & year <=2007
replace udsatte_temp_2 = 1 if [inrange(ras,200,415) | ras == 513] & year >= 2008
bysort pnr: egen udsattebrutto = sum(udsatte_temp_2)

keep pnr byear udsattenetto udsattebrutto
bysort pnr: keep if _n == 1 
replace udsattenetto = (udsattenetto==2)
replace udsattebrutto= (udsattebrutto==2)
gen age=`t'-byear        // age ultimo year because of date definition of RAS, see comment above. RAS<t> contains labour market status beginning of t+1 (end Nov. t) for population beginning of t+1. 

forval y=1989(-1)1986{
local a=`t'-`y'
display `a'
gen udsattenetto`a'  = .
gen udsattebrutto`a' = .
replace udsattenetto`a'  = udsattenetto   if `a'==age
replace udsattebrutto`a' = udsattebrutto  if `a'==age
la var udsattenetto`a'  "NEET age `a'"
la var udsattebrutto`a' "NEET age `a' (gross)"
}
sum udsattenetto*
drop udsattenetto udsattebrutto age byear

if `t'>`start' merge 1:1 pnr using `append', update nogen
save `append', replace
}
rename pnr pnrb
drop  *22 *23 *24 
order _all, alpha
save discony, replace

sum udsatte*

erase "$data/lag.dta"


