//           Income and employment variables for parents when the child is 13 (beginning of year),
//           and income for "child" at age 25 and above

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

set more off 

tempfile append

cd "$data"

clear
save appendm, replace emptyok
save appendf, replace emptyok
save appendc, replace emptyok
save appendd, replace emptyok
save `append', replace emptyok

use data, clear
keep pnrm pnrf pnrb byear
save temp2, replace

foreach z in "m" "f" {

use temp2, clear
rename pnr`z' pnr
save temp3, replace

forval t=2000/2003{    // byear: 1986-1989. That is, byear+14=2000-2003
use temp3, clear
gen year=`t'
keep if byear+14==`t'

tempfile temp`z'`t'
save "`temp`z'`t''", replace
if `t' <=2001 {
use "$rawdata\indh`t'.dta", clear
keep pnr socio dispon_ny personindk erhvervsindk
duplicates drop
merge 1:m pnr using "`temp`z'`t''", keep(using match) nogen
rename socio socio`z'
}
else{
use "$rawdata\indh`t'.dta", clear
keep pnr socio02 dispon_ny personindk erhvervsindk
duplicates drop
merge 1:m pnr using "`temp`z'`t''", keep(using match) nogen
rename socio02 socio`z'    
}
rename dispon_ny disp`z'
rename personindk perindkialt`z'
rename erhvervsindk	erhvervsindk`z'

merge m:1 pnr using "$adj_raw\ras`t'", keep(master match) keepusing(soc_status_kode) nogen
rename soc_status_kode socstil`z'

append using append`z'
save append`z', replace
}
}

use appendf, clear
rename pnr pnrf
rename pnrm pnr
merge 1:1 pnrb pnr pnrf using appendm, nogen

*generate a variable for consumer price index (from Statistics Denmark)
gen real = 45.6 if year == 1980
replace real = 51.0 if year == 1981 
replace real =56.1 if year == 1982  
replace real = 60.0 if year == 1983  
replace real = 63.8 if year == 1984  
replace real = 66.7 if year == 1985  
replace real = 69.2 if year == 1986  
replace real = 72.0 if year == 1987  
replace real = 75.3 if year == 1988  
replace real = 78.9 if year == 1989  
replace real = 80.9 if year == 1990  
replace real = 82.9 if year == 1991  
replace real = 84.6 if year == 1992  
replace real = 85.7 if year == 1993  
replace real = 87.4 if year == 1994  
replace real = 89.2 if year == 1995  
replace real = 91.1 if year == 1996  
replace real = 93.1 if year == 1997  
replace real = 94.8 if year == 1998  
replace real = 97.2 if year == 1999  
replace real = 100.0 if year == 2000  
replace real = 102.4 if year == 2001  
replace real = 104.8 if year == 2002  
replace real = 107.0 if year == 2003  
replace real = 108.3 if year == 2004  
replace real = 110.2 if year == 2005  
replace real = 112.3 if year == 2006  
replace real = 114.2 if year == 2007  
replace real = 118.1 if year == 2008  
replace real = 119.7 if year == 2009  
replace real = 122.4 if year == 2010
replace real = 125.8 if year == 2011  
replace real = 128.8 if year == 2012  
replace real = 129.9 if year == 2013
replace real = 130.6 if year == 2014
replace real = 100*100.0/76.2 if year == 2015  // CPI, 2015=100, and 2000=76.2
replace real = 100*100.3/76.2 if year == 2016
replace real = 100*101.4/76.2 if year == 2017
replace real = 100*102.2/76.2 if year == 2018
  
*converts all prices to 2015 prices
gen real2015 = (real/100)/(100/76.2)       // 2015=1 (not 100)
sort year
table year, c(mean real mean real2015)

gen incomem = perindkialtm/real2015
gen incomef = perindkialtf/real2015
la var incomem "Mother's total income"
la var incomef "Father's total income"

replace dispm = dispm/real2015
replace dispf = dispf/real2015
la var dispm "Mother's disposable income"
la var dispf "Father's disposable income"

gen busincm =erhvervsindkm/real2015
gen busincf =erhvervsindkf/real2015
la var busincm "Mother's business income"
la var busincf "Father's business income"

gen wagerecm = (inrange(sociom,131,135) | sociom==13) if sociom !=. & year<=2001
replace wagerecm = (inrange(sociom,131,135)|sociom==139) if sociom !=. & year>2001
la var wagerecm "Mother employed"
gen selfempm = (inrange(sociom,111,114)|sociom==11|sociom==12) if sociom !=. & year<=2001
replace selfempm =(inrange(sociom,111,114)|sociom==120) if sociom !=. & year>2001
la var selfempm "Mother self-employed"
gen penm = (sociom==321) if sociom !=.
la var penm "Mother disability pension"
gen unempm = (sociom==2) if sociom!=. & year<=2001
replace unempm = (sociom==210) if sociom!=. & year>2001
la var unempm "Mother unemployed"
gen othm =(wagerecm ==0 & selfempm ==0 & penm==0 & unempm==0) if sociom !=.
la var othm "Mother not in work force"
gen nosociom = (sociom==.)
la var nosociom "Mother labor market status missing"

gen wagerecf = (inrange(sociof,131,135) | sociof==13) if sociof !=. & year<=2001
replace wagerecf = (inrange(sociof,131,135)|sociof==139) if sociof !=. & year>2001
la var wagerecf "Father employed"
gen selfempf = (inrange(sociof,111,114)|sociof==11|sociof==12) if sociof !=. & year<=2001
replace selfempf =(inrange(sociof,111,114)|sociof==120) if sociof !=. & year>2001
la var selfempf "Father self-employed"
gen penf = (sociof==321) if sociof !=.
la var penf "Father disability pension"
gen unempf = (sociof==2) if sociof!=. & year<=2001
replace unempf = (sociof==210) if sociof!=. & year>2001
la var unempf "Father unemployed"
gen othf =(wagerecf ==0 & selfempf ==0 & penf==0 & unempf==0) if sociof !=.
la var othf "Father not in work force"
gen nosociof = (sociof==.)
la var nosociof "Father labor market status missing"

save temp4, replace
use temp4, clear

* degree of unemployment for the mothers
forval t=2000/2003{
use temp4, clear
keep if byear+14==`t'
count if year != `t'
merge m:1 pnr using "$rawdata\idap`t'.dta", keepusing(arledgr) keep(master match) nogen

gen ledgrm = arledgr/1000 
drop arledgr
append using appendc
save appendc, replace
}
gen ledgm = (ledgrm>0) 
label var ledgrm "Degree of unemployment, mothers"
label var ledgm "Some unemployment, mothers"
rename pnr pnrm
rename pnrf pnr
save temp5, replace
* degree of unemployment for the fathers
forval t=2000/2003{
use temp5, clear
keep if byear+14==`t'
count if year != `t'
merge m:1 pnr using "$rawdata\idap`t'.dta", keepusing(arledgr) keep(master match)

gen ledgrf = arledgr/1000 
drop _merge arledgr
append using appendd
save appendd, replace
}
gen ledgf = (ledgrf>0) 
label var ledgrf "Degree of unemployment, fathers"
label var ledgf "Some unemployment, fathers"
rename pnr pnrf

foreach z in "m" "f" {
if "`z'" == "m" local parrent Mother
if "`z'" == "f" local parrent Father

gen rasbesk`z' = socstil`z' <= 199
gen rasudd`z' = socstil`z' == 310 
gen rasuarbstyrk`z' = inrange(socstil`z',315,399) 
gen rasledig`z' = inrange(socstil`z',200,201)
gen raskont`z' = socstil`z' == 326
gen rasfortid`z' = socstil`z' == 331

la var rasbesk`z' "`parrent' in employment, (13 years)"
la var rasudd`z' "`parrent' in education, (13 years)"
la var rasuarbstyrk`z' "`parrent' not in workforce (other), (13 years)"
la var rasledig`z' "`parrent' unemployed (13 years)"
la var raskont`z' "`parrent' cash benefits (13 years)"
la var rasfortid`z' "`parrent' disability pension, (13 years)"
}

gen norasm = socstilm == .
gen norasf = socstilf == .
la var norasm "Mother not in ras"
la var norasf "Father not in ras"
drop real2015 year real

save temp5, replace

// Income for children from IND register
use temp2, clear
rename pnrb pnr
save temp3, replace

local start=2012

forval t=`start'/2018{                     //     byear=1986: 2012 age=25 (beginning of year).  byear=1989: 2018 age=28 (beginning of year)
use "$rawdata\ind`t'", clear
keep pnr perindkialt_13 erhvervsindk_13      
drop if pnr==.
merge 1:1 pnr using temp3, keep(match) nogen
gen real=.
replace real = 128.8 if `t' == 2012  
replace real = 129.9 if `t' == 2013
replace real = 130.6 if `t' == 2014
replace real = 100*100.0/76.2 if `t' == 2015  // CPI, 2015=100, 2000=76.2
replace real = 100*100.3/76.2 if `t' == 2016
replace real = 100*101.4/76.2 if `t' == 2017
replace real = 100*102.2/76.2 if `t' == 2018
*converts incomes to 2015 prices
gen real2015 = (real/100)/(100/76.2)                    // 2015=1 
foreach x in /*dispon_13*/ perindkialt_13 erhvervsindk_13{
replace `x'=`x'/real2015
}
gen age=`t'-byear-1        // age primo year t
forval y=1989(-1)1986{
local a=`t'-`y'-1
display `a'
//gen inddis`a' = .
gen indper`a' = .
gen inderh`a' = .
//replace inddis`a' = dispon_13       if `a'==age
replace indper`a' = perindkialt_13  if `a'==age
replace inderh`a' = erhvervsindk_13 if `a'==age
//la var inddis`a'  "Disposable income age `a'"
la var indper`a'  "Gross income age `a'"
la var inderh`a'  "Earnings age `a'"
}
sum inderh*
drop /*dispon_13*/ perindkialt* erhvervsindk* age byear

if `t'>`start' merge 1:1 pnr using `append', update nogen   // option update: non-missing values from using overwrite values in master 
save `append', replace
}
save temp6, replace

clear
save `append', replace emptyok

// Similar for disposable income (was only updated to 2017)
forval t=`start'/2017{                     //     byear=1986: 2012 age=25 (beginning of year).  byear=1989: 2018 age=28 (beginning of year)
use "$rawdata\ind`t'", clear
keep pnr dispon_13 
drop if pnr==.
merge 1:1 pnr using temp3, keep(match) nogen
gen real=.
replace real = 128.8 if `t' == 2012  
replace real = 129.9 if `t' == 2013
replace real = 130.6 if `t' == 2014
replace real = 100*100.0/76.2 if `t' == 2015  // CPI, 2015=100, 2000=76.2
replace real = 100*100.3/76.2 if `t' == 2016
replace real = 100*101.4/76.2 if `t' == 2017
replace real = 100*102.2/76.2 if `t' == 2018
*converts incomes to 2015 prices
gen real2015 = (real/100)/(100/76.2)                    // 2015=1 
foreach x in dispon_13{
replace `x'=`x'/real2015
}
gen age=`t'-byear-1        // age primo year t
forval y=1989(-1)1986{
local a=`t'-`y'-1
display `a'
gen inddis`a' = .
replace inddis`a' = dispon_13       if `a'==age
la var inddis`a'  "Disposable income age `a'"
}
sum inddis*
drop dispon_13 age byear

if `t'>`start' merge 1:1 pnr using `append', update nogen   // option update: non-missing values from using overwrite values in master 
save `append', replace
}
merge 1:1 pnr using temp6, keepusing(indper* inderh*) keep(master match) nogen 

rename pnr pnrb
drop  *22 *23 *24 
drop real2015 real

merge 1:1 pnrb using temp5
drop _merge
drop erhvervsin* perindkialt*
order _all, alphabetic
save indh, replace
sum
//deleting tempfiles
erase appendm.dta
erase appendf.dta
erase appendc.dta
erase appendd.dta
erase temp2.dta
erase temp3.dta
erase temp4.dta
erase temp5.dta
erase temp6.dta

