//  Education variables for child and parents

set more off 

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"

cd "$data"

clear
* Saving empty datasets to be used later on
save appendb, replace emptyok
save appendby, replace emptyok
save appendby2, replace emptyok
save appendby3, replace emptyok
save appendm, replace emptyok
save appendf, replace emptyok

use data, clear   // byear: 1986-1989. byear+26 (year aged 25 beginning of year): 2012-2015 (byear is birth year)

keep pnrb pnrm pnrf fodtdato byear
rename pnrb pnr   // the id variable pnr is now the child's id (pnrb means pnr for child)
save temp, replace
save temp7, replace

** Individuals' (children's) education at age 25
forval t=1981/2015 {
di `t'
use temp, clear
keep if byear+26==`t' //Education in year t is education end of year t-1 in udda register. 
                      //It is recorded for the population beginning of year t and enrolment oct t-1, and completion end (typically June) of t-1. 
					  //Education status beginning of year where the person is 25 years old beginning of year
if `t' <= 2014 {
merge 1:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(match) keepusing(hf_kode udd_kode hfpria) nogen
}
if `t' >= 2015 {
merge 1:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(match) keepusing(hf_kode udd_kode) nogen
gen hfpria = .
}
append using appendb
save appendb, replace
}
gen hf_mis=1 if hf_kode==.
gen y_educ = hfpria/12
label var y_educ "Years of completed education (pria)"
gen hf = hf_kode / 10
gen ufag= ((0.0<=hf&hf<2.0)|(3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0))           // changed 191017:   | hf==.)
gen fag = (3.5<=hf&hf<4)
gen vu =(4.0<=hf&hf<8.0)  
gen gym =(2.0<=hf&hf<3.0) 
gen kvu =(4.0<=hf&hf<5.0) 
gen mvu =(5.0<=hf&hf<6.5)
gen lvu = (6.5 <=hf & hf <8.0)

gen ig_mis= (udd_kode==.)
la var ig_mis "Not in education, age 25"
gen hfyrs=.
replace hfyrs=10 if (0.0<=hf&hf<2.0) | (3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0)          // lower secondary
replace hfyrs=13 if (2.0<=hf&hf<3.0) | (3.5<=hf&hf<4)                              // upper secondary
replace hfyrs=15 if (4.0<=hf&hf<5.0)                                               // short further (post-secondary)
replace hfyrs=16 if (5.0<=hf&hf<6.5)                                               // long further (e.g., professional bachelor)
replace hfyrs=18 if (6.5 <=hf & hf <8.0)                                           // higher (university)
la var hfyrs "Years of education, age 25"

drop hf hf_kode udd_kode
rename pnr pnrb   // 
save appendb, replace

**Individuals' first completed upper secondary education
use temp, clear
gen firstuddafinish = .
gen firstuddafinishyear = .
forval t=1981/2015 {
merge 1:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(master match) keepusing(hf_kode) nogen
replace firstuddafinish = hf_kode if inlist(hf_kode,20,25,35) & firstuddafinish == .
replace firstuddafinishyear = `t' if firstuddafinish != . & firstuddafinishyear ==.
drop hf_kode
}
gen firstuddafinishalder = firstuddafinishyear - byear - 1   // Earlier: +1 instead of -1: age is primo year.
replace firstuddafinish = . if firstuddafinishalder >= 26
replace firstuddafinishyear = . if firstuddafinishalder >= 26
replace firstuddafinishalder = . if firstuddafinishalder >= 26

rename pnr pnrb
save append123, replace

** Years of education (YOE) at ages after 25 years
local a0=26
forval a=`a0'/32{
di `a'
use appendby, clear
drop _all
save appendby, replace emptyok
forval t=2012/2019 {   
di `t'
use temp, clear
keep if byear+`a'+1==`t' 
merge 1:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(match) keepusing(hf_kode udd_kode hfaudd udd hf_kilde) nogen
append using appendby
save appendby, replace
}
gen ig_mis`a'= (udd_kode==.)
la var ig_mis`a' "Not in education, age `a'"
gen hf = hf_kode
gen hfyrs`a'=.
replace hfyrs`a'=10 if hf==10                 // lower secondary
replace hfyrs`a'=13 if inlist(hf,20,25,35)    // upper secondary
replace hfyrs`a'=15 if hf==40                 // short further
replace hfyrs`a'=16 if inlist(hf,50,60)       // long further 
replace hfyrs`a'=18 if inlist(hf,65,70)       // higher (university)
la var hfyrs`a' "Years of education, age `a'"  // Status beginning of the year where the person has age a beginning of year (i.e. educatiohn status typically attained by medio the previous year)

gen hfaudd`a'=hfaudd
gen udd`a'=udd
gen hf_kode`a'=hf_kode
gen udd_kode`a'=udd_kode
gen hf_kilde`a'=hf_kilde

drop hf hf_kode udd_kode hfaudd udd hf_kilde
if `a'>`a0'  merge 1:1 pnr using appendby2, update nogen
save appendby2, replace
}
rename pnr pnrb
save appendby2, replace

use temp, clear
rename pnr pnrb
rename pnrm pnr  // the id variable pnr is now the mother's id
save temp, replace

* parents' education when the child is 15 years old
forval t=1981/2015{
di `t'
use temp, clear
keep if byear+14==`t' //Mother's education when the child is 15 years old. 
merge m:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(master match) keepusing(hf_kode udd_kode) 
gen missuddanym = (_merge==1)
drop _merge
append using appendm
save appendm, replace
}
gen hf_mism=1 if hf_kode==.
la var hf_mism "Mother is in uddany but missing info on education"
gen hf=hf_kode/10
gen ufagm= ((0.0<=hf&hf<2.0)|(3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0)| hf==.)
gen fagm = (3.5<=hf&hf<4)
gen vum =(4.0<=hf&hf<8.0) | (2.0<=hf&hf<3.0) 
gen gymm =(2.0<=hf&hf<3.0) 
gen kvum =(4.0<=hf&hf<5.0) | (2.0<=hf&hf<3.0) 
gen mvum =(5.0<=hf&hf<6.5)
gen lvum = (6.5 <=hf & hf <8.0)
gen ig_m= (udd_kode!=.)
la var ig_m "Mother is in education"
la var missuddanym "Mother is missing in Uddany"
drop hf hf_kode udd_kode
rename pnr pnrm
save appendm, replace

use temp, clear
rename pnr pnrm
rename pnrf pnr   // the id variable pnr is now the father's id
save temp, replace

forval t=1981/2015{
di `t'
use temp, clear
keep if byear+14==`t' //Fathers education when the child is 15 years old. 
merge m:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(master match) keepusing(hf_kode udd_kode) 
gen missuddanyf = (_merge==1)
drop _merge
append using appendf
save appendf, replace
}
gen hf_misf=1 if hf_kode==.
la var hf_misf "Father is in uddany but missing info on education"
gen hf=hf_kode/10
gen ufagf= ((0.0<=hf&hf<2.0)|(3.0<=hf&hf<3.5)|(9.0<=hf&hf<10.0)| hf==.)
gen fagf = (3.5<=hf&hf<4)
gen vuf =(4.0<=hf&hf<8.0) | (2.0<=hf&hf<3.0) 
gen gymf =(2.0<=hf&hf<3.0) 
gen kvuf =(4.0<=hf&hf<5.0) | (2.0<=hf&hf<3.0) 
gen mvuf =(5.0<=hf&hf<6.5)
gen lvuf = (6.5 <=hf & hf <8.0)
gen ig_f= (udd_kode!=.)
la var ig_f "Father is in education"
la var missuddanyf "Father is missing in Uddanny"
drop hf hf_kode udd_kode
rename pnr pnrf
save appendf, replace
use appendf, clear

merge 1:1 pnrb using appendm, nogen
merge 1:1 pnrb using appendb, nogen
merge 1:1 pnrb using appendby2, nogen
merge 1:1 pnrb using data, keepusing(pnrb) keep(using match) nogen 
merge 1:1 pnrb using append123, nogen
rename hfyrs hfyrs25
rename ig_mis ig_mis25

// some corrections
tab firstuddafinish hfyrs25, mis        // some persons have completed an upper sec. edu. by age 25 according to firstuddafinish, but do not have an upper sec. edu. at age 25 according to hfyrs25
tab hfyrs25 hfyrs27, mis                // some persons have hfyrs25>hfyrs27
bys byear: tab hfyrs25 hfyrs27, mis
bys byear: tab hfyrs26 hfyrs27, mis
tab hfyrs26 hfyrs28, mis                // some persons have hfyrs26>hfyrs28
bys byear: tab hfyrs26 hfyrs28, mis
bys byear: tab hfyrs26 hfyrs30, mis

// The reason for the above 'inconsistencies' is that hfaudd(t) in the UDDA(t) register is based on KOTRE(t) (the longitudinal student register for year t and earlier years).
// Errors in UDDA(t) are not corrected based on later versions of KOTRE (since UDDA is a 'status register'). However, KOTRE(t) is corrected back in time when an error is discovered.
// Therefore we 'trust' the later versions of UDDA when there are inconsistencies, and implement the following corrections:
forval a=31(-1)25{
local a1 = `a' + 1
replace hfyrs`a'=hfyrs`a1' if hfyrs`a'>hfyrs`a1' & hfyrs`a'!=. & hfyrs`a1'!=.
}
replace firstuddafinish=. if firstuddafinish!=. & hfyrs25==10
replace firstuddafinishyear=. if firstuddafinishyear!=. & hfyrs25==10
replace firstuddafinishalder=. if firstuddafinishalder!=. & hfyrs25==10

forval a=25/31{
gen upsec`a' = hfyrs`a'>=13 & hfyrs`a'!=.  
replace upsec`a'=. if hfyrs`a'==.
label var upsec`a' "Upper secondary edu. by age `a'"
}
tab firstuddafinish hfyrs25, mis        
tab firstuddafinish upsec25, mis        

save appendf, replace

** hf_kode (highest attained education) variable for age 15-25 (hf_kode for age 26-32 is constructed above). hf_kode(a)!=. is indicator for the person living in Denmark at age a (beginning of year)
local a00=15
forval a=`a00'/25{
di `a'
use appendby, clear
drop _all
save appendby, replace emptyok
forval t=2000/2019 {   
di `t'
use temp7, clear
keep if byear+`a'+1==`t' 
merge 1:1 pnr using  "$rawdata_udda\udda`t'.dta", keep(match) keepusing(hf_kode) nogen
append using appendby
save appendby, replace
}
gen hf_kode`a'=hf_kode
drop hf_kode
if `a'>`a00'  merge 1:1 pnr using appendby3, update nogen
save appendby3, replace
}
rename pnr pnrb
keep pnrb hf_kode*
save appendby3, replace
sum

use appendf, clear
merge 1:1 pnrb using appendby3, keep(master match) nogen 

order _all, alpha

save udd, replace

sum  hfyrs25 hfyrs26 hfyrs27 hfyrs28 hfyrs29 hfyrs30 hfyrs31
tab1 hfyrs25 hfyrs26 hfyrs27 hfyrs28 hfyrs29 hfyrs30 hfyrs31
sum  ig_mis25 ig_mis26 ig_mis27 ig_mis28 ig_mis29 ig_mis30 ig_mis31
tab1 firstuddafinish firstuddafinishyear firstuddafinishalder 

sum

//deleting files
erase "$data/appendb.dta"
erase "$data/appendby.dta"
erase "$data/appendby2.dta"
erase "$data/appendby3.dta"
erase "$data/append123.dta"
erase "$data/appendm.dta"
erase "$data/appendf.dta"
erase "$data/temp.dta"
erase "$data/temp7.dta"

