include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

cd "$data"
clear
set matsize 1000

use "$data/prep2", clear  

*********************************************************************************
// Construction of Table A3 and A4 in the Online Appendix

// highest completed education in 2019 beginning of year, i.e. by october 2018
gen     hfaudd=hfaudd29
replace hfaudd=hfaudd30 if byear==1988
replace hfaudd=hfaudd31 if byear==1987
replace hfaudd=hfaudd32 if byear==1986
sum hfaudd
save temp, replace

local dstformat "\\srvfsenas1\data\Formater\SAS formater i Danmarks Statistik\STATA_datasaet\Disced\"
** format for education variables
// English labels
	use "`dstformat'n_audd_hoved_e_l1l4_k.dta", clear    
		rename start hfaudd
		rename AUDD_HOVED_E_L1L4_K hf_disced4	
		destring hf_disced4, replace force
	save temp_audd_l1l4, replace
	
	use "`dstformat'n_audd_hoved_e_l1l4_kt.dta", clear    // Tekstvariabel / "format"
		rename start hfaudd
		rename AUDD_HOVED_E_L1L4_KT hf_disced4_text	
	save temp_audd_l1l4_text, replace
// Danish labels
	use "`dstformat'n_audd_hoved_l1l4_k.dta", clear    
		rename start hfaudd
		rename AUDD_HOVED_L1L4_K hf_disced4d	
		destring hf_disced4d, replace force
	save temp_audd_l1l4d, replace
	
	use "`dstformat'n_audd_hoved_l1l4_kt.dta", clear    // Tekstvariabel / "format"
		rename start hfaudd
		rename AUDD_HOVED_L1L4_KT hf_disced4d_text	
	save temp_audd_l1l4d_text, replace

use temp, clear
merge m:1 hfaudd using temp_audd_l1l4,      keep(master match) nogen
merge m:1 hfaudd using temp_audd_l1l4_text, keep(master match) nogen
merge m:1 hfaudd using temp_audd_l1l4d,      keep(master match) nogen
merge m:1 hfaudd using temp_audd_l1l4d_text, keep(master match) nogen
labmask hf_disced4, values(hf_disced4_text)
labmask hf_disced4d, values(hf_disced4d_text)
tab hf_disced4           if complete==1
tab hf_disced4d          if complete==1
// Aggregation for table
gen hf=hf_disced4
labmask hf, values(hf_disced4_text)
replace hf=2010 if inlist(hf,2020,2030)
replace hf=3035 if inlist(hf,1520,3090,3520)
replace hf=3020 if inlist(hf,3025,3030)
replace hf=3050 if hf==3065
replace hf=3040 if inlist(hf,3045,3055,3060)
replace hf=4020 if inrange(hf,4000,4099) & !inlist(hf,4038,4058)      // KVU other (than social science, technical)
replace hf=5030 if inlist(hf,5024,5075,5080,5085,5095,5097)   // Other MVU
replace hf=5038 if hf==5039
replace hf=hf+1000 if inrange(hf,6000,6999)   // BA to MA
replace hf=hf-1000 if inrange(hf,8000,8999)   // PHD to MA
replace hf=7039 if hf==7097
replace hf=7025 if inlist(hf,7020,7030)
replace hf=7059 if inlist(hf,7075,7080)
tab hf if complete==1
tab hf if complete==1, nolabel
// Change codes to change order for table
gen hft=hf
replace hft=3001 if hft==3015
replace hft=3002 if hft==3040
replace hft=3003 if hft==3035
replace hft=3004 if hft==3020
replace hft=3005 if hft==3050
replace hft=3006 if hft==3010
replace hft=4099 if hft==4020
replace hft=5099 if hft==5030
// Value labels for table
label define hftlab ///
2010 "General upper secondary" ///
3001 "Commercial field, office" ///
3002 "Technology, communication" ///
3003 "Construction and craftsmanship" ///
3004 "Food production, catering" ///
3005 "Mechanics, transport, logistics" ///
3006 "Service, care, health" ///
4038 "Social science" ///
4058 "Technical educations" ///
4099 "Other 2-year post-secondary programs" ///
5020 "Educational" ///
5038 "Social scinece" ///
5058 "Technical educations" ///
5089 "Health" ///
5099 "Other 4-year post-secondary programs" ///
7025 "Humanities and arts" ///
7035 "Science" ///
7039 "Social science" ///
7059 "Technical sciences" ///
7090 "Health" 
label values hft hftlab
tab hft if complete==1
tab hft if complete==1, nolabel
 /* Upper secondary educations */
 /* 2-year post-secondary educations */
 /* 4-year post-secondary educations */
 /* University (BA, MA, PhD) */

//Table A3 of online Appendix
foreach m in 1 0{
eststo clear
estpost tab hft if complete==1 & male==`m'
esttab using "$output\Table_A3_distribution_attainment_age28-31_male`m'.rtf", replace cell(pct(fmt(1))) unstack /*noobs*/ title("Educational attainment at age 28-31. Male `m'") varlabels(`e(labels)') varwidth(40)
}
//Table A4 of online Appendix
cap drop hf1
gen hf1=floor(hf_disced4/1000)
replace hf1=3 if hf1==1 & complete==1
label define hf1lab 2 "General upper secondary" 3 "Vocational upper secondary" 4 "2-year post secondary" 5 "4-year post secondary" 6 "Bacehlor" 7 "Master" 8"PhD" 
label values hf1 hf1lab
tab hf1 if complete==1
foreach m in 1 0{
eststo clear
estpost tab hf1 if complete==1 & male==`m'
esttab using "$output\Table_A4_distribution_edu_level_age28-31_male`m'.rtf", replace cell(pct(fmt(1))) unstack /*noobs*/ title("Educational level at age 28-31. Male `m'") varlabels(`e(labels)') varwidth(40)
}
//Similar to Table A4 above, but by type of upper secondary education completed (not shown in paper)
foreach m in 1 0{
foreach e in 1 0{
eststo clear
estpost tab hf1 if complete==1 & male==`m' & erhvcomp==`e'
esttab using "$output\distribution_edu_level_age28-31_male`m'_erhvcomp`e'.rtf", replace cell(pct(fmt(1))) unstack /*noobs*/ title("Educational level at age 28-31. Male `m'. Erhvcomp `e'") varlabels(`e(labels)') varwidth(40)
}
}
**********************************************************************




*Table A2 in the Online Appendix
foreach m in 1 0{
eststo clear
estpost tab igfirst4 if 2000<igfirst4&igfirst4<2900 & male==`m'
esttab using "$output\Table_A2_distribution_academic_uppersec_male`m'.rtf", replace cell(pct(fmt(2))) unstack noobs title("Types of general upper secondary education. Male `m'")
eststo clear
estpost tab igfirst4 if 3000<igfirst4&igfirst4<3099 & male==`m'
esttab using "$output\Table_A2_distribution_vocational_uppersec_male`m'.rtf", replace cell(pct(fmt(2))) unstack noobs title("Main types of vocational upper secondary education. Male `m'") varlabels(`e(labels)') varwidth(30)
}

*Table A5
eststo clear
quietly estpost tabstat $covariates_exmissvars if uddcat3!=3, by(uddcat3) statistics(mean) columns(statistics) /*nototal*/ 
esttab using "$output\Table_A5_covariates_by_uppersec_category_complete_all_exmissvars_2cat.rtf", replace ///
        main(mean) /*b(%9.3g)*/ b(%9.3f) nostar unstack nonote nomtitle nonumber noobs nolines nogaps plain label not varwidth(40) title("Covariates by first upper secondary completion up to age 25") ///
addnotes("Categories: 1 General education; 2 Vocational education; 3 Did not complete; 4 All. Dummies for cohorts (4), regions (10) and missing information on specific variables are not shown.")
eststo clear
estpost tabulate uddcat3 if uddcat3!=3 
esttab . using "$output\Table_A5_obs_by_uppersec_category_complete_2cat.rtf", replace cells("b(fmt(%9.0gc)) pct(fmt(2)) cumpct(fmt(2))") noobs  ///
addnotes("Categories: 1 General education; 2 Vocational education; 3 Did not complete; 4 All")



*Table C7 in Online Appendix 
foreach m in 1 0{         // males and females, respectively
foreach tr in erhv gymn{  // vocational and general upper secondary school enrollment, respectively
eststo clear
estpost tabulate uddcat if `tr'==1 & male==`m'
esttab . using "$output\Table_C7_obs_by_uppersec_category_given_`tr'_&_Male`m'.rtf", replace cells("b(fmt(%9.0gc)) pct(fmt(2)) cumpct(fmt(2))") noobs 
}
}

*Table C8 in Online Appendix
eststo clear
quietly estpost tabstat tinderh28 earn40x3lag7477 if uddcat2e!=3 & uddcat2e!=6, by(uddcat2e) statistics(mean) columns(statistics) /*nototal*/ 
esttab using "$output\Table_C8_outcomes_by_uppersec_category_start_gender_start_small_new_2cat.rtf", replace ///
        main(mean) /*b(%9.3g)*/ b(%9.3f) nostar unstack nonote nomtitle nonumber /*noobs*/ nolines nogaps plain label not varwidth(40) title("Outcomes by gender and first upper secondary enrollment up to age 25") ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education; 4 Females, general education; 5 Females, vocational education; 7 All")
eststo clear
estpost tabulate uddcat2e if uddcat2e!=3 & uddcat2e!=6
esttab . using "$output\Table_C8_obs_by_uppersec_category_gender_start_2cat.rtf", replace cells("b(fmt(%9.0gc)) pct(fmt(2)) cumpct(fmt(2))") noobs  ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education; 4 Females, general education; 5 Females, vocational education;  7 All")



*Table 1
eststo clear
quietly estpost tabstat tinderh28 earn40x3lag7477 emp28 wearn28 self28 edu28 neet28 unemp28 notlft28 postsec29 lvu29 pria29 priaus29 priaps29 child28 ///
        if uddcat3e!=3 & uddcat3e!=6, by(uddcat3e) statistics(mean) columns(statistics) /*nototal*/ 
esttab using "$output\Table_1_outcomes_additional_by_uppersec_category_complete_gender_complete_2cat_small.rtf", replace ///
        main(mean) /*b(%9.3g)*/ b(%9.3f) nostar unstack nonote nomtitle nonumber /*noobs*/ nolines nogaps plain label not varwidth(40) title("Outcomes by gender and first upper secondary completion up to age 25") ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education;  3 Females, general education; 4 Females, vocational education;  5 All")
eststo clear
quietly estpost tabstat tinderh28 earn40x3lag7477 emp28 wearn28 self28 edu28 neet28 unemp28 notlft28 postsec29 lvu29 pria29 priaus29 priaps29 child28 ///
        if uddcat3e!=3 & uddcat3e!=6, by(uddcat3e) statistics(count) columns(statistics) /*nototal*/ 
esttab using "$output\Table_1_outcomes_additional_by_uppersec_category_complete_gender_complete_2cat_small.rtf", append ///
        main(count) /*b(%9.3g)*/ b(%9.0gc) nostar unstack nonote nomtitle nonumber /*noobs*/ nolines nogaps plain label not varwidth(40) title("Outcomes by gender and first upper secondary completion up to age 25") ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education;  3 Females, general education; 4 Females, vocational education;  5 All")
// Hours and wage rate for wage earners - and only observations with non-missing hourly wage (postive hours) - Winsorized (top coded) wage and hours
eststo clear
quietly estpost tabstat hours_mtc28 wage_htc28 lnh_mtc28 lnw_htc28 ///
        if uddcat3e!=3 & uddcat3e!=6 & wearn28==1 & wage_hour28!=. , by(uddcat3e) statistics(mean) columns(statistics) /*nototal*/ 
esttab using "$output\Table_1_outcomes_additional_by_uppersec_category_complete_gender_complete_2cat_wageearners_Winsorized_small_2.rtf", replace ///
        main(mean) /*b(%9.3g)*/ b(%9.3f) nostar unstack nonote nomtitle nonumber /*noobs*/ nolines nogaps plain label not varwidth(40) title("Outcomes by gender and first upper secondary completion up to age 25") ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education;  3 Females, general education; 4 Females, vocational education;  5 All."  /// 
         "Standard full time is 160 hours per month")
eststo clear
quietly estpost tabstat hours_mtc28 wage_htc28 lnh_mtc28 lnw_htc28 ///
        if uddcat3e!=3 & uddcat3e!=6 & wearn28==1 & wage_hour28!=. , by(uddcat3e) statistics(count) columns(statistics) /*nototal*/ 
esttab using "$output\Table_1_outcomes_additional_by_uppersec_category_complete_gender_complete_2cat_wageearners_Winsorized_small_2.rtf", append ///
        main(count) /*b(%9.3g)*/ b(%9.0gc) nostar unstack nonote nomtitle nonumber /*noobs*/ nolines nogaps plain label not varwidth(40) title("Outcomes by gender and first upper secondary completion up to age 25") ///
addnotes("Categories: 1 Males, general education; 2 Males, vocational education;  3 Females, general education; 4 Females, vocational education;  5 All")


*Table 2
eststo clear
quietly estpost tabstat $covariates_small if uddcat3!=3, by(uddcat3) statistics(mean) columns(statistics) /*nototal*/ 
esttab using "$output\Table_2_covariates_by_uppersec_category_complete_small_2cat.rtf", replace ///
        main(mean) /*b(%9.3g)*/ b(%9.3f) nostar unstack nonote nomtitle nonumber noobs nolines nogaps plain label not varwidth(40) title("Covariates (selected) by first upper secondary completion up to age 25") ///
addnotes("Categories: 1 General education; 2 Vocational education; 3 Did not complete; 4 All")
eststo clear
estpost tabulate uddcat3 if uddcat3!=3 
esttab . using "$output\Table_2_obs_by_uppersec_category_complete_2cat.rtf", replace cells("b(fmt(%9.0gc)) pct(fmt(2)) cumpct(fmt(2))") noobs  ///
addnotes("Categories: 1 General education; 2 Vocational education; 3 Did not complete; 4 All")


*Table 3
egen distcat_gym_5=cut(afst1_2025_average_w), at(0,5,10,15,20,100)
egen distcat_erh_5=cut(afst1_30_average_w),   at(0,5,10,15,20,100)
eststo clear
estpost tabulate distcat_gym_5 distcat_erh_5
esttab using "$output\Table_3_distance_2025_vs30_tabulate2way.rtf", replace cell(pct(fmt(2))) unstack noobs title("Observations (percent) by distance to academic and vocational schools") ///
addnotes("Weighted average distance to academic (rows) and vocational (cols): 0-5, 5-10, 10-15, 15-20, 20+ km")

cor afst1_2025_average_w afst1_30_average_w                 // 0.8069
cor afst1_2025_average_w afst1_30_average_w if start==1     // 0.8057
cor afst1_2025_average_w afst1_30_average_w if complete==1  // 0.8036



// OLS tables A7-A10 in the Online Appendix

*  Table A7 in the Online Appendix: Effects on labor market status and educational attainment
foreach tr in erhvcomp /*erhv*/{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
eststo clear
foreach m in 1 0{
foreach y in emp28 wearn28 edu28 pria29 postsec29 lvu29{
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny      if male==`m' & `cond'==1, robust  
}  
}
esttab using "$output\OLS_emp28_edu28_pria29_postsec29_`tr'_given_`cond'.rtf", replace b(%9.3f) se(3) stats(N r2_a, fmt(%9.0fc %9.3f)) compress nogaps varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) keep(`tr') nonumber nonotes 
}

*  Table A8 in Online Appendix: Effect on working hours and hourly wage rate
foreach tr in erhvcomp /*erhv*/{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
eststo clear
foreach m in 1 0{
foreach y in lnh_mtc28 lnw_htc28{
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny     if male==`m' & `cond'==1 & wearn28==1 & wage_htc28!=., robust  
}  
}
esttab using "$output\OLS_lnhoursmtc28_lnwagehtc28_`tr'_given_`cond'.rtf", replace b(%9.3f) se(3) stats(N r2_a, fmt(%9.0fc %9.3f)) compress nogaps varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) keep(`tr') nonumber nonotes 
}

*  Table A9 in Online Appendix: Effect on fertility by 28 
foreach tr in erhvcomp /*erhv*/{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
eststo clear
foreach m in 1 0{
foreach y in child28 /*numchildren28*/{
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny       if male==`m' & `cond'==1, robust  
}  
}
esttab using "$output\OLS_child28_numchildren28_`tr'_given_`cond'.rtf", replace b(%9.3f) se(3) stats(N r2_a, fmt(%9.0fc %9.3f)) compress nogaps varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) keep(`tr') nonumber nonotes 
}

*  Table A10 in the Online Appendix
foreach tr in erhvcomp /*erhv*/{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
eststo clear
foreach m in 1 0{
foreach y in tinderh28 {
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny     if male==`m' & `cond'==1, robust  
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny     if male==`m' & `cond'==1 & edu28==0, robust  
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny     if male==`m' & `cond'==1 & edu28==0 & edu27==0, robust  
eststo: quietly reg `y' `tr'   $all_factor_exmale i.byear i.kom_ny     if male==`m' & `cond'==1 & edu28==0 & edu27==0 & edu26==0, robust  
}  
}
esttab using "$output\OLS_tinderh28_`tr'_given_`cond'_robust_NOTedu28edu27.rtf", replace b(%9.3f) se(3) stats(N, fmt(%9.0fc)) /*ar2*/ /*nolines*/ compress nogaps /*label*/ varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) keep(`tr') nonumber /*nonotes*/ /*noobs*/ /*plain*/  ///
	mtitle("Males, baseline" "Not enrolled 28" "Not enrolled 27-28" "Not enrolled 26-28"  ///
	     "Females, baseline" "Not enrolled 28" "Not enrolled 27-28" "Not enrolled 26-28")
}


*****************************************
// MTE estimation using the mtefe command
*****************************************

// Initial estimates to choose the order of the polynomials in p
// Main outcomes and most additional outcomes
foreach tr in /*erhv*/ erhvcomp{  // erhvcomp is the treatment in the main analysis (completion of vocational edu.); erhv is the alternative treatment (enrollment in vocational edu.), see Appendix C4
foreach m in 1 0 {                //1: males,  2: females
foreach y in  tinderh28 earn40x3lag7477  /*Main outcomes: Earnings at age 28 and predicted earnings at age 40*/  ///
		      earn40x7477 earn40x3lag earn40edu7477  earn28p27_7477   earn28p27main earn28p27main_allx  /*For robustness and speicification checks for predicted earnings*/   ///
			  tindper28  /*For robustness check: Total income at age 28*/  ///
			  emp28 wearn28  edu28 pria29  postsec29 lvu29 child28  /*Additional outcomes at age 28: Labor market status, educational attainment, fertility*/  {
eststo clear
foreach p in polynomial(1) polynomial(2) polynomial(3) polynomial(4) /*polynomial(5)*/  {
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  vce(robust) separate level(90) noplot
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
mtefeplot , memory 
gr save   "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate.gph", replace
gr export "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate.png", replace height(800)
}
}
}
}

// Additional outcomes: log of hours and wage per hour - conditional on being wage earner
foreach tr in erhv erhvcomp{
foreach m in 1 0{
foreach y in  lnh_mtc28 lnw_htc28   {
eststo clear
foreach p in polynomial(1) polynomial(2) polynomial(3) {
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & wearn28==1 & wage_hour28!=. , link(logit) `p' gridpoints(100)  vce(robust) separate level(90) 
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_prte_p001.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
mtefeplot , memory 
gr save   "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate.gph", replace
gr export "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate.png", replace height(800)
}
}
}
}

// Bootstrapped SE's for models with preferred polynomials in p (based on the estimations above)
// Only outcomes at age 28 and outcomes for which we do not estimate PRTEs
// For other outcomes (including the main earnings outcomes) we use the code in the following do-files prefixed B1, B2, etc.
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tindper28 emp28 wearn28 edu28 pria29  postsec29 lvu29 child28   {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
if       "`y'"=="tinderh28"   & (`m'==0 & "`tr'"=="erhv")                                         local p "polynomial(3)"
else if  "`y'"=="pria29" 																		  local p "polynomial(4)"
else if  "`y'"=="lvu29"       & `m'==0															  local p "polynomial(3)"
else if  "`y'"=="child28"     & `m'==0															  local p "polynomial(3)"
else                                                                                              local p "polynomial(2)" 
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
          if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est sto reg
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.ster", replace
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N mean_p mean_p_policy)
mtefeplot , memory
gr save   "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate_boot500.gph", replace 
gr export "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate_boot500.png", replace height(800)
}
}
}
// Additional outcomes: hours and wage per hour - conditional on being wage earner
foreach tr in /*erhv*/ erhvcomp{
foreach m in /*1*/ 0{
foreach y in  lnh_mtc28 /*lnw_htc28*/    {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
if       ("`y'"=="lnh_mtc28" & `m'==1) | ("`y'"=="lnw_htc28" & `m'==0)    local p "polynomial(1)"
else 																	  local p "polynomial(2)"
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & wearn28==1 & wage_hour28!=. , link(logit) `p' gridpoints(100)  boot(500)  separate level(90) noplot
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
mtefeplot , memory 
gr save   "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate_boot500.gph", replace
gr export "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate_boot500.png", replace height(800)
}
}
}

******
// Additional outcomes - tables

* Table A11 in the Online Appendix	   
// Bootstrappped standard errors
// emp28, wearn28, edu28, pria29, postsec29, lvu29 
eststo clear
estimates use "$output\mtefe_emp28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est1
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_wearn28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est2
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_edu28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est3
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_pria29_KOMNY_erhvcomp_given_complete_male1_polynomial(4)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est4
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_postsec29_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est4a
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_lvu29_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est4b
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_emp28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est5
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_wearn28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est6
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_edu28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est7
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_pria29_KOMNY_erhvcomp_given_complete_male0_polynomial(4)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est8
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_postsec29_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est8a
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_lvu29_KOMNY_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est8b
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
esttab est1 est2 est3 est4 est4a est4b est5 est6 est7 est8 est8a est8b using /// 
	   "$output\mtefe_emp_wearn_edu_pria_postsec_lvu_KOMNY_erhvcomp_given_complete_maleX_dist_voc&gen_mathcross_separate_6_MTEtable_boot500.rtf", ///
	   replace keep(ate att atut p01 p02 p03 p04 p1 p2 p3 p4) stats(N polynomial pX pU, fmt(%9.0gc %9.0gc %9.4f %9.4f))  b(%9.3f) se(3)  nogaps label ///
	   /*varwidth(40)*/ title("Treatment effects. Preferred polynomial models. Treatment: erhvcomp given complete. Males & females.") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
	   
* Table A12 in the Online Appendix
// Log of top and bottom coded hours per month and wage per hour, conditional on being wage earner at age 28 
// Bootstrapped SE's
eststo clear
estimates use "$output\mtefe_lnh_mtc28_KOMNY_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est1
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_lnw_htc28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est2
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_lnh_mtc28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est3
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_lnw_htc28_KOMNY_erhvcomp_given_complete_male0_polynomial(1)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est4
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
esttab est1 est2 est3 est4 using "$output\mtefe_loghours_logwage_topcoded_KOMNY_erhvcomp_given_complete_maleX_dist_voc&gen_mathcross_separate_4_MTEtable_boot500.rtf", ///
	   replace keep(ate att atut p01 p02 p1 p2) stats(N polynomial pX pU, fmt(%9.0gc %9.0gc %9.4g %9.4f))  b(%9.3f) se(3)  nogaps label ///
	   /*varwidth(40)*/ title("Treatment effects. Preferred polynomial models. Treatment: erhvcomp given complete. Males & females.") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 

* Table A13 in the Online Appendix
// child28  
// Bootstrapped SEs
eststo clear
estimates use "$output\mtefe_child28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est1
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
estimates use "$output\mtefe_child28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"
eststo est2
estadd scalar pX=real(e(p_X))
estadd scalar pU=real(e(p_U))
esttab est1 est2 using "$output\mtefe_child28_KOMNY_erhvcomp_given_complete_maleX_dist_voc&gen_mathcross_separate_MTEtable_boot500.rtf", ///
	   replace keep(ate att atut p01 p02 p1 p2) stats(N polynomial pX pU, fmt(%9.0gc %9.0gc %9.4g %9.4g))  b(%9.3f) se(3)  nogaps label ///
	   /*varwidth(40)*/ title("Treatment effects. Preferred polynomial models. Treatment: erhvcomp given complete. Males & females. Boot500") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 

	   

* Figure 2
//att&sep graphs
eststo clear
estimates use "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_prte_p01.ster"
eststo est1
estimates use "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_prte_p01.ster"
eststo est2
foreach x in separate att /*atut mprte2 late mprte1 mprte3*/{	   
mtefeplot est1, memory `x' graph_opts(title("") subtitle("Earnings age 40:  Males"))  
gr save   "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_`x'.gph", replace
mtefeplot est2, memory `x' graph_opts(title("") subtitle("Earnings age 40:  Females"))  
gr save   "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_`x'.gph", replace
}
// Modify "separate" graphs with potential outcomes to make Y1 curve more visible and remove colors, playing a recorded file with changes created in graph edit! 
gr use  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_separate.gph", play("$output\aa_graphedit_separate2.grec")
gr save "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_separate2.gph", replace
gr use  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_separate.gph", play("$output\aa_graphedit_separate2.grec")
gr save "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_separate2.gph", replace
// Modify "att" graphs with potential outcomes to remove colors, playing a recorded file with changes created in graph edit! 
gr use  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_att.gph", play("$output\aa_graphedit_att_male1.grec")
gr save "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_att2.gph", replace
gr use  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_att.gph", play("$output\aa_graphedit_att_male1.grec")
gr save "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_att2.gph", replace
// Combined graph for earn40x3lag7477: att and separate
gr combine "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_att2.gph" ///
           "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_att2.gph" /// 
           "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male1_polynomial(1)_dist_voc&gen_mathcross_separate_separate2.gph" ///
           "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_male0_polynomial(3)_dist_voc&gen_mathcross_separate_separate2.gph", altshrink rows(2) scheme(lean1) 
gr display, scale(1.2)
gr save    "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_maleX_polynomial_dist_voc&gen_mathcross_separate_att&sep.gph", replace		   
gr export  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_maleX_polynomial_dist_voc&gen_mathcross_separate_att&sep.png", replace height(3000)		   
gr use     "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_maleX_polynomial_dist_voc&gen_mathcross_separate_att&sep.gph"		   
gr export  "$output\mtefe_earn40x3lag7477_erhvcomp_given_complete_maleX_polynomial_dist_voc&gen_mathcross_separate_att&sep.tif", replace 		   



*********************************
// Robustness checks - MTE models
*********************************
	   
// Estimations for Table A14 in the Online Appendix	which is constructed in B2_bootstrap_tables_6_A14_C3_figure_1.do (using also the baseline estimated in B2_bootstrap_earn28)   
// Robustness check/earnings dynamics: excluding those in education at age 28
// Bootstrapped SEs
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28  {
eststo clear
foreach p in /*polynomial(1)*/ polynomial(2) /*polynomial(3)*/ /*polynomial(4)*/ {
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & edu28==0, link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est save "$output\mtefe_`y'_edu280_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_edu280_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
}
}
}
}
// Robustness check: excluding those in education at age 28 or 27
// Bootstrapped SEs
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28  {
eststo clear
foreach p in /*polynomial(1)*/ polynomial(2) /*polynomial(3)*/ /*polynomial(4)*/ {
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & edu28==0 & edu27==0, link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est save "$output\mtefe_`y'_edu280edu270_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_edu280edu270_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
}
}
}
}
// Robustness check: excluding those in education at age 28 or 27 or 26
// Bootstrapped SEs
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28  {
eststo clear
foreach p in /*polynomial(1)*/ polynomial(2) /*polynomial(3)*/ /*polynomial(4)*/ {
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & edu28==0 & edu27==0 & edu26==0, link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est save "$output\mtefe_`y'_edu280edu260_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_edu280edu260_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
}
}
}
}

	   

// Robustness check: Same N in estimation for tinderh28 as for earn28p27. Second column in Table C6, see B6_bootstrap_specification_table_C6.do for construction of this table.
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28{
eststo clear
foreach p in polynomial(2){
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m' & earn28p27_7477!=., link(logit) `p' gridpoints(100)  boot(500) noplot separate level(90)  
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_robustNearn28p27_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_robustNearn28p27_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
}
}
}
}


// Robustness check: No cross terms betweeen distance and math test score in the first stage
// 1. Initial estimations to determine order of polynomial in p
foreach tr in erhv erhvcomp{
foreach m in 1 0{
foreach y in  tinderh28 earn40x3lag7477  {
eststo clear
foreach p in polynomial(1) polynomial(2) polynomial(3){
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w )  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100) vce(robust) separate level(90) 
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_NOTmathcross_separate.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_NOTmathcross_separate.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
mtefeplot , memory prte
gr save   "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_NOTmathcross_separate.gph", replace
gr export "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_NOTmathcross_separate.png", replace height(800)
}
}
}
}
// 2. Bootstrapped SEs for earnings at age 28 (tinderh28) for preferred order of polynomial (2). 
//    For earnings at age 40, see the file B3_bootstrap_robustness_distnocross
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28 {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
local p "polynomial(2)" 
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w)  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est sto reg
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_NOTmathcross_separate_boot500.ster", replace
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_NOTmathcross_separate_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N)
}
}
}


// Robustness check: distance to nearest vocational/general school instead of weighted average distance 
// Outcome is earnings at age 28 (tinderh28). For earnings at age 40, see the file B3_bootstrap_robustness_distnearest
// Bootstrapped standard errors (preferred order of polynomial is 2)
// For earnings at age 40, see the file B3_bootstrap_robustness_distnearest
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
foreach y in tinderh28 {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
local p "polynomial(2)" 
set seed 211103
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_first c.afst1_2025_first c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  boot(500) separate level(90) noplot
est save "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_Robustness_nearest_school_boot500.ster", replace
est sto reg
esttab reg using "$output\mtefe_`y'_KOMNY_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_Robustness_nearest_school_boot500.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
}
}
}


// Robustness check (not bootstrapped SE's): Completion versus enrollment as treatment
// We here use enrollment as treatment BUT restrict the sample to completers only (the main sample)
// The idea is to see if effects of enrollment differ from effects of completion when the sample is fixed (main sample of completers)
// As noted at the end of Online Appendix C.4, the two sets of effects are very similar. 
foreach tr in erhv /*erhvcomp*/{
foreach m in 1 0{
foreach y in  tinderh28 earn40x3lag7477 {
eststo clear
foreach p in polynomial(1) polynomial(2) polynomial(3){
local cond "complete"
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  vce(robust) separate level(90) noplot
est save "$output\mtefe_robustness_`y'_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.ster", replace
est sto reg
esttab reg using "$output\mtefe_robustness_`y'_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate.rtf", replace b(%9.3f) se(3)  nogaps label varwidth(40) title("MTE") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
mtefeplot , memory 
gr export "$output\mtefe_robustness_`y'_`tr'_given_`cond'_male`m'_`p'_mtePlot_dist_voc&gen_mathcross_separate.png", replace height(800)
}
}
}
}




*********************************************
// First stage: Table 5 and Appendix Table C9
*********************************************
*  Table 5 and Appendix Table C9
// first stage logit - distance interacted with test scores: math and no math score dummy; distance to both voc and gen
eststo clear
foreach tr in erhv erhvcomp{
foreach m in 0 1{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'  c.afst1_30_average_w    c.afst1_2025_average_w   c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13) ///
            $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m', robust																					// with interactions
testparm    c.afst1_30_average_w    c.afst1_2025_average_w   c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13)
estadd scalar chi_2=r(chi2)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
testparm     c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13)
estadd scalar chi_2_cross=r(chi2)
estadd scalar pvalue_cross=r(p)
estadd scalar df_constraints_cross=r(df)
est sto m`m'1
logit `tr'  c.afst1_30_average_w   c.afst1_2025_average_w  $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust                                   // without interactions
testparm c.afst1_30_average_w   c.afst1_2025_average_w 
estadd scalar chi_2=r(chi2)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`m'2
}
esttab m11 m12 m01 m02 using "$output\firststage_logit_interactions_math&nomathscore_distgen_distvoc_`tr'_given_`cond'_komny.rtf", replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("First stage, treatment: `tr' conditional on `cond'") mlabel("Male" "Male" "Female" "Female") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
	   stats(N chi_2 pvalue df_constraints chi_2_cross pvalue_cross df_constraints_cross, fmt(0 1 %10.7e 0 1 %10.7e 0))   ///
	   keep(afst1_30_average_w afst1_2025_average_w c.afst1_30_average_w#c.math_ex13 1.no_exam_mat13#c.afst1_30_average_w c.afst1_2025_average_w#c.math_ex13 1.no_exam_mat13#c.afst1_2025_average_w)
}
// first stage logit - marginal effects
eststo clear
foreach tr in erhv erhvcomp{
foreach m in 0 1{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'    c.afst1_30_average_w c.afst1_2025_average_w c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13) ///
              $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
margins, dydx(c.afst1_30_average_w c.afst1_2025_average_w $all_factor_exmale i.byear i.kom_ny) post
est sto m`m'1
logit `tr'    c.afst1_30_average_w c.afst1_2025_average_w $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
margins, dydx(c.afst1_30_average_w c.afst1_2025_average_w $all_factor_exmale i.byear i.kom_ny) post
est sto m`m'2
}
esttab m11 m12 m01 m02 using "$output\firststage_logit_interactions_math&nomathscore_distgen_distvoc_marginaleffects_`tr'_given_`cond'_komny.rtf", replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("First stage, treatment: `tr' conditional on `cond'") mlabel("Male" "Male" "Female" "Female") star(+ 0.10 * 0.05 ** 0.01 *** 0.001)  ///
	   keep(afst1_30_average_w afst1_2025_average_w)
}
*******************
* Figure A1 in the Online Appendix
// Histograms of estimated propensity scores in first stage: Figure A1 in the Online Appendix. And similar figure for enrollment as treatment (not shown in the paper or appendix) 
// Check common support: frequencies
// Distance-math cross terms included
eststo clear
foreach tr in erhv erhvcomp{
foreach m in 0 1{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
quietly logit `tr'  c.afst1_30_average_w    c.afst1_2025_average_w   c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13) ///
            $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
predict phat_`tr'_`m' if e(sample), pr
}
}
// Frequency histograms
foreach tr in erhvcomp erhv{
// males
gen phat=phat_`tr'_1
gen treated=.
replace treated=phat if `tr'==1
gen untreated=.
replace untreated=phat if `tr'==0
gr twoway histogram treated , freq xtitle("Propensity score") subtitle("Males, treated") scheme(lean1) bin(100)
gr save "$output\CommonSupport_`tr'_male_treated.gph", replace
gr twoway histogram untreated , freq xtitle("Propensity score") subtitle("Males, untreated") scheme(lean1) bin(100) 
gr save "$output\CommonSupport_`tr'_male_untreated.gph", replace
gr twoway histogram treated if treated<=.5, freq xtitle("Propensity score") subtitle("Males, treated, p<0.5") scheme(lean1) bin(50)
gr save "$output\CommonSupport_`tr'_male_treated_low.gph", replace
gr twoway histogram untreated if untreated>=.5, freq xtitle("Propensity score") subtitle("Males, untreated, p>0.5") scheme(lean1) bin(50)
gr save "$output\CommonSupport_`tr'_male_untreated_high.gph", replace
drop phat treated untreated
// females
gen phat=phat_`tr'_0
gen treated=.
replace treated=phat if `tr'==1
gen untreated=.
replace untreated=phat if `tr'==0
gr twoway histogram treated , freq xtitle("Propensity score") subtitle("Females, treated") scheme(lean1) bin(100)
gr save "$output\CommonSupport_`tr'_female_treated.gph", replace
gr twoway histogram untreated , freq xtitle("Propensity score") subtitle("Females, untreated") scheme(lean1) bin(100) ylabel(0(2000)8000)
gr save "$output\CommonSupport_`tr'_female_untreated.gph", replace
gr twoway histogram treated if treated<=.5, freq xtitle("Propensity score") subtitle("Females, treated, p<0.5") scheme(lean1) bin(50)
gr save "$output\CommonSupport_`tr'_female_treated_low.gph", replace
gr twoway histogram untreated if untreated>=.5, freq xtitle("Propensity score") subtitle("Females, untreated, p>0.5") scheme(lean1) bin(50)
gr save "$output\CommonSupport_`tr'_female_untreated_high.gph", replace
drop phat treated untreated
gr combine "$output\CommonSupport_`tr'_male_treated.gph" ///
           "$output\CommonSupport_`tr'_female_treated.gph" ///
           "$output\CommonSupport_`tr'_male_untreated.gph" ///
           "$output\CommonSupport_`tr'_female_untreated.gph", altshrink scheme(lean1) 
gr display, /*ysize(6)*/ scale(1.2)
gr save   "$output\CommonSupport_`tr'.gph", replace
gr export "$output\CommonSupport_`tr'.png", replace height(3000)
gr combine "$output\CommonSupport_`tr'_male_treated.gph" ///
           "$output\CommonSupport_`tr'_female_treated.gph" ///
           "$output\CommonSupport_`tr'_male_untreated.gph" ///
           "$output\CommonSupport_`tr'_female_untreated.gph" /// 
           "$output\CommonSupport_`tr'_male_untreated_high.gph" ///
           "$output\CommonSupport_`tr'_female_untreated_high.gph", altshrink scheme(lean1) row(3)
gr display, ysize(6) scale(1.2)
gr save   "$output\CommonSupport_`tr'_6.gph", replace
gr export "$output\CommonSupport_`tr'_6.png", replace height(3000)
}
drop phat*

**********



*************************************************************************************
// Robustness and specification checks related to the first stage and the instruments
*************************************************************************************

*  Table C11 in the Online Appendix
// Selection into the sample: Test of significance of the two distance instruments
// First stage for treatment start vs nostart and complete vs nocomplete, respectively
// linear models without cross terms (not by gender)
eststo clear
foreach tr in erhv erhvcomp{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
reg  `cond'  c.afst1_30_average_w  c.afst1_2025_average_w  i.male  $all_factor_exmale i.byear i.kom_ny  , robust
testparm  c.afst1_30_average_w  c.afst1_2025_average_w
estadd scalar Ftest=r(F)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`cond'
esttab mstart mcomplete  using "$output\SelectionSample_linear_distgen_distvoc_notbygender.rtf", replace keep(afst1_30_average_w  afst1_2025_average_w) b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("Effect of IVs on selection into sample") /*mlabel("Start" "Complete")*/ star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N Ftest pvalue df_constraints, fmt(0 1 4 0))
}
// For comparison with above table: Main first stage, but linear regression without cross terms, and not by gender
eststo clear
foreach tr in erhv erhvcomp{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
reg  `tr'  c.afst1_30_average_w  c.afst1_2025_average_w  i.male  $all_factor_exmale i.byear i.kom_ny  if `cond'==1, robust
testparm  c.afst1_30_average_w  c.afst1_2025_average_w
estadd scalar Ftest=r(F)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`cond'
esttab mstart mcomplete  using "$output\Selection_`tr'_given_`cond'_linear_distgen_distvoc_notbygender.rtf", replace keep(afst1_30_average_w  afst1_2025_average_w) b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("Effect of IVs on selection into treatment. OLS, no cross terms. Not by gender") /*mlabel("Start" "Complete")*/ star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N Ftest pvalue df_constraints, fmt(0 1 %10.7e 0))
}


*  Table C12 in the Online Appendix
// Additional 1st stage analysis: Do the instruments affect completion given enrolment?
// SUR (suest)
eststo clear
foreach cond in start erhv gymn{
foreach tr in nocomplete erhvcomp gymncomp{
reg `tr'  c.afst1_30_average_w   c.afst1_2025_average_w  $all_factor i.byear i.kom_ny  if `cond'==1  // same as above but without robust option - this is applied in suest below 
est sto `tr'_given_`cond'
}
eststo: suest nocomplete_given_`cond' erhvcomp_given_`cond' gymncomp_given_`cond', vce(robust)
foreach t in nocomplete erhvcomp gymncomp{
test [`t'_given_`cond'_mean]afst1_30_average_w   [`t'_given_`cond'_mean]afst1_2025_average_w 
estadd local c`t'`cond' = "`: display %9.1f r(chi2)'"
estadd local p`t'`cond' = "`: display %9.4f r(p)'"
estadd local d`t'`cond' = "`: display %9.0f r(df)'"
}
test [nocomplete_given_`cond'_mean]afst1_30_average_w   [nocomplete_given_`cond'_mean]afst1_2025_average_w ///
       [erhvcomp_given_`cond'_mean]afst1_30_average_w     [erhvcomp_given_`cond'_mean]afst1_2025_average_w ///
       [gymncomp_given_`cond'_mean]afst1_30_average_w     [gymncomp_given_`cond'_mean]afst1_2025_average_w 
estadd local c`cond' = "`: display %9.1f r(chi2)'"	   
estadd local p`cond' = "`: display %9.4f r(p)'"
estadd local d`cond' = "`: display %9.0f r(df)'"
esttab . using "$output\firststage_Additional_SUR_distgen_distvoc_complete_given_`cond'.rtf", replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
	   keep(afst1_30_average_w afst1_2025_average_w)  title("Completion conditional on `cond'") unstack star(+ 0.10 * 0.05 ** 0.01 *** 0.001) /// 
	   stats(N ///
			 cnocomplete`cond' cerhvcomp`cond' cgymncomp`cond' ///
			 pnocomplete`cond' perhvcomp`cond' pgymncomp`cond' ///
			 dnocomplete`cond' derhvcomp`cond' dgymncomp`cond' ///
			 c`cond' p`cond' d`cond', layout(@  "@ @ @"  "@ @ @"  "@ @ @"  @ @ @)  ///
			 fmt(%9.0gc  %9.1f %9.1f %9.1f  %9.4f %9.4f %9.4f  %9.0f %9.0f %9.0f  %9.1f %9.4f %9.0f)  ///
			 labels("N"  "Chi squared" "P value" "Degrees of freedom"   "Chi squared" "P value" "Degrees of freedom"))
}


*  Table C13 in the Online Appendix
// Do the instruments affect test scores in general upper secondary school given completion of this education?
eststo clear
foreach cond in gymncomp gymn none{   // we condition on different subsamples 
if      "`cond'"=="gymncomp" local condi "gymncomp==1"
else if "`cond'"=="gymn"     local condi "gymncomp==1 & gymn==1" 
else                         local condi "gpa!=." 
reg gpa  c.afst1_30_average_w   c.afst1_2025_average_w  $all_factor_exmale male i.byear i.kom_ny  if `condi' , robust
testparm c.afst1_30_average_w   c.afst1_2025_average_w 
estadd scalar Ftest=r(F)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`cond'
}
esttab mgymn mgymncomp mnone using "$output\firststage_Additional_GPA_OLS_distgen_distvoc_given_gymncomp_gymn_komny.rtf", replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
	   keep(afst1_30_average_w afst1_2025_average_w)  ///
	   title("Effect of distance on GPA conditional on (1) first enrollment and completion of general edu., or (2) first completion of general edu., or (3) all with non-missing GPA (including those who completed a vocatinal edu. before a general).") ///
	   mlabel("gymncomp&gymn" "gymncomp" "none") star(+ 0.10 * 0.05 ** 0.01 *** 0.001)  stats(N Ftest pvalue df_constraints, fmt(%9.0gc 1 4 0)) addnotes("GPA has a mean of 66 and a standard deviation of 24")



*  Table C14 in the Online Appendix
// Placebo test that distance instruments do not predict completion of 9th grade
// Completion of 9th grade is measured by dummies for non-missing and passing test scores at the end of 9th grade
// OLS regressions without test score controls
gen nomis_matdan = no_exam_mat13==0 & no_exam_dan13==0   // non-missing test scores in math and Danish
gen pass_matdan  = no_exam_mat13==0 & no_exam_dan13==0 & danish_OW_ex13>=6  & math_ex13>=6   // passing test scores in math and Danish
gen pass_all     = no_exam_mat13==0 & no_exam_dan13==0 & danish_OW_ex13>=6  & math_ex13>=6 & no_english_ex13==0 & no_science_ex13==0 & english_ex13>=6 & science_ex13>=6 // passing scores in math, Danish, English and science
gen some_grade9marks=1-not_grade9marks // at least one non-missing 9th grade test score
// specify table to use for append below
eststo clear
quietly reg some_grade9marks c.afst1_30_average_w c.afst1_2025_average_w  i.male $factor_cohort_reg $factor_demo_socio, robust  
testparm  c.afst1_30_average_w    c.afst1_2025_average_w   
estadd scalar pvalue=r(p)
esttab  using "$output\firststage_OLS_PLACEBO_small_distgen_distvoc_komny.rtf", replace b(%9.5f) se(5)  nogaps label varwidth(40) /// 
	   keep(afst1_30_average_w afst1_2025_average_w) ///
       title("First stage, PLACEBO, effect of distance on 9th grade exam")  star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N pvalue, fmt(0 5))
foreach y in some_grade9marks nomis_matdan pass_matdan pass_all {
eststo clear
foreach tr in sample erhv erhvcomp{
if      "`tr'"=="sample" local cond "sample"
else if "`tr'"=="erhv"   local cond "start"
else                     local cond "complete"
quietly reg `y'  c.afst1_30_average_w c.afst1_2025_average_w  i.male $factor_cohort_reg $factor_demo_socio   if `cond'==1, robust
testparm  c.afst1_30_average_w    c.afst1_2025_average_w   
estadd scalar Ftest=r(F)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`cond'
}
esttab msample mstart mcomplete using "$output\firststage_OLS_PLACEBO_small_distgen_distvoc_komny.rtf", append b(%9.5f) se(5)  nogaps label varwidth(40) /// 
	   keep(afst1_30_average_w afst1_2025_average_w) ///
       title("First stage, PLACEBO, effect of distance on `y'") mlabel("sample" "start" "complete") star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N pvalue, fmt(0 5))
}


*  Table C15 in the Online Appendix
// Robustness: 1st stage with only subsets of test scores or without test scores
// Logit first stage
global all            $all_factor_exmale i.byear i.kom_ny
global notmathsci     c.danish_OW_ex13 c.english_ex13 c.danish_OW_co13 c.english_co13 c.obl_proj13  ///
                      i.no_exam_dan13 i.no_english_ex13 i.no_english_co13 i.no_obl_proj13 i.old_grad i.not_grade9marks i.nogrades86  $factor_cohort_reg $factor_demo_socio    
global notdaneng      c.math_ex13 c.science_ex13  c.math_co13 c.science_co13  c.obl_proj13  ///
                      i.no_exam_mat13 i.no_science_ex13 i.no_obl_proj13 i.old_grad i.not_grade9marks i.nogrades86                    $factor_cohort_reg $factor_demo_socio
global no                                                                                                                            $factor_cohort_reg $factor_demo_socio     
eststo clear
foreach tr in /*erhv*/ erhvcomp{
foreach m in 0 1{
foreach r in all notmathsci notdaneng no{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'  c.afst1_30_average_w c.afst1_2025_average_w  $`r'  if `cond'==1 & male==`m', robust
testparm  c.afst1_30_average_w    c.afst1_2025_average_w   
estadd scalar chi_2=r(chi2)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`m'`r'
}
}
esttab m1all m1notmathsci m1notdaneng m1no m0all m0notmathsci m0notdaneng m0no using "$output\firststage_logit_SomeTestscores_distgen_distvoc_`tr'_given_`cond'_komny.rtf", replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("First stage, All, some or no test scores, treatment: `tr' conditional on `cond'") ///
	   mlabel("Male, All" "Male, Not Math or Sci." "Male, Not Danish or English" "Male, No" "Female, All" "Female, Not Math or Sci." "Female, Not Danish or English" "Female, No") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) stats(N chi_2 pvalue df_constraints, fmt(%9.0gc 1 %10.7e 0)) keep(afst1_30_average_w afst1_2025_average_w)
}
// Logit first stage - marginal effects 
eststo clear
foreach tr in /*erhv*/ erhvcomp{
foreach m in 0 1{
foreach r in all notmathsci notdaneng no{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'  c.afst1_30_average_w c.afst1_2025_average_w  $`r'   if `cond'==1 & male==`m', robust
margins, dydx(c.afst1_30_average_w c.afst1_2025_average_w) post
est sto m`m'`r'
}
}
esttab m1all m1notmathsci m1notdaneng m1no m0all m0notmathsci m0notdaneng m0no using "$output\firststage_logit_SomeTestscores_distgen_distvoc_`tr'_given_`cond'_komny_marginal_effects.rtf", ///
	   replace b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("First stage, All, some or no test scores, treatment: `tr' conditional on `cond'. Marginal effects") ///
	   mlabel("Male, All" "Male, Not Math or Sci." "Male, Not Danish or English" "Male, No" "Female, All" "Female, Not Math or Sci." "Female, Not Danish or English" "Female, No") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) keep(afst1_30_average_w afst1_2025_average_w)
}


	   
*********************************************************


