*** This programme constructs tables and figures for MTE results for earnings at age 28 and 40. Standard errors are bootstrapped. 

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

// MTE curves

est use "$output\boot_earn40x3lag7477_male1_complete_reps500_seed211103_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 40: Males") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_earn40x3lag7477_male1_complete_reps500_seed211103.gph", replace

est use "$output\boot_earn40x3lag7477_male0_complete_reps500_seed211103_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 40: Females") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
			   legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_earn40x3lag7477_male0_complete_reps500_seed211103.gph", replace

est use "$output\boot_tinderh28_male1_complete_reps500_seed211103_date211203_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 28: Males") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_tinderh28_male1_complete_reps500_seed211103.gph", replace

est use "$output\boot_tinderh28_male0_complete_reps500_seed211103_date211203_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 28: Females") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_tinderh28_male0_complete_reps500_seed211103.gph", replace

// Combined graph: 
// Figure 1
gr combine "$output\graph_mte_boot_tinderh28_male1_complete_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_tinderh28_male0_complete_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_earn40x3lag7477_male1_complete_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_earn40x3lag7477_male0_complete_reps500_seed211103.gph", altshrink /*iscale(.55)*/ rows(2) scheme(lean1) 
gr display, /*ysize(6)*/ scale(1.2)
gr save    "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhvcomp_given_complete_maleX_boot_reps500_seed211103.gph", replace		   
gr export  "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhvcomp_given_complete_maleX_boot_reps500_seed211103.png", replace height(3000)

gr use     "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhvcomp_given_complete_maleX_boot_reps500_seed211103.gph"	   
gr export  "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhvcomp_given_complete_maleX_boot_reps500_seed211103.tif", replace height(800)


// Main table of MTE results with bootstrapped SEs
// Table 6
eststo clear
foreach m in tinderh28_male1_complete_reps500_seed211103_date211203  earn40x3lag7477_male1_complete_reps500_seed211103_date211129 ///
			 tinderh28_male0_complete_reps500_seed211103_date211203  earn40x3lag7477_male0_complete_reps500_seed211103_date211129 {
eststo: est use "$output\boot_`m'_p01.ster"
test $Xname
estadd scalar pX=r(p)
test k_p1 k_p2 k_p3 k_p4
estadd scalar pU=r(p)
estadd scalar pol=r(df)
}
esttab using "$output\mtefe_earn28_earn40_erhvcomp_given_complete_separate_MTEtable_prte_boot500.rtf", replace keep(k_p1 k_p2 k_p3 ate att atut prte N) order(k_p1 k_p2 k_p3 ate att atut prte N) /// 
       stats(pol pX pU, fmt(%9.0gc %9.4g %9.4g))  b(%9.3f) se(3)  nogaps /*label*/ /*varwidth(40)*/ title("Treatment effects. Preferred polynomial models. Treatment: erhvcomp given complete. Males & females. PRTE: p+0.01") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
// Append PRTE estimates (other than p01)
foreach x in 1km p01matlow p01matmid p01mathigh{
eststo clear
foreach m in tinderh28_male1_complete_reps500_seed211103_date211203  earn40x3lag7477_male1_complete_reps500_seed211103          ///
			 tinderh28_male0_complete_reps500_seed211103_date211203  earn40x3lag7477_male0_complete_reps500_seed211103_date211129 {
eststo: est use "$output\boot_`m'_`x'.ster"
}
esttab using "$output\mtefe_earn28_earn40_erhvcomp_given_complete_separate_MTEtable_prte_boot500.rtf", /// 
       append keep(prte) b(%9.3f) se(3) nogaps label /*varwidth(40)*/ title("PRTE `x'") nomtitle nonumber star(+ 0.10 * 0.05 ** 0.01 *** 0.001) nonotes noobs
}


// Robustness check: Total income instead of earnings at age 28
// Table C3 in the Online Appendix
use "$data/prep2", clear  
eststo clear
eststo: est use "$output\boot_tinderh28_male1_complete_reps500_seed211103_date211203_p01.ster"  //created in B2_bootstrap_earn28_prte_p01.do
qui sum tinderh28 if complete==1 & male==1 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==1 & erhvcomp==0
estadd scalar mgen=r(mean)
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tindper28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"  //created in B0_estimation.do
qui sum tindper28 if complete==1 & male==1 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tindper28 if complete==1 & male==1 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\boot_tinderh28_male0_complete_reps500_seed211103_date211203_p01.ster"  //created in B2_bootstrap_earn28_prte_p01.do
qui sum tinderh28 if complete==1 & male==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==0 & erhvcomp==0
estadd scalar mgen=r(mean)
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tindper28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster" //created in B0_estimation.do
qui sum tindper28 if complete==1 & male==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tindper28 if complete==1 & male==0 & erhvcomp==0
estadd scalar mgen=r(mean)
esttab using "$output\mtefe_tindper28_erhvcomp_given_complete_MTEtable_boot500.rtf", replace keep(ate att atut N) order(ate att atut N) /// 
       stats(N polynomial mvoc mgen, fmt(%9.0gc %9.0gc %9.3f %9.3f) label("N" "Order of polynomial in p" "Mean outcome, vocational" "Mean outcome, general"))  b(%9.3f) se(3)  nogaps /*label coeflabels(ATE ATT ATUT N)*/ varwidth(25) ///
	   title("Robustness check: Baseline vs. total income at age 28. Treatment effects. Preferred polynomial models. Treatment: Vocational given complete. Males & females. Bootstrapped SEs (500 reps.)") ///
	   mtitle("Male, baseline" "Male, total income" "Female, baseline" "Female, total income")  ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 


// Robustness check: Excluding persons enrolled in education at age 28
// And models excluding those not enrolled in education at age 28 or 27; and at age 28, 27 and 26	   
// Table A14 in the Online Appendix
use "$data/prep2", clear  
eststo clear
eststo: est use "$output\boot_tinderh28_male1_complete_reps500_seed211103_date211203_p01.ster" // Baseline (Table 6) created in B2_bootstrap_earn28_prte_p01.do
qui sum tinderh28 if complete==1 & male==1 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==1 & erhvcomp==0
estadd scalar mgen=r(mean)
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tinderh28_edu280_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"  // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\mtefe_tinderh28_edu280edu270_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"  // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & edu27==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & edu27==0 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\mtefe_tinderh28_edu280edu260_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster"  // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & edu27==0 & edu26==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==1 & edu28==0 & edu27==0 & edu26==0 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\boot_tinderh28_male0_complete_reps500_seed211103_date211203_p01.ster" // Baseline (Table 6) created in B2_bootstrap_earn28_prte_p01.do
qui sum tinderh28 if complete==1 & male==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==0 & erhvcomp==0
estadd scalar mgen=r(mean)
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tinderh28_edu280_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster" // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\mtefe_tinderh28_edu280edu270_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster" // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & edu27==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & edu27==0 & erhvcomp==0
estadd scalar mgen=r(mean)
eststo: est use "$output\mtefe_tinderh28_edu280edu260_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_boot500.ster" // created in B0_estimation.do
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & edu27==0 & edu26==0 & erhvcomp==1
estadd scalar mvoc=r(mean)
qui sum tinderh28 if complete==1 & male==0 & edu28==0 & edu27==0 & edu26==0 & erhvcomp==0
estadd scalar mgen=r(mean)
esttab using "$output\mtefe_tinderh28_edu280edu270edu260_erhvcomp_given_complete_MTEtable_boot500.rtf", replace keep(ate att atut N) order(ate att atut N) /// 
       stats(N polynomial mvoc mgen, fmt(%9.0gc %9.0gc %9.3f %9.3f) label("N" "Order of polynomial in p" "Mean outcome, vocational" "Mean outcome, general"))  b(%9.3f) se(3)  nogaps /*label coeflabels(ATE ATT ATUT N)*/ varwidth(25) ///
	   title("Robustness check: Baseline vs. excluding individuals enrolled in education at age 28. Treatment effects. Preferred polynomial models. Treatment: Vocational given complete. Males & females. Bootstrapped SEs (500 reps.)") ///
	   mtitle("Male, baseline" "Male, excluding enrollees 28" "Male, excluding enrollees 27-28" "Male, excluding enrollees 26-28" ///
	          "Female, baseline" "Female, excluding enrollees 28" "Female, excluding enrollees 27-28" "Female, excluding enrollees 26-28")  ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 




