*** This programme calculates bootstrapped standard errors taking account of the estimation of the surrogate index of earnings at age 40
*** as well as the logit first-stage educational selection equation 

local dato 211207    // date used in output files
local seed 211103    // used as seed
local reps 500       // No. of repetitions in bootstrap
global male 1        // 1 0
global prte p01      // p01 1km p01matlow p01matmid p01mathigh 
global outcome earn40x3lag7477

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

*****************************************************
* 1. Initial MTE estimates
*****************************************************
foreach tr in /*erhv*/ erhvcomp{
foreach m in $male{
foreach y in $outcome {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
if      ("`y'"=="earn40x3lag" | "`y'"=="earn40x3lag7477") & `m'==0                                local p "polynomial(3)"
else if ("`y'"=="earn40x3lag" | "`y'"=="earn40x3lag7477") & `m'==1 & "`tr'"=="erhvcomp"           local p "polynomial(1)"
else                                                                                              local p "polynomial(2)" 

use "$data/prep2", clear  

qui logit `tr' $all_factor_exmale i.byear i.kom_ny  c.afst1_30_first c.afst1_2025_first c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13) ///
               if `y'!=. & `cond'==1 & male==`m'
predict double p if e(sample)

if "$prte"=="p01"{
gen     p_policy = p+.01
}
else if "$prte"=="p01matlow"{
gen     p_policy = p
replace p_policy = p+.01  if matlow==1
}
else if "$prte"=="p01matmid"{
gen     p_policy = p
replace p_policy = p+.01  if matmid==1
}
else if "$prte"=="p01mathigh"{
gen     p_policy = p
replace p_policy = p+.01  if mathigh==1
}
else if "$prte"=="1km" {
gen temp=afst1_2025_average_w
replace  afst1_2025_average_w=afst1_2025_average_w + 1  
predict double p_policy if e(sample)
replace afst1_2025_average_w=temp
}
replace p_policy = 1      if p_policy>1 & p_policy!=.

mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_first c.afst1_2025_first c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  /*boot(100)*/ vce(robust) separate level(90) /*trimsupport(.01)*/ prte(p_policy) noplot
est save "$output\mtefe_`y'_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_distnearest_separate_prte_$prte.ster", replace
/*
est use "$output\mtefe_`y'_`tr'_given_`cond'_male`m'_`p'_dist_voc&gen_mathcross_separate_prte_$prte.ster"
*/
matrix obs = ( _b[effects:ate], _b[effects:att], _b[effects:atut], _b[effects:prte] )
forval j=1/99{
matrix obs = (obs, _b[mte:u`j'] )
}
sum `y' if male==`m' & `cond'==1, d    // descriptive statistics for estimated earnings at age 40
matrix observe = (obs, r(N), r(mean), r(sd), r(min), r(max), r(p1), r(p99))
sum p 
matrix observe = (observe, r(mean))
sum p_policy
matrix observe = (observe, r(mean))

if e(polynomial)==1{
matrix observe = (observe, _b[k:p1], 0, 0, 0)
}
else if e(polynomial)==2{
matrix observe = (observe, _b[k:p1], _b[k:p2], 0, 0)
}
else if e(polynomial)==3{
matrix observe = (observe, _b[k:p1], _b[k:p2], _b[k:p3], 0)
}
else if e(polynomial)==4{
matrix observe = (observe, _b[k:p1], _b[k:p2], _b[k:p3], _b[k:p4])
}
foreach x of global Xcoef{
matrix observe = (observe, _b[beta1-beta0:`x'])
}

local u 
forval j=1/99{
local u `u' u`j'
}
matrix colnames observe = ate att atut prte `u' N mean sd min max p1 p99 mean_p mean_p_policy k_p1 k_p2 k_p3 k_p4 $Xname
matrix list observe	  
}
}
}


***********************
* 2. Bootstrap sample program 
***********************

use tempboot_7477_complete, clear

capture program drop myboot
program define myboot, rclass
preserve
bsample, strata(strat)

// 1. Estimation (prediction) of earnings at age 40
gen $outcome=.

forval a=28/31{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')) ///
		   ///
		   ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3' ib0.male ///
		   ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')  ///
		   ib0.male#(ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib0.male#(ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3')) ///
		   ib0.male#(ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')) ///
		   ///
		   if old==1
predict ytemp          if old==.                                                          /// 
					  &   earn`a'!=. & status`a'  !=. & hfd`a1' !=. & byear+`a1'==2018     ///
                      &   earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.                      ///
                      &   earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.                      ///
                      &   earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.
replace $outcome = ytemp if old==. & byear+`a1'==2018 //& ytemp!=.
drop ytemp
}

keep if old==. 
keep pnr $outcome
replace $outcome = $outcome / 6.5    // convert to USD: predictions are based on variables in DKK
merge m:1 pnr using main
drop _merge
keep if $outcome !=.

// 2. MTE estimation

foreach tr in /*erhv*/ erhvcomp{
foreach m in $male{
foreach y in $outcome {
eststo clear
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
if      ("`y'"=="earn40x3lag" | "`y'"=="earn40x3lag7477") & `m'==0                                local p "polynomial(3)"
else if ("`y'"=="earn40x3lag" | "`y'"=="earn40x3lag7477") & `m'==1 & "`tr'"=="erhvcomp"           local p "polynomial(1)"
else                                                                                              local p "polynomial(2)" 
qui logit `tr' $all_factor_exmale i.byear i.kom_ny  c.afst1_30_first c.afst1_2025_first c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13) ///
               if `y'!=. & `cond'==1 & male==`m'
predict double p if e(sample)

if "$prte"=="p01"{
gen     p_policy = p+.01
}
else if "$prte"=="p01matlow"{
gen     p_policy = p
replace p_policy = p+.01  if matlow==1
}
else if "$prte"=="p01matmid"{
gen     p_policy = p
replace p_policy = p+.01  if matmid==1
}
else if "$prte"=="p01mathigh"{
gen     p_policy = p
replace p_policy = p+.01  if mathigh==1
}
else if "$prte"=="1km" {
gen temp=afst1_2025_average_w
replace  afst1_2025_average_w=afst1_2025_average_w + 1  
predict double p_policy if e(sample)
replace afst1_2025_average_w=temp
}

replace p_policy = 1      if p_policy>1 & p_policy!=.
mtefe `y' $all_factor_exmale i.byear i.kom_ny  (`tr' = c.afst1_30_first c.afst1_2025_first c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13))  ///
      if `cond'==1 & male==`m', link(logit) `p' gridpoints(100)  /*boot(100)*/ vce(robust) separate level(90) prte(p_policy) noplot

return scalar ate  = _b[effects:ate]
return scalar att  = _b[effects:att]
return scalar atut = _b[effects:atut]
return scalar prte = _b[effects:prte]
forval j=1/99{
return scalar u`j'  = _b[mte:u`j']

}
sum `y' if male==`m' & complete==1, d            // descriptive statistics for estimated earnings at age 40
return scalar N = r(N)
return scalar mean = r(mean)
return scalar sd = r(sd)
return scalar min = r(min)
return scalar max = r(max)
return scalar p1 = r(p1)
return scalar p99= r(p99)

sum p 
return scalar mean_p=r(mean)
sum p_policy
return scalar mean_p_policy=r(mean)

if e(polynomial)==1{
return scalar k_p1 = _b[k:p1]
return scalar k_p2 = 0
return scalar k_p3 = 0
return scalar k_p4 = 0
}
else if e(polynomial)==2{
return scalar k_p1 = _b[k:p1]
return scalar k_p2 = _b[k:p2]
return scalar k_p3 = 0
return scalar k_p4 = 0
}
else if e(polynomial)==3{
return scalar k_p1 = _b[k:p1]
return scalar k_p2 = _b[k:p2]
return scalar k_p3 = _b[k:p3]
return scalar k_p4 = 0
}
else if e(polynomial)==4{
return scalar k_p1 = _b[k:p1]
return scalar k_p2 = _b[k:p2]
return scalar k_p3 = _b[k:p3]
return scalar k_p4 = _b[k:p4]
}

matrix x = (0)
foreach c of global Xcoef{
matrix x = (x, _b[beta1-beta0:`c'])
}
matrix colnames x = zero $Xname
matselrc x y, c(2/154)            // omit 1st column with a zero
matrix list y
foreach j of global Xname{
return scalar `j'=y[1,colnumb(y,"`j'")]
}

}
}
}
restore
end

**************
* 3. Simulate
**************
local male    "$male"
local outcome "$outcome" 
simulate $returnlist , ///
		 reps(`reps') seed(`seed') saving("$output\bootdata_robustness_distnearest_`outcome'_male`male'_complete_reps`reps'_seed`seed'_date`dato'_$prte.dta" , replace )  : myboot


*****************
* 4. Bootstrap results
*****************

bstat, stat(observe) level(90)
estout using "$output\boot_robustness_distnearest_`outcome'_male`male'_complete_all_reps`reps'_seed`seed'_date`dato'_$prte.rtf", ///
	   replace stats(N_reps, fmt(%9.0gc))  cells("b(fmt(4)) se ci_normal[1] ci_normal[2]") label  ///
	   /*varwidth(40)*/ title("Treatment effects with bootstrapped standard errors, 90% CI. Male $male.") 
est save "$output\boot_robustness_distnearest_`outcome'_male`male'_complete_reps`reps'_seed`seed'_date`dato'_$prte.ster", replace

ereturn list

regsave using "$output\boot_robustness_distnearest_`outcome'_male`male'_complete_reps`reps'_seed`seed'_date`dato'_$prte.dta", ci level(90) replace   // dta-dataset with coefs and bootstrapped CI (90%) to be used for creating MTE graphs. 
