*** This programme creates Appendix Tables C1 and C2: Robustness checks: Alternative specifications for the distance instruments


include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

// Table C1 in the Online Appendix
// Robustness check: No cross terms in first stage
// Main MTE results with bootstrapped SEs
eststo clear
// Baseline results
foreach m in tinderh28_male1_complete_reps500_seed211103_date211203  earn40x3lag7477_male1_complete_reps500_seed211103_date211129 ///
			 tinderh28_male0_complete_reps500_seed211103_date211203  earn40x3lag7477_male0_complete_reps500_seed211103_date211129 {
eststo: est use "$output\boot_`m'_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar pol=r(df)
}
esttab using "$output\mtefe_earn28_earn40_robustness_NOTmathcross_boot500.rtf", replace keep(ate att atut N) order(ate att atut N) /// 
       stats(pol, fmt(%9.0gc))  b(%9.3f) se(3)  nogaps title("Baseline estimates. Males & females.") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
// Append results for models with no cross terms in first stage
eststo clear
eststo: est use "$output\mtefe_tinderh28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_NOTmathcross_separate_boot500.ster"
eststo: est use "$output\boot_robustness_distnocross_earn40x3lag7477_male1_complete_reps500_seed211103_date211207_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tinderh28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_NOTmathcross_separate_boot500.ster"
eststo: est use "$output\boot_robustness_distnocross_earn40x3lag7477_male0_complete_reps500_seed211103_date211216_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
esttab using "$output\mtefe_earn28_earn40_robustness_NOTmathcross_boot500.rtf", append keep(ate att atut N) order(ate att atut N) /// 
       stats(N polynomial, fmt(%9.0gc %9.0gc))  b(%9.3f) se(3)  nogaps title("No cross terms in 1st stage. Males & females") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 

	   
	   
// Table C2 in the Online Appendix
// Distance to nearest vocational and general instead of weighted averages across sub-categories
// Main MTE results with bootstrapped SEs
eststo clear
// Baseline results
foreach m in tinderh28_male1_complete_reps500_seed211103_date211203  earn40x3lag7477_male1_complete_reps500_seed211103_date211129 ///
			 tinderh28_male0_complete_reps500_seed211103_date211203  earn40x3lag7477_male0_complete_reps500_seed211103_date211129 {
eststo: est use "$output\boot_`m'_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar pol=r(df)
}
esttab using "$output\mtefe_earn28_earn40_robustness_distnearest_boot500.rtf", replace keep(ate att atut N) order(ate att atut N) /// 
       stats(pol, fmt(%9.0gc))  b(%9.3f) se(3)  nogaps title("Baseline estimates. Males & females.") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
// Append results for models with distance to nearest institutions in first stage
eststo clear
eststo: est use "$output\mtefe_tinderh28_KOMNY_erhvcomp_given_complete_male1_polynomial(2)_dist_voc&gen_mathcross_separate_Robustness_nearest_school_boot500.ster"
eststo: est use "$output\boot_robustness_distnearest_earn40x3lag7477_male1_complete_reps500_seed211103_date211216_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
eststo: est use "$output\mtefe_tinderh28_KOMNY_erhvcomp_given_complete_male0_polynomial(2)_dist_voc&gen_mathcross_separate_Robustness_nearest_school_boot500.ster"
eststo: est use "$output\boot_robustness_distnearest_earn40x3lag7477_male0_complete_reps500_seed211103_date211207_p01.ster"
test k_p1 k_p2 k_p3 k_p4
estadd scalar polynomial=r(df)
esttab using "$output\mtefe_earn28_earn40_robustness_distnearest_boot500.rtf", append keep(ate att atut N) order(ate att atut N) /// 
       stats(N polynomial, fmt(%9.0gc %9.0gc))  b(%9.3f) se(3)  nogaps title("Distance to nearest school in 1st stage. Males & females") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
// Append first stage test for exclusion restrictions
use "$data/prep2", clear  
eststo clear
foreach tr in /*erhv*/ erhvcomp{
foreach m in 1 0{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
qui logit `tr'  c.afst1_30_first    c.afst1_2025_first   c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13) ///
            $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m', robust
testparm  c.afst1_30_first    c.afst1_2025_first   c.afst1_30_first#(c.math_ex13 no_exam_mat13) c.afst1_2025_first#(c.math_ex13 no_exam_mat13)
estadd scalar chi_2=r(chi2)
estadd scalar pvalue=r(p)
estadd scalar df_constraints=r(df)
est sto m`m'1
}
}
esttab m11 m01 using "$output\mtefe_earn28_earn40_robustness_distnearest_boot500.rtf", append keep(_cons) b(%9.4f) se(4)  nogaps label varwidth(40) /// 
       title("First stage. Robustness: Distance to nearest school. Test for exclusion restrictions") mlabel("Male" "Female")  ///
	   stats(N chi_2 pvalue df_constraints, fmt(0 1 %10.7e 0)) nostar
	   
