*** For the OLS model, this programme calculates bootstrapped standard errors taking account of the estimation of the surrogate index of earnings at age 40

local dato 211201 // used in output files
local seed 211103 /*472195*/   // used as seed
local reps 500       // No. of repetitions in bootstrap
//global male 0        // 1 0
global outcome earn40x3lag7477

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear
			 

*****************************************************
* 1. Initial OLS estimates
*****************************************************
use "$data/prep2", clear  

matrix obs = (0)
foreach y in $outcome {
foreach tr in /*erhv*/ erhvcomp{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
foreach m in 1 0{
forval c=1/3{
if      `c'==1 local control "$factor_cohort_reg"
else if `c'==2 local control "$factor_cohort_reg $factor_demo_socio"
else           local control "$factor_cohort_reg $factor_demo_socio $factor_testscores"

regress `y' `tr' `control'  if male==`m' & `cond'==1, robust  
est save "$output\OLS_`y'_`tr'_given_`cond'_male`m'_control`c'.ster", replace
matrix obs = ( obs, _b[`tr'] )
}
}
}
}
matselrc obs observe, c(2/7)   // omit 1st column (zero)
matrix colnames observe = vocm1c1 vocm1c2 vocm1c3 vocm0c1 vocm0c2 vocm0c3 
matrix list observe	  

***********************
* 2. Bootstrap sample program 
***********************

use tempboot_7477_complete, clear

capture program drop mybootOLS
program define mybootOLS, rclass
preserve
bsample, strata(strat)

// 1. Estimation (prediction) of earnings at age 40
gen $outcome=.

forval a=28/31{
local a1  = `a'+1
local a_1 = `a'-1
local a_2 = `a'-2
local a_3 = `a'-3
reg earn40 ib502020.hfd`a1' ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib0.male ///
		   ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism ///
		   ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf ///
		   ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf) ///
		   ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')  ///
		   ib0.male#(ib50.hfmain`a1' c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk) ///
		   ib0.male#(ib1.hfm ib0.hf_mism c.earningsm c.earningsm#c.earningsm ib0.incmism) ///
		   ib0.male#(ib1.hff ib0.hf_misf c.earningsf c.earningsf#c.earningsf ib0.incmisf) ///
		   ib0.male#(ib50.hfmain`a1'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a' ib1.status`a' c.k7 ib0.misk)) ///
		   ib0.male#(ib50.hfmain`a1'#(ib1.hfm ib0.hf_mism ib1.hff ib0.hf_misf)) ///
		   ib0.male#(ib1.status`a'#(c.earn`a' c.earn`a'#c.earn`a' ib2.ecat`a')) ///
		   ///
		   ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1' ib0.male ///
		   ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')  ///
		   ib0.male#(ib50.hfmain`a' c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1') ///
		   ib0.male#(ib50.hfmain`a'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1' ib1.status`a_1')) ///
		   ib0.male#(ib1.status`a_1'#(c.earn`a_1' c.earn`a_1'#c.earn`a_1' ib2.ecat`a_1')) ///
		   ///
		   ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2' ib0.male ///
		   ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')  ///
		   ib0.male#(ib50.hfmain`a_1' c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2') ///
		   ib0.male#(ib50.hfmain`a_1'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2' ib1.status`a_2')) ///
		   ib0.male#(ib1.status`a_2'#(c.earn`a_2' c.earn`a_2'#c.earn`a_2' ib2.ecat`a_2')) ///
		   ///
		   ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3' ib0.male ///
		   ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')  ///
		   ib0.male#(ib50.hfmain`a_2' c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3') ///
		   ib0.male#(ib50.hfmain`a_2'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3' ib1.status`a_3')) ///
		   ib0.male#(ib1.status`a_3'#(c.earn`a_3' c.earn`a_3'#c.earn`a_3' ib2.ecat`a_3')) ///
		   ///
		   if old==1
predict ytemp          if old==.                                                          /// 
					  &   earn`a'!=. & status`a'  !=. & hfd`a1' !=. & byear+`a1'==2018     ///
                      &   earn`a_1'!=. & status`a_1'!=. & hfd`a'  !=.                      ///
                      &   earn`a_2'!=. & status`a_2'!=. & hfd`a_1'!=.                      ///
                      &   earn`a_3'!=. & status`a_3'!=. & hfd`a_2'!=.
replace $outcome = ytemp if old==. & byear+`a1'==2018 //& ytemp!=.
drop ytemp
}

keep if old==. 
keep pnr $outcome
replace $outcome = $outcome / 6.5    // convert to USD: predictions are based on variables in DKK
merge m:1 pnr using main
drop _merge
keep if $outcome !=.

// 2. OLS estimation

foreach y in $outcome {
foreach tr in /*erhv*/ erhvcomp{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
foreach m in 1 0{
forval c=1/3{
if      `c'==1 local control "$factor_cohort_reg"
else if `c'==2 local control "$factor_cohort_reg $factor_demo_socio"
else           local control "$factor_cohort_reg $factor_demo_socio $factor_testscores"

regress `y' `tr' `control'  if male==`m' & `cond'==1, robust  
return scalar vocm`m'c`c' =  _b[`tr']
}
}
}
}
restore
end

**************
* 3. Simulate
**************
local outcome "$outcome" 
simulate vocm1c1=r(vocm1c1) vocm1c2=r(vocm1c2) vocm1c3=r(vocm1c3) vocm0c1=r(vocm0c1) vocm0c2=r(vocm0c2) vocm0c3=r(vocm0c3) , ///
		 reps(`reps') seed(`seed') saving("$output\bootdata_OLS_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.dta" , replace ) /*noisily*/ : mybootOLS


*****************
* 4. Bootstrap results
*****************

bstat, stat(observe) level(90)
esttab using "$output\boot_OLS_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.rtf", ///
	   replace stats(N_reps, fmt(%9.0gc))  b(%9.4f) se(4)  nogaps label  ///
	   /*varwidth(40)*/ title("OLS estimates with bootstrapped standard errors. OLS estimates by male (1 0) and controls (1 2 3)") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
est save "$output\boot_OLS_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.ster", replace


