*** This programme constructs tables with OLS results. For earnings at age 40 standard errors are bootstrapped

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A17_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

// OLS estimates for earnings at age 28 with robust standard errors
use "$data/prep2", clear  
foreach y in tinderh28 {
foreach tr in /*erhv*/ erhvcomp{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
foreach m in 1 0{
forval c=1/3{
if      `c'==1 local control "$factor_cohort_reg"
else if `c'==2 local control "$factor_cohort_reg $factor_demo_socio"
else           local control "$factor_cohort_reg $factor_demo_socio $factor_testscores"

qui regress `y' `tr' `control'  if male==`m' & `cond'==1, robust  
est save "$output\OLS_`y'_`tr'_given_`cond'_male`m'_control`c'.ster", replace
}
}
}
}

// OLS table with robust SEs for earnings at age 28 and bootstrapped SEs for earnings at age 40
foreach m in 1 0{
eststo clear
est use "$output\OLS_tinderh28_erhvcomp_given_complete_male`m'_control1.ster"
est sto r1
est use "$output\boot_OLS_earn40x3lag7477_complete_reps500_seed211103_date211201.ster"
est sto r2
esttab r1 r2 using "$output\OLS_tinderh28_earn40x3lag7477_boot500_by_controls_alt_male`m'.rtf", rename(vocm`m'c1 erhvcomp) keep(erhvcomp /*vocm`m'c1*/) replace b(%9.3f) se(3) stats(N , fmt(%9.0fc)) ///
       title("OLS. Male `m'. Controls: Row1 cohort&municipality dummies; Row2 also family background; Row3 also test scores. SEs bootstrapped for earn40.") compress nogaps /*label*/ varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) nonumber nonotes /*noobs*/ /*plain*/ 
forval c=2/3{
eststo clear
est use "$output\OLS_tinderh28_erhvcomp_given_complete_male`m'_control`c'.ster"
est sto r1
est use "$output\boot_OLS_earn40x3lag7477_complete_reps500_seed211103_date211201.ster"
est sto r2
esttab r1 r2 using "$output\OLS_tinderh28_earn40x3lag7477_boot500_by_controls_alt_male`m'.rtf", rename(vocm`m'c`c' erhvcomp) keep(erhvcomp) append b(%9.3f) se(3) stats(N , fmt(%9.0fc)) compress nogaps /*label*/ varwidth(10) modelwidth(6) abbrev star(+ 0.10 * 0.05 ** 0.01 *** 0.001) nonumber nonotes /*noobs*/ /*plain*/ 
}
}

// Table A6 in the Online Appendix contains all 3 rows, Table 4 in the article contains only the last row (with all controls).
