*** This programme creates table C10 and figure C1 based on results with bootstrapped standard errors taking account of the estimation of the surrogate index of earnings at age 40
*** as well as the logit first-stage educational selection equation 
*** NB: version with enrollment in vocational edu. as treatment

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

// MTE curves - Figure C1

est use "$output\boot_earn40x3lag7477_male1_start_reps500_seed211103_date211221_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 40: Males") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_earn40x3lag7477_male1_start_reps500_seed211103.gph", replace

est use "$output\boot_earn40x3lag7477_male0_start_reps500_seed211103_date211221_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 40: Females") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
			   legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_earn40x3lag7477_male0_start_reps500_seed211103.gph", replace

est use "$output\boot_tinderh28_male1_start_reps500_seed211103_date211221_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 28: Males") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_tinderh28_male1_start_reps500_seed211103.gph", replace

est use "$output\boot_tinderh28_male0_start_reps500_seed211103_date211221_p01.ster"      
regsave, ci level(90)
gen ate=_b[ate]
gen Ud=.
forval j=1/99{
replace Ud=`j'/100 if var=="u`j'" 
}
keep if Ud!=.
rename coef mte
label var Ud   "Unobserved resistance to treatment"
label var mte  "MTE"
label var ate  "ATE"
label var ci_lower "90% CI"
label var ci_upper "90% CI"
gr twoway line mte ci_lower ci_upper ate Ud, sort subtitle("Earnings age 28: Females") scheme(lean1) lpattern(solid longdash longdash dash_dot) color(gs0 gs8 gs8 gs6) lwidth(thick medium medium medium) ///
               legend(rows(1) position(6) order(1 2 4)) ylabel(,grid) //  ytitle("Density") xtitle("Propensity score")  lean1
gr save "$output\graph_mte_boot_tinderh28_male0_start_reps500_seed211103.gph", replace

// Combined graph  - Figure C1
gr combine "$output\graph_mte_boot_tinderh28_male1_start_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_tinderh28_male0_start_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_earn40x3lag7477_male1_start_reps500_seed211103.gph" ///
           "$output\graph_mte_boot_earn40x3lag7477_male0_start_reps500_seed211103.gph", altshrink /*iscale(.55)*/ rows(2) scheme(lean1) 
gr display, /*ysize(6)*/ scale(1.2)
gr save    "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhv_given_start_maleX_boot_reps500_seed211103.gph", replace		   
gr export  "$output\mtefe_tinderhv28&earn40x3lag7477_KOMNY_erhv_given_start_maleX_boot_reps500_seed211103.png", replace height(3000)


// Table of MTE results with bootstrapped SEs - Table C10

eststo clear
foreach m in tinderh28_male1_start_reps500_seed211103_date211221  earn40x3lag7477_male1_start_reps500_seed211103_date211221 ///
			 tinderh28_male0_start_reps500_seed211103_date211221  earn40x3lag7477_male0_start_reps500_seed211103_date211221 {
eststo: est use "$output\boot_`m'_p01.ster"
test $Xname
estadd scalar pX=r(p)
test k_p1 k_p2 k_p3 k_p4
estadd scalar pU=r(p)
estadd scalar pol=r(df)
}
esttab using "$output\mtefe_earn28_earn40_erhv_given_start_separate_MTEtable_prte_boot500.rtf", replace keep(k_p1 k_p2 k_p3 ate att atut prte N) order(k_p1 k_p2 k_p3 ate att atut prte N) /// 
       stats(pol pX pU, fmt(%9.0gc %9.4f %9.4f))  b(%12.3f) se(3)  nogaps /*label*/ /*varwidth(40)*/ title("Treatment effects. Preferred polynomial models. Treatment: erhv given start. Males & females. PRTE: p+0.01") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
// Append PRTE estimates (other than p01)
foreach x in 1km p01matlow p01matmid p01mathigh{
eststo clear
foreach m in tinderh28_male1_start_reps500_seed211103_date211221  earn40x3lag7477_male1_start_reps500_seed211103_date211221          ///
			 tinderh28_male0_start_reps500_seed211103_date211221  earn40x3lag7477_male0_start_reps500_seed211103_date211221 {
eststo: est use "$output\boot_`m'_`x'.ster"
}
esttab using "$output\mtefe_earn28_earn40_erhv_given_start_separate_MTEtable_prte_boot500.rtf", /// 
       append keep(prte) b(%9.3f) se(3) nogaps label /*varwidth(40)*/ title("PRTE `x'") nomtitle nonumber star(+ 0.10 * 0.05 ** 0.01 *** 0.001) nonotes noobs
}

