*** This programme calculates bootstrapped standard errors for iv-estimates on earnings at age 28 with phat as IV, taking account of 
*** of the estimation of phat 

local dato 211203      // used in output files
local seed 211103      // used as seed
local reps 500         // No. of repetitions in bootstrap
global outcome tinderh28

include "D:\data\Workdata\703822\Do_3822\p1602\Fra_RFF\Voc_vs_General_JHR\A0_paths.do"
include "$dofiles\A16_globals.do"

set more off 
cd "$data"
set matsize 2000
clear

*****************************************************
* 1. Initial IV estimates
*****************************************************

use "$data/prep2", clear  
matrix obs = (0)
foreach y in $outcome{
foreach tr in /*erhv*/ erhvcomp{
eststo clear
foreach m in 1 0{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'  c.afst1_30_average_w    c.afst1_2025_average_w   c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13) ///
            $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
predict p, pr
quietly ivregress 2sls `y' (`tr' = p) $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
est save "$output\2SLS_PhatIV_`y'_`tr'_given_`cond'_male`m'.ster", replace
mat obs = (obs, _b[`tr'])
drop p
}
}
}
matselrc obs observe, c(2/3)   // omit 1st column (zero)
matrix colnames observe = vocm1ivp vocm0ivp  // (male=1 iv=phat)  (male=0 iv=phat)  
matrix list observe	  

***********************
* 2. Bootstrap sample program 
***********************

use "$data/prep2", clear 
keep if sample==1  
keep if complete==1

capture program drop mybootIV28
program define mybootIV28, rclass
preserve
bsample, strata(male)

// 2. IV estimation using phat as IV

foreach y in $outcome{
foreach tr in /*erhv*/ erhvcomp{
eststo clear
foreach m in 1 0{
if "`tr'"=="erhv" local cond "start"
else              local cond "complete"
logit `tr'  c.afst1_30_average_w    c.afst1_2025_average_w   c.afst1_30_average_w#(c.math_ex13 no_exam_mat13) c.afst1_2025_average_w#(c.math_ex13 no_exam_mat13) ///
            $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
predict p, pr
quietly ivregress 2sls `y' (`tr' = p) $all_factor_exmale i.byear i.kom_ny  if `cond'==1 & male==`m' , robust
return scalar vocm`m'ivp =  _b[`tr']
drop p
}
}
}
restore
end

**************
* 3. Simulate
**************
local outcome "$outcome" 
simulate vocm1ivp=r(vocm1ivp) vocm0ivp=r(vocm0ivp) , ///
		 reps(`reps') seed(`seed') saving("$output\bootdata_2SLS_earn28_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.dta" , replace every(5))  : mybootIV28

*****************
* 4. Bootstrap results
*****************

bstat, stat(observe) level(90)
esttab using "$output\boot_2SLS_earn28_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.rtf", ///
	   replace stats(N_reps, fmt(%9.0gc))  b(%9.4f) se(4)  nogaps label  ///
	   /*varwidth(40)*/ title("IV estimates using phat as IV with bootstrapped standard errors. Estimates by male (1 0)") ///
	   star(+ 0.10 * 0.05 ** 0.01 *** 0.001) 
est save "$output\boot_2SLS_earn28_`outcome'_complete_reps`reps'_seed`seed'_date`dato'.ster", replace





